<?php
// Exit if accessed directly.
if (!defined('ABSPATH')) {
    exit;
}

class EssentialAdmin {

    private $plugin_name;
    private $plugin_version;

    public function __construct($name, $version) {

        $this->plugin_name = $name;
        $this->plugin_version = $version;
        add_action('admin_menu', array($this, 'add_menu_page'));
        add_action('admin_enqueue_scripts', array($this, 'enqueue_styles'));
        add_action('admin_enqueue_scripts', array($this, 'enqueue_scripts'));
        add_action('wp_ajax_save_eb_admin_options', [$this, 'eb_save_blocks']);
        register_activation_hook(ESSENTIAL_BLOCKS_FILE, array($this, 'activate'));
    }

    public function add_menu_page() {
        add_menu_page(
            __('Essential Blocks', 'essential-blocks'), __('Essential Blocks', 'essential-blocks'),
            'delete_user', 'essential-blocks', array($this, 'menu_page_display'), ESSENTIAL_BLOCKS_ADMIN_URL . 'admin/assets/images/eb-icon.svg', 100
        );
    }

    public function menu_page_display() {
        include ESSENTIAL_BLOCKS_DIR_PATH . 'admin/includes/partials/menu-page-display.php';
    }

    public function enqueue_styles() {
        wp_enqueue_style(
            $this->plugin_name,
            ESSENTIAL_BLOCKS_ADMIN_URL . 'admin/assets/css/essential-blocks.css',
            array(), $this->plugin_version, 'all'
        );
    }
    public function enqueue_scripts($hook) {
        if ($hook === 'toplevel_page_essential-blocks') {
            wp_enqueue_script(
                $this->plugin_name . '-admin',
                ESSENTIAL_BLOCKS_ADMIN_URL . 'admin/assets/js/essential-blocks.js',
                array('jquery', $this->plugin_name . '-swal'), $this->plugin_version, true
            );

            wp_enqueue_script(
                $this->plugin_name . '-swal',
                ESSENTIAL_BLOCKS_ADMIN_URL . 'admin/assets/js/sweetalert.min.js',
                array('jquery'),
                $this->plugin_version, true
            );

            wp_enqueue_script(
                $this->plugin_name . '-admin-blocks',
                ESSENTIAL_BLOCKS_ADMIN_URL . 'admin/assets/js/build.js',
                array('wp-i18n', 'wp-element', 'wp-hooks', 'wp-util', 'wp-components'),
                $this->plugin_version, true
            );

            wp_localize_script($this->plugin_name . '-admin-blocks', 'EssentialBlocksAdmin', array(
                'all_blocks' => $this->get_blocks(),
                'ajax_url' => admin_url('admin-ajax.php'),
                'nonce' => wp_create_nonce('eb-save-admin-options'),
            ));

        }

        wp_localize_script('essential-blocks-js', 'EssentialBlocks', array(
            'nonce' => $this->disabling_nonce(),
            'enabled_blocks' => $this->enabled_blocks(),
        ));
    }

    public function enabled_blocks() {
        $blocks = $this->get_blocks();

        $enabled_blocks = array();

        if ($blocks) {
            foreach ($blocks as $block) {
                if( isset( $block['visibility'] ) && $block['visibility'] == 'true' ){
                    $enabled_blocks[] = $block['value'];
                }
            }
        }

        return $enabled_blocks;
    }

    public function activate() {
        $default_blocks = [
            [
                'label' => 'Accordion',
                'value' => 'accordion',
                'visibility' => 'true',
            ],
            [
                'label' => 'Button',
                'value' => 'button',
                'visibility' => 'true',
            ],
            [
                'label' => 'Call To Action',
                'value' => 'call_to_action',
                'visibility' => 'true',
            ],
            [
                'label' => 'Countdown',
                'value' => 'countdown',
                'visibility' => 'true',
            ],
            [
                'label' => 'Flipbox',
                'value' => 'flipbox',
                'visibility' => 'true',
            ],
            [
                'label' => 'Infobox',
                'value' => 'infobox',
                'visibility' => 'true',
            ],
            [
                'label' => 'Notice',
                'value' => 'notice',
                'visibility' => 'true',
            ],
            [
                'label' => 'Pricing Table',
                'value' => 'pricing_table',
                'visibility' => 'true',
            ],
            [
                'label' => 'Social',
                'value' => 'social',
                'visibility' => 'true',
            ],
            [
                'label' => 'Team Member',
                'value' => 'team_member',
                'visibility' => 'true',
            ],
            [
                'label' => 'Testimonial',
                'value' => 'testimonial',
                'visibility' => 'true',
            ],
            [
                'label' => 'Progress Bar',
                'value' => 'progress_bar',
                'visibility' => 'true',
            ],
            [
                'label' => 'Interactive Promo',
                'value' => 'interactive_promo',
                'visibility' => 'true',
            ],
            [
                'label' => 'Image Comparison',
                'value' => 'image_comparison',
                'visibility' => 'true',
            ],
            [
                'label' => 'Wrapper',
                'value' => 'wrapper',
                'visibility' => 'true',
            ],
        ];

        $pro_blocks = apply_filters( 'essential_pro_blocks', []);

        $merged_blocks = array_merge( $default_blocks, $pro_blocks );

        update_option( 'essential_all_blocks', $merged_blocks );
    }

    public function eb_save_blocks() {
        if (!wp_verify_nonce($_POST['_wpnonce'], 'eb-save-admin-options')) {
            die('Security check');
        } else {
            update_option('essential_all_blocks', $_POST['all_blocks']);
        }
        die();
    }

    public function get_blocks() {
        $all_blocks = get_option('essential_all_blocks');
        return $all_blocks;
    }

    public function disabling_nonce() {
        return wp_create_nonce('essential_disabling_nonce');
    }
}
