/**
 * WordPress dependencies
 */
const { __ } = wp.i18n;
const { InspectorControls, PanelColorSettings, MediaUpload } = wp.editor;
const {
	PanelBody,
	BaseControl,
	ButtonGroup,
	Button,
	ToggleControl,
	TextControl,
	SelectControl,
	RangeControl,
	IconButton
} = wp.components;

/**
 * Internal dependencies
 */
import {
	ACCORDION_TYPES,
	BACKGROUND_TYPE,
	TITLE_BACKGROUND_TYPE,
	BACKGROUND_SIZE,
	BACKGROUND_CLIP,
	BACKGROUND_REPEAT,
	BACKGROUND_ATTACHMENT,
	BORDER_STYLES,
	HEADERS,
	ICON_POSITIONS,
	TRANSITION_TYPES,
	TITLE_ALIGNMENT,
	CONTENT_ALIGN,
	COLOR_TYPES
} from "./constants";
import FontIconPicker from "@fonticonpicker/react-fonticonpicker";
import iconList from "../../../util/faIcons";
import SortableAccordions from "./sortable-accordion";
import GradientColorControl from "../../../util/gradient-color-controller";
import ImageAvatar from "../../../util/image-avatar/ImageAvater";
import DimentionsControl from "../../../util/dimentions-control";
// import { material, dark, gradient, royal, custom } from "./demo-styles";
import UnitControl from "../../../util/unit-control";

const Inspector = props => {
	const { attributes, setAttributes, onDeleteAccordion, onSortEnd } = props;
	const {
		accordionType,
		displayIcon,
		transitionDuration,
		accordionStyle,
		backgroundType,
		containerBorderSize,
		containerBorderType,
		containerBorderColor,
		containerGradient,
		containerMarginTop,
		containerMarginRight,
		containerMarginBottom,
		containerMarginLeft,
		containerPaddingTop,
		containerPaddingRight,
		containerPaddingBottom,
		containerPaddingLeft,
		accordions,
		tabIcon,
		expandedIcon,
		containerBackground,
		containerHOffset,
		containerVOffset,
		containerShadowBlur,
		containerShadowSpread,
		containerShadowColor,
		titleLevel,
		titleColor,
		titleBackgroundType,
		titleBackgroundColor,
		titleBackgroundGradient,
		tabBorderStyle,
		tabBorderColor,
		tabBorderRadius,
		contentAlign,
		contentColor,
		contentFontSize,
		contentMarginTop,
		contentMarginRight,
		contentMarginBottom,
		contentMarginLeft,
		contentPaddingTop,
		contentPaddingRight,
		contentPaddingBottom,
		contentPaddingLeft,
		contentBackgroundType,
		contentBackgroundColor,
		contentGradient,
		contentBorderColor,
		contentHOffset,
		contentVOffset,
		contentShadowColor,
		contentShadowBlur,
		contentShadowSpread,
		iconColor,
		iconSize,
		iconMarginTop,
		iconMarginRight,
		iconMarginBottom,
		iconMarginLeft,
		iconPaddingTop,
		iconPaddingRight,
		iconPaddingBottom,
		iconPaddingLeft,
		iconBackgroundType,
		iconBackgroundColor,
		iconGradient,
		iconBorderRadius,
		iconPosition,
		iconHOffset,
		iconVOffset,
		iconShadowBlur,
		iconShadowSpread,
		iconShadowColor,
		transitionFunction,
		tabHOffset,
		tabVOffset,
		tabShadowBlur,
		tabShadowSpread,
		tabShadowColor,
		titleAlignment,
		tabBorderColorType,
		tabBorderGradient,
		tabBorderImageSlice,
		tabBorderWidth,
		hoverColor,
		activeColor,
		containerImageID,
		containerImageURL,
		containerBackgroundSize,
		containerBackgroundClip,
		containerBackgroundRepeat,
		containerBackgroundPositionX,
		containerBackgroundPositionY,
		containerBackgoundAttachment,
		tabMarginTop,
		tabMarginRight,
		tabMarginBottom,
		tabMarginLeft,
		tabPaddingTop,
		tabPaddingRight,
		tabPaddingBottom,
		tabPaddingLeft,
		contentBorderTop,
		contentBorderRight,
		contentBorderBottom,
		contentBorderLeft,
		containerBorderRadius,
		containerMarginUnit,
		containerPaddingUnit,
		containerBorderUnit,
		containerRadiusUnit,
		tabMarginUnit,
		tabPaddingUnit,
		tabBorderUnit,
		tabRadiusUnit,
		contentMarginUnit,
		contentPaddingUnit,
		iconSizeUnit,
		iconMarginUnit,
		iconPaddingUnit,
		contentSizeUnit
	} = attributes;

	return (
		<InspectorControls keys="controls">
			<PanelBody>
				<BaseControl label={__("Accordion Types")} id="eb-accordion-type">
					<ButtonGroup id="eb-accordion-type">
						{ACCORDION_TYPES.map(item => (
							<Button
								isLarge
								isDefault={accordionType !== item.value}
								isPrimary={accordionType === item.value}
								onClick={() => setAttributes({ accordionType: item.value })}
							>
								{item.label}
							</Button>
						))}
					</ButtonGroup>
				</BaseControl>

				<BaseControl id="eb-accordion-sortable" label={__("Accordion List")}>
					<SortableAccordions
						accordions={accordions}
						onDeleteAccordion={onDeleteAccordion}
						onSortEnd={onSortEnd}
					/>
				</BaseControl>

				<TextControl
					label={__("Toggle Speed")}
					type="number"
					value={transitionDuration || 500}
					onChange={newValue =>
						setAttributes({ transitionDuration: parseInt(newValue, 10) })
					}
				/>

				<SelectControl
					label={__("Transition Function")}
					value={transitionFunction}
					options={TRANSITION_TYPES}
					onChange={newValue => setAttributes({ transitionFunction: newValue })}
				/>

				<ToggleControl
					label={__("Display Icon")}
					checked={displayIcon}
					onChange={() => setAttributes({ displayIcon: !displayIcon })}
				/>

				{displayIcon && (
					<PanelBody title={__("Icon Settings")} initialOpen={false}>
						<BaseControl label={__("Tab Icon")}>
							<FontIconPicker
								icons={iconList}
								value={tabIcon}
								onChange={tabIcon => setAttributes({ tabIcon })}
								appendTo="body"
							/>
						</BaseControl>

						<BaseControl label={__("Expanded Icon")}>
							<FontIconPicker
								icons={iconList}
								value={expandedIcon}
								onChange={expandedIcon => setAttributes({ expandedIcon })}
								appendTo="body"
							/>
						</BaseControl>
					</PanelBody>
				)}
			</PanelBody>

			<PanelBody title={__("General")} initialOpen={false}>
				<BaseControl
					label={__("Background Type")}
					id="eb-accordion-background-type"
				>
					<ButtonGroup id="eb-accordion-background-type">
						{BACKGROUND_TYPE.map(item => (
							<Button
								isLarge
								isDefault={backgroundType !== item.value}
								isPrimary={backgroundType === item.value}
								onClick={() => setAttributes({ backgroundType: item.value })}
							>
								{item.label}
							</Button>
						))}
					</ButtonGroup>
				</BaseControl>

				{backgroundType === "fill" && (
					<PanelColorSettings
						title={__("Container Background")}
						initialOpen={false}
						colorSettings={[
							{
								value: containerBackground,
								onChange: newColor =>
									setAttributes({ containerBackground: newColor }),
								label: __("Container Background")
							}
						]}
					/>
				)}

				{backgroundType === "gradient" && (
					<PanelBody title={__("Gradient Colors")} initialOpen={false}>
						<GradientColorControl
							onChange={newValue =>
								setAttributes({ containerGradient: newValue })
							}
						/>

						<RangeControl
							label={__("Border Image Slice")}
							value={tabBorderImageSlice}
							onChange={newValue =>
								setAttributes({ tabBorderImageSlice: newValue })
							}
							min={0}
							max={50}
						/>
					</PanelBody>
				)}

				{backgroundType === "image" && (
					<PanelBody title={__("Image Settings")}>
						<MediaUpload
							onSelect={media =>
								setAttributes({
									containerImageURL: media.url,
									containerImageID: media.id
								})
							}
							allowedTypes={["image"]}
							value={containerImageID}
							render={({ open }) =>
								!containerImageURL && (
									<IconButton
										className="eb-accordion-upload-button"
										label={__("Upload Image")}
										icon="format-image"
										onClick={open}
									/>
								)
							}
						/>
					</PanelBody>
				)}

				{containerImageURL && (
					<BaseControl
						label={__("Background Image")}
						id="eb-accordion-bg-image"
					>
						<ImageAvatar
							imageUrl={containerImageURL}
							onDeleteImage={() => setAttributes({ containerImageURL: null })}
						/>
					</BaseControl>
				)}

				{backgroundType === "image" && containerImageURL && (
					<SelectControl
						label={__("Background Size")}
						value={containerBackgroundSize}
						options={BACKGROUND_SIZE}
						onChange={newSize =>
							setAttributes({ containerBackgroundSize: newSize })
						}
					/>
				)}

				{backgroundType === "image" && containerImageURL && (
					<SelectControl
						label={__("Background Clip")}
						value={containerBackgroundClip}
						options={BACKGROUND_CLIP}
						onChange={newValue =>
							setAttributes({ containerBackgroundClip: newValue })
						}
					/>
				)}

				{backgroundType === "image" && containerImageURL && (
					<SelectControl
						label={__("Background Repeat")}
						value={containerBackgroundRepeat}
						options={BACKGROUND_REPEAT}
						onChange={newValue =>
							setAttributes({ containerBackgroundRepeat: newValue })
						}
					/>
				)}

				{backgroundType === "image" && containerImageURL && (
					<RangeControl
						label={__("Background Position X")}
						value={containerBackgroundPositionX}
						onChange={newValue =>
							setAttributes({ containerBackgroundPositionX: newValue })
						}
						min={0}
						max={100}
					/>
				)}

				{backgroundType === "image" && containerImageURL && (
					<RangeControl
						label={__("Background Position Y")}
						value={containerBackgroundPositionY}
						onChange={newValue =>
							setAttributes({ containerBackgroundPositionY: newValue })
						}
						min={0}
						max={100}
					/>
				)}

				{backgroundType === "image" && containerImageURL && (
					<SelectControl
						label={__("Background Attachment")}
						value={containerBackgoundAttachment}
						options={BACKGROUND_ATTACHMENT}
						onChange={newValue =>
							setAttributes({ containerBackgoundAttachment: newValue })
						}
					/>
				)}

				<PanelBody title={__("Container Margin & Padding")} initialOpen={false}>
					<UnitControl
						selectedUnit={containerMarginUnit}
						unitTypes={[
							{ label: "px", value: "px" },
							{ label: "em", value: "em" },
							{ label: "%", value: "%" }
						]}
						onClick={containerMarginUnit =>
							setAttributes({ containerMarginUnit })
						}
					/>

					<DimentionsControl
						label={__("Margin")}
						top={containerMarginTop}
						right={containerMarginRight}
						bottom={containerMarginBottom}
						left={containerMarginLeft}
						onChange={({ top, right, bottom, left }) =>
							setAttributes({
								containerMarginTop: top,
								containerMarginRight: right,
								containerMarginBottom: bottom,
								containerMarginLeft: left
							})
						}
					/>

					<UnitControl
						selectedUnit={containerPaddingUnit}
						unitTypes={[
							{ label: "px", value: "px" },
							{ label: "em", value: "em" },
							{ label: "%", value: "%" }
						]}
						onClick={containerPaddingUnit =>
							setAttributes({ containerPaddingUnit })
						}
					/>

					<DimentionsControl
						label={__("Padding")}
						top={containerPaddingTop}
						right={containerPaddingRight}
						bottom={containerPaddingBottom}
						left={containerPaddingLeft}
						onChange={({ top, right, bottom, left }) =>
							setAttributes({
								containerPaddingTop: top,
								containerPaddingRight: right,
								containerPaddingBottom: bottom,
								containerPaddingLeft: left
							})
						}
					/>
				</PanelBody>
				<PanelBody title={__("Container Border")} initialOpen={false}>
					<SelectControl
						label={__("Border Type")}
						value={containerBorderType}
						options={BORDER_STYLES}
						onChange={newValue =>
							setAttributes({ containerBorderType: newValue })
						}
					/>
					<PanelColorSettings
						title={__("Border Color")}
						colorSettings={[
							{
								value: containerBorderColor,
								onChange: newColor =>
									setAttributes({ containerBorderColor: newColor }),
								label: __("Border Color")
							}
						]}
					/>

					<UnitControl
						selectedUnit={containerBorderUnit}
						unitTypes={[
							{ label: "px", value: "px" },
							{ label: "em", value: "em" }
						]}
						onClick={containerBorderUnit =>
							setAttributes({ containerBorderUnit })
						}
					/>

					<RangeControl
						label={__("Border Size")}
						value={containerBorderSize}
						onChange={newValue =>
							setAttributes({ containerBorderSize: newValue })
						}
						min={0}
						max={10}
					/>

					<UnitControl
						selectedUnit={containerRadiusUnit}
						unitTypes={[
							{ label: "px", value: "px" },
							{ label: "em", value: "em" },
							{ label: "%", value: "%" }
						]}
						onClick={containerRadiusUnit =>
							setAttributes({ containerRadiusUnit })
						}
					/>

					<RangeControl
						label={__("Border Radius")}
						value={containerBorderRadius}
						onChange={newValue =>
							setAttributes({ containerBorderRadius: newValue })
						}
						min={0}
						max={100}
					/>
				</PanelBody>

				<PanelBody title={__("Container Shadow")} initialOpen={false}>
					<PanelColorSettings
						title={__("Shadow Color")}
						colorSettings={[
							{
								value: containerShadowColor,
								onChange: newColor =>
									setAttributes({ containerShadowColor: newColor }),
								label: __("Shadow Color")
							}
						]}
					/>

					<RangeControl
						label={__("Horizontal Offset")}
						value={containerHOffset}
						allowReset
						onChange={newValue => setAttributes({ containerHOffset: newValue })}
						min={0}
						max={10}
					/>

					<RangeControl
						label={__("Vertical Offset")}
						allowReset
						value={containerVOffset}
						onChange={newValue => setAttributes({ containerVOffset: newValue })}
						min={0}
						max={10}
					/>

					<RangeControl
						label={__("Shadow Blur")}
						value={containerShadowBlur}
						allowReset
						onChange={newValue =>
							setAttributes({ containerShadowBlur: newValue })
						}
						min={0}
						max={10}
					/>

					<RangeControl
						label={__("Shadow Spread")}
						value={containerShadowSpread}
						allowReset
						onChange={newValue =>
							setAttributes({ containerShadowSpread: newValue })
						}
						min={0}
						max={10}
					/>
				</PanelBody>
			</PanelBody>

			<PanelBody title={__("Tab Style")} initialOpen={false}>
				<BaseControl label={__("Title Level")} id="eb-accoridon-title-level">
					<ButtonGroup>
						{HEADERS.map(header => (
							<Button
								isDefault={titleLevel !== header.value}
								isPrimary={titleLevel === header.value}
								onClick={() => setAttributes({ titleLevel: header.value })}
							>
								{header.label}
							</Button>
						))}
					</ButtonGroup>
				</BaseControl>

				<BaseControl label={__("Title Align ")} id="eb-accoridon-title-align">
					<ButtonGroup>
						{TITLE_ALIGNMENT.map(item => (
							<Button
								isDefault={titleAlignment !== item.value}
								isPrimary={titleAlignment === item.value}
								onClick={() => setAttributes({ titleAlignment: item.value })}
							>
								{item.label}
							</Button>
						))}
					</ButtonGroup>
				</BaseControl>

				<BaseControl
					label={__("Title Background Type")}
					id="eb-accordion-title-bg-type"
				>
					<ButtonGroup id="eb-accordion-title-bg-type">
						{TITLE_BACKGROUND_TYPE.map(item => (
							<Button
								isLarge
								isDefault={titleBackgroundType !== item.value}
								isPrimary={titleBackgroundType === item.value}
								onClick={() =>
									setAttributes({ titleBackgroundType: item.value })
								}
							>
								{item.label}
							</Button>
						))}
					</ButtonGroup>
				</BaseControl>

				{titleBackgroundType === "fill" && (
					<PanelColorSettings
						title={__("Title Background Color")}
						initialOpen={false}
						colorSettings={[
							{
								value: titleBackgroundColor,
								onChange: newColor =>
									setAttributes({ titleBackgroundColor: newColor }),
								label: __("Title Background Color")
							}
						]}
					/>
				)}

				{titleBackgroundType === "gradient" && (
					<PanelBody title={__("Gradient Colors")} initialOpen={false}>
						<GradientColorControl
							label={__("Title Background Gradient")}
							onChange={newGradient =>
								setAttributes({ titleBackgroundGradient: newGradient })
							}
						/>
					</PanelBody>
				)}

				<PanelColorSettings
					title={__("Title Color")}
					initialOpen={false}
					colorSettings={[
						{
							value: titleColor,
							onChange: newColor => setAttributes({ titleColor: newColor }),
							label: __("Title Color")
						}
					]}
				/>

				<PanelBody title={__("Tab Margin & Padding")} initialOpen={false}>
					<UnitControl
						selectedUnit={tabMarginUnit}
						unitTypes={[
							{ label: "px", value: "px" },
							{ label: "em", value: "em" },
							{ label: "%", value: "%" }
						]}
						onClick={tabMarginUnit => setAttributes({ tabMarginUnit })}
					/>

					<DimentionsControl
						label={__("Margin")}
						top={tabMarginTop}
						right={tabMarginRight}
						bottom={tabMarginBottom}
						left={tabMarginLeft}
						onChange={({ top, right, bottom, left }) =>
							setAttributes({
								tabMarginTop: top,
								tabMarginRight: right,
								tabMarginBottom: bottom,
								tabMarginLeft: left
							})
						}
					/>

					<UnitControl
						selectedUnit={tabPaddingUnit}
						unitTypes={[
							{ label: "px", value: "px" },
							{ label: "em", value: "em" },
							{ label: "%", value: "%" }
						]}
						onClick={tabPaddingUnit => setAttributes({ tabPaddingUnit })}
					/>

					<DimentionsControl
						label={__("Padding")}
						top={tabPaddingTop}
						right={tabPaddingRight}
						bottom={tabPaddingBottom}
						left={tabPaddingLeft}
						onChange={({ top, right, bottom, left }) =>
							setAttributes({
								tabPaddingTop: top,
								tabPaddingRight: right,
								tabPaddingBottom: bottom,
								tabPaddingLeft: left
							})
						}
					/>
				</PanelBody>

				<PanelBody title={__("Tab Border Settings")} initialOpen={false}>
					<BaseControl label={__("Tab Border Color Type")}>
						<ButtonGroup>
							{COLOR_TYPES.map(item => (
								<Button
									isDefault={tabBorderColorType !== item.value}
									isPrimary={tabBorderColorType === item.value}
									onClick={() =>
										setAttributes({ tabBorderColorType: item.value })
									}
								>
									{item.label}
								</Button>
							))}
						</ButtonGroup>
					</BaseControl>

					{tabBorderColorType === "fill" && (
						<PanelColorSettings
							title={__("Border Color")}
							colorSettings={[
								{
									value: tabBorderColor,
									onChange: newColor =>
										setAttributes({ tabBorderColor: newColor }),
									label: __("Border Color")
								}
							]}
						/>
					)}

					{tabBorderColorType === "gradient" && (
						<PanelBody title={__("Border Gradient")} initialOpen={false}>
							<GradientColorControl
								onChange={newValue =>
									setAttributes({ tabBorderGradient: newValue })
								}
							/>
							<RangeControl
								label={__("Tab Border Image Slice")}
								value={tabBorderImageSlice}
								onChange={newValue =>
									setAttributes({ tabBorderImageSlice: newValue })
								}
								min={0}
								max={50}
							/>
						</PanelBody>
					)}

					{tabBorderColorType === "fill" && (
						<SelectControl
							label={__("Border Style")}
							value={tabBorderStyle}
							options={BORDER_STYLES}
							onChange={newStyle => setAttributes({ tabBorderStyle: newStyle })}
						/>
					)}

					<UnitControl
						selectedUnit={tabBorderUnit}
						unitTypes={[
							{ label: "px", value: "px" },
							{ label: "em", value: "em" }
						]}
						onClick={tabBorderUnit => setAttributes({ tabBorderUnit })}
					/>

					<RangeControl
						label={__("Tab Border Width")}
						value={tabBorderWidth}
						allowReset
						onChange={newValue => setAttributes({ tabBorderWidth: newValue })}
						min={0}
						max={100}
					/>

					<UnitControl
						selectedUnit={tabRadiusUnit}
						unitTypes={[
							{ label: "px", value: "px" },
							{ label: "em", value: "em" },
							{ label: "%", value: "%" }
						]}
						onClick={tabRadiusUnit => setAttributes({ tabRadiusUnit })}
					/>

					<RangeControl
						label={__("Tab Border Radius")}
						value={tabBorderRadius}
						allowReset
						onChange={newSize => setAttributes({ tabBorderRadius: newSize })}
						min={0}
						max={100}
					/>
				</PanelBody>

				<PanelBody title={__("Tab Shadow Settings")} initialOpen={false}>
					<PanelColorSettings
						title={__("Shadow Color")}
						colorSettings={[
							{
								value: tabShadowColor,
								onChange: newColor =>
									setAttributes({ tabShadowColor: newColor }),
								label: __("Shadow Color")
							}
						]}
					/>

					<RangeControl
						label={__("Horizontal Offset")}
						value={tabHOffset}
						allowReset
						onChange={newValue => setAttributes({ tabHOffset: newValue })}
						min={0}
						max={10}
					/>

					<RangeControl
						label={__("Vertical Offset")}
						value={tabVOffset}
						allowReset
						onChange={newValue => setAttributes({ tabVOffset: newValue })}
						min={0}
						max={10}
					/>

					<RangeControl
						label={__("Shadow Blur")}
						value={tabShadowBlur}
						allowReset
						onChange={newValue => setAttributes({ tabShadowBlur: newValue })}
						min={0}
						max={10}
					/>

					<RangeControl
						label={__("Shadow Spread")}
						value={tabShadowSpread}
						allowReset
						onChange={newValue => setAttributes({ tabShadowSpread: newValue })}
						min={0}
						max={10}
					/>
				</PanelBody>

				<PanelColorSettings
					title={__("Active Color")}
					initialOpen={false}
					colorSettings={[
						{
							value: activeColor,
							onChange: newColor => setAttributes({ activeColor: newColor }),
							label: __("Active Color")
						}
					]}
				/>

				<PanelColorSettings
					title={__("Hover Color")}
					initialOpen={false}
					colorSettings={[
						{
							value: hoverColor,
							onChange: newColor => setAttributes({ hoverColor: newColor }),
							label: __("Hover Color")
						}
					]}
				/>
			</PanelBody>

			<PanelBody title={__("Content Style")} initialOpen={false}>
				<BaseControl label={__("Align")}>
					<ButtonGroup>
						{CONTENT_ALIGN.map(item => (
							<Button
								isLarge
								isDefault={contentAlign !== item.value}
								isPrimary={contentAlign === item.value}
								onClick={() => setAttributes({ contentAlign: item.value })}
							>
								{item.label}
							</Button>
						))}
					</ButtonGroup>
				</BaseControl>

				<UnitControl
					selectedUnit={contentSizeUnit}
					unitTypes={[
						{ label: "px", value: "px" },
						{ label: "em", value: "em" },
						{ label: "%", value: "%" }
					]}
					onClick={contentSizeUnit => setAttributes({ contentSizeUnit })}
				/>

				<RangeControl
					label={__("Font Size")}
					value={contentFontSize}
					allowReset
					onChange={newSize => setAttributes({ contentFontSize: newSize })}
					min={8}
					max={100}
				/>

				<BaseControl label={__("Background Type")}>
					<ButtonGroup>
						{TITLE_BACKGROUND_TYPE.map(item => (
							<Button
								isLarge
								isDefault={contentBackgroundType !== item.value}
								isPrimary={contentBackgroundType === item.value}
								onClick={() =>
									setAttributes({ contentBackgroundType: item.value })
								}
							>
								{item.label}
							</Button>
						))}
					</ButtonGroup>
				</BaseControl>

				{contentBackgroundType === "fill" && (
					<PanelColorSettings
						title={__("Background Color")}
						initialOpen={false}
						colorSettings={[
							{
								value: contentBackgroundColor,
								onChange: newColor =>
									setAttributes({ contentBackgroundColor: newColor }),
								label: __("Background Color")
							}
						]}
					/>
				)}

				{contentBackgroundType === "gradient" && (
					<PanelBody title={__("Gradient Colors")} initialOpen={false}>
						<GradientColorControl
							onChange={newValue =>
								setAttributes({ contentGradient: newValue })
							}
						/>
					</PanelBody>
				)}

				<PanelColorSettings
					title={__("Content Text Color")}
					initialOpen={false}
					colorSettings={[
						{
							value: contentColor,
							onChange: newColor => setAttributes({ contentColor: newColor }),
							label: __("Content Color")
						}
					]}
				/>

				<PanelBody title={__("Content Margin & Padding")} initialOpen={false}>
					<UnitControl
						selectedUnit={contentMarginUnit}
						unitTypes={[
							{ label: "px", value: "px" },
							{ label: "em", value: "em" },
							{ label: "%", value: "%" }
						]}
						onClick={contentMarginUnit => setAttributes({ contentMarginUnit })}
					/>

					<DimentionsControl
						label={__("Margin")}
						top={contentMarginTop}
						right={contentMarginRight}
						bottom={contentMarginBottom}
						left={contentMarginLeft}
						onChange={({ top, right, bottom, left }) =>
							setAttributes({
								contentMarginTop: top,
								contentMarginRight: right,
								contentMarginBottom: bottom,
								contentMarginLeft: left
							})
						}
					/>

					<UnitControl
						selectedUnit={contentPaddingUnit}
						unitTypes={[
							{ label: "px", value: "px" },
							{ label: "em", value: "em" },
							{ label: "%", value: "%" }
						]}
						onClick={contentPaddingUnit =>
							setAttributes({ contentPaddingUnit })
						}
					/>

					<DimentionsControl
						label={__("Padding")}
						top={contentPaddingTop}
						right={contentPaddingRight}
						bottom={contentPaddingBottom}
						left={contentPaddingLeft}
						onChange={({ top, right, bottom, left }) =>
							setAttributes({
								contentPaddingTop: top,
								contentPaddingRight: right,
								contentPaddingBottom: bottom,
								contentPaddingLeft: left
							})
						}
					/>
				</PanelBody>

				<PanelBody title={__("Content Border")} initialOpen={false}>
					<PanelColorSettings
						title={__("Border Color")}
						colorSettings={[
							{
								value: contentBorderColor,
								onChange: newColor =>
									setAttributes({ contentBorderColor: newColor }),
								label: __("Border Color")
							}
						]}
					/>

					<DimentionsControl
						label={__("Border Width")}
						top={contentBorderTop}
						right={contentBorderRight}
						bottom={contentBorderBottom}
						left={contentBorderLeft}
						onChange={({ top, right, bottom, left }) =>
							setAttributes({
								contentBorderTop: top,
								contentBorderRight: right,
								contentBorderBottom: bottom,
								contentBorderLeft: left
							})
						}
					/>
				</PanelBody>

				<PanelBody title={__("Content Shadow")} initialOpen={false}>
					<PanelColorSettings
						title={__("Shadow Color")}
						colorSettings={[
							{
								value: contentShadowColor,
								onChange: newColor =>
									setAttributes({ contentShadowColor: newColor }),
								label: __("Sahdow Color")
							}
						]}
					/>

					<RangeControl
						label={__("Horizontal Offset")}
						value={contentHOffset}
						allowReset
						onChange={newValue => setAttributes({ contentHOffset: newValue })}
						min={0}
						max={10}
					/>

					<RangeControl
						label={__("Vertical Offset")}
						value={contentVOffset}
						allowReset
						onChange={newValue => setAttributes({ contentVOffset: newValue })}
						min={0}
						max={10}
					/>

					<RangeControl
						label={__("Shadow Blur")}
						value={contentShadowBlur}
						allowReset
						onChange={newValue =>
							setAttributes({ contentShadowBlur: newValue })
						}
						min={0}
						max={10}
					/>

					<RangeControl
						label={__("Shadow Spread")}
						value={contentShadowSpread}
						allowReset
						onChange={newValue =>
							setAttributes({ contentShadowSpread: newValue })
						}
						min={0}
						max={10}
					/>
				</PanelBody>
			</PanelBody>

			{displayIcon && (
				<PanelBody title={__("Icon Style")} initialOpen={false}>
					<BaseControl label={__("Icon Position")}>
						<ButtonGroup>
							{ICON_POSITIONS.map(item => (
								<Button
									isLarge
									isDefault={iconPosition !== item.value}
									isPrimary={iconPosition === item.value}
									onClick={() => setAttributes({ iconPosition: item.value })}
								>
									{item.label}
								</Button>
							))}
						</ButtonGroup>
					</BaseControl>

					<UnitControl
						selectedUnit={iconSizeUnit}
						unitTypes={[
							{ label: "px", value: "px" },
							{ label: "em", value: "em" },
							{ label: "%", value: "%" }
						]}
						onClick={iconSizeUnit => setAttributes({ iconSizeUnit })}
					/>

					<RangeControl
						label={__("Icon Size")}
						value={iconSize}
						allowReset
						onChange={newSize => setAttributes({ iconSize: newSize })}
						min={0}
						max={100}
					/>

					<BaseControl label={__("Icon Background Type")}>
						<ButtonGroup>
							{TITLE_BACKGROUND_TYPE.map(item => (
								<Button
									isLarge
									isDefault={iconBackgroundType !== item.value}
									isPrimary={iconBackgroundType === item.value}
									onClick={() =>
										setAttributes({ iconBackgroundType: item.value })
									}
								>
									{item.label}
								</Button>
							))}
						</ButtonGroup>
					</BaseControl>

					{iconBackgroundType === "fill" && (
						<PanelColorSettings
							title={__("Icon Background Color")}
							initialOpen={false}
							colorSettings={[
								{
									value: iconBackgroundColor,
									onChange: newColor =>
										setAttributes({ iconBackgroundColor: newColor }),
									label: __("Icon Background Color")
								}
							]}
						/>
					)}

					{iconBackgroundType === "gradient" && (
						<PanelBody title={__("Icon Gradient Colors")} initialOpen={false}>
							<GradientColorControl
								label={__("Icon Background Gradient")}
								onChange={newGradient =>
									setAttributes({ iconGradient: newGradient })
								}
							/>
						</PanelBody>
					)}

					<PanelColorSettings
						title={__("Icon Color")}
						initialOpen={false}
						colorSettings={[
							{
								value: iconColor,
								onChange: newColor => setAttributes({ iconColor: newColor }),
								label: __("Icon Color")
							}
						]}
					/>

					<PanelBody title={__("Icon Margin & Padding")} initialOpen={false}>
						<UnitControl
							selectedUnit={iconMarginUnit}
							unitTypes={[
								{ label: "px", value: "px" },
								{ label: "em", value: "em" },
								{ label: "%", value: "%" }
							]}
							onClick={iconMarginUnit => setAttributes({ iconMarginUnit })}
						/>

						<DimentionsControl
							label={__("Margin")}
							top={iconMarginTop}
							right={iconMarginRight}
							bottom={iconMarginBottom}
							left={iconMarginLeft}
							onChange={({ top, right, bottom, left }) =>
								setAttributes({
									iconMarginTop: top,
									iconMarginRight: right,
									iconMarginBottom: bottom,
									iconMarginLeft: left
								})
							}
						/>

						<UnitControl
							selectedUnit={iconPaddingUnit}
							unitTypes={[
								{ label: "px", value: "px" },
								{ label: "em", value: "em" },
								{ label: "%", value: "%" }
							]}
							onClick={iconPaddingUnit => setAttributes({ iconPaddingUnit })}
						/>

						<DimentionsControl
							label={__("Padding")}
							top={iconPaddingTop}
							right={iconPaddingRight}
							bottom={iconPaddingBottom}
							left={iconPaddingLeft}
							onChange={({ top, right, bottom, left }) =>
								setAttributes({
									iconPaddingTop: top,
									iconPaddingRight: right,
									iconPaddingBottom: bottom,
									iconPaddingLeft: left
								})
							}
						/>
					</PanelBody>

					<PanelBody title={__("Icon Background Radius")} initialOpen={false}>
						<RangeControl
							label={__("Icon Background Radius")}
							value={iconBorderRadius}
							allowReset
							onChange={newValue =>
								setAttributes({ iconBorderRadius: newValue })
							}
							min={0}
							max={50}
						/>
					</PanelBody>

					<PanelBody title={__("Icon Shadow")} initialOpen={false}>
						<PanelColorSettings
							title={__("Shadow Color")}
							colorSettings={[
								{
									value: iconShadowColor,
									onChange: newColor =>
										setAttributes({ iconShadowColor: newColor }),
									label: __("Border Color")
								}
							]}
						/>

						<RangeControl
							label={__("Horizontal Offset")}
							value={iconHOffset}
							allowReset
							onChange={newValue => setAttributes({ iconHOffset: newValue })}
							min={0}
							max={10}
						/>

						<RangeControl
							label={__("Vertical Offset")}
							value={iconVOffset}
							allowReset
							onChange={newValue => setAttributes({ iconVOffset: newValue })}
							min={0}
							max={10}
						/>

						<RangeControl
							label={__("Shadow Blur")}
							value={iconShadowBlur}
							allowReset
							onChange={newValue => setAttributes({ iconShadowBlur: newValue })}
							min={0}
							max={10}
						/>

						<RangeControl
							label={__("Shadow Spread")}
							value={iconShadowSpread}
							allowReset
							onChange={newValue =>
								setAttributes({ iconShadowSpread: newValue })
							}
							min={0}
							max={10}
						/>
					</PanelBody>
				</PanelBody>
			)}
		</InspectorControls>
	);
};

export default Inspector;
