/**
 * Import WordPress dependencies
 */
const { __ } = wp.i18n;
const { Dashicon } = wp.components;

const { BlockControls, BlockAlignmentToolbar, RichText, URLInput } = wp.editor;

/**
 * Internal dependencies
 */
import Inspector from "./inspector";

const edit = props => {
  const { attributes, isSelected, setAttributes } = props;
  const {
    marginTop,
    marginRight,
    marginBottom,
    marginLeft,
    paddingTop,
    paddingRight,
    paddingBottom,
    paddingLeft,
    buttonText,
    textSize,
    borderRadiusTopLeft,
    borderRadiusTopRight,
    borderRadiusBottomRight,
    borderRadiusBottomLeft,
    borderWidth,
    borderColor,
    borderStyle,
    buttonHOffset,
    buttonVOffset,
    buttonShadowBlur,
    buttonShadowSpread,
    buttonShadowColor,
    textColor,
    textHOffset,
    textVOffset,
    textShadowBlur,
    textShadowColor,
    buttonColor,
    buttonURL,
    buttonAlign,
    isHover,
    hoverButtonColor,
    hoverTextColor,
    marginUnit,
    paddingUnit,
    buttonSizeUnit,
    borderRadiusUnit
  } = attributes;

  // Style objects
  const buttonWrapperStyles = {
    display: "flex",
    flexDirection: "column",
    alignItems: buttonAlign
  };

  const buttonStyles = {
    margin: `${marginTop || 0}${marginUnit} ${marginRight ||
      0}${marginUnit} ${marginBottom || 0}${marginUnit} ${marginLeft ||
      0}${marginUnit}`,
    padding: `${paddingTop || 0}${paddingUnit} ${paddingRight ||
      0}${paddingUnit} ${paddingBottom || 0}${paddingUnit} ${paddingLeft ||
      0}${paddingUnit}`,
    borderRadius: `${borderRadiusTopLeft ||
      0}${borderRadiusUnit}  ${borderRadiusTopRight ||
      0}${borderRadiusUnit} ${borderRadiusBottomRight ||
      0}${borderRadiusUnit} ${borderRadiusBottomLeft || 0}${borderRadiusUnit}`,
    background:
      isHover && hoverButtonColor ? hoverButtonColor : buttonColor || "#0f94f6",
    display: "inline-block",
    borderWidth: `${borderWidth || 0}px`,
    borderStyle: borderStyle,
    borderColor: borderColor,
    boxShadow: `${buttonHOffset || 0}px ${buttonVOffset ||
      0}px ${buttonShadowBlur || 0}px ${buttonShadowSpread ||
      0}px ${buttonShadowColor || "#767676"}`,
    fontSize: `${textSize || 20}${buttonSizeUnit}`,
    textAlign: "center",
    cursor: "pointer"
  };

  const textStyles = {
    color: isHover && hoverTextColor ? hoverTextColor : textColor || "#ffffff",
    textShadow: `${textHOffset || 0}px ${textVOffset || 0}px ${textShadowBlur ||
      0}px ${textShadowColor || "#767676"}`
  };

  const setButtonAlign = newAlign => {
    switch (newAlign) {
      case "left":
        setAttributes({ buttonAlign: "flex-start" });
        break;

      case "center":
        setAttributes({ buttonAlign: "center" });
        break;

      case "right":
        setAttributes({ buttonAlign: "flex-end" });
        break;
    }
  };

  return [
    isSelected && <Inspector {...props} />,
    <div className="eb-button-wrapper" style={buttonWrapperStyles}>
      <div
        className="eb-button"
        style={buttonStyles}
        onMouseEnter={() => setAttributes({ isHover: true })}
        onMouseLeave={() => setAttributes({ isHover: false })}
      >
        <BlockControls>
          <BlockAlignmentToolbar
            value={buttonAlign}
            onChange={newAlign => setButtonAlign(newAlign)}
            controls={["left", "center", "right"]}
          />
        </BlockControls>

        <RichText
          style={textStyles}
          placeholder="Add Text.."
          keepPlaceholderOnFocus
          className="eb-button-text"
          value={buttonText}
          onChange={newText => setAttributes({ buttonText: newText })}
          formattingControls={["bold", "italic", "strikethrough"]}
        />
      </div>

      {isSelected && (
        <div className="eb-button-link">
          <Dashicon icon="admin-links" />
          <URLInput
            value={buttonURL}
            onChange={newURL => setAttributes({ buttonURL: newURL })}
          />
        </div>
      )}
    </div>
  ];
};

export default edit;
