/**
 * WordPress dependencies
 */
const { __ } = wp.i18n;
const { Component } = wp.element;
const { PanelBody, SelectControl, RangeControl, ToggleControl } = wp.components;
const { InspectorControls, PanelColorSettings } = wp.editor;

/**
 * Internal depencencies
 */
import { BORDER_STYLES, BUTTON_STYLES } from "./constants";
import DimentionsControl from "../../../util/dimentions-control";
import UnitControl from "../../../util/unit-control";
//import { material, ghost, rounded } from "./demo-styles";

class Inspector extends Component {
  changeButtonStyles = style => {
    switch (style) {
      case "fill":
        this.props.setAttributes({
          buttonColor: "#2196f3",
          textColor: "white",
          hoverButtonColor: "#1976d2",
          hoverTextColor: "white",
          borderColor: "transparent",
          borderWidth: 0,
          borderStyle: "none"
        });
        break;
      case "outline":
        this.props.setAttributes({
          buttonColor: "white",
          textColor: "#e10050",
          hoverButtonColor: "#e10050",
          hoverTextColor: "white",
          borderColor: "#e10050",
          borderWidth: 2,
          borderStyle: "solid"
        });
        break;

      case "text":
        this.props.setAttributes({
          buttonColor: "white",
          textColor: "#4CAF50",
          hoverButtonColor: "#4CAF50",
          hoverTextColor: "white",
          borderColor: "transparent",
          borderWidth: 0,
          borderStyle: "none"
        });
        break;
    }
  };

  changeAllBorderRadius = newValue =>
    this.props.setAttributes({
      borderRadiusTopLeft: newValue,
      borderRadiusTopRight: newValue,
      borderRadiusBottomRight: newValue,
      borderRadiusBottomLeft: newValue
    });

  render() {
    const { attributes, setAttributes } = this.props;
    const {
      marginTop,
      marginRight,
      marginBottom,
      marginLeft,
      paddingTop,
      paddingRight,
      paddingBottom,
      paddingLeft,
      linkedBorderRadius,
      borderRadiusTopLeft,
      borderRadiusTopRight,
      borderRadiusBottomRight,
      borderRadiusBottomLeft,
      borderWidth,
      borderColor,
      borderStyle,
      buttonHOffset,
      buttonVOffset,
      buttonShadowBlur,
      buttonShadowSpread,
      buttonShadowColor,
      textSize,
      textColor,
      textHOffset,
      textVOffset,
      textShadowBlur,
      textShadowColor,
      buttonColor,
      buttonStyle,
      hoverButtonColor,
      hoverTextColor,
      marginUnit,
      paddingUnit,
      buttonSizeUnit,
      borderRadiusUnit
    } = attributes;

    return (
      <InspectorControls key="controls">
        <PanelBody title={__("Button Styles")}>
          <SelectControl
            label={__("Button Styles")}
            value={buttonStyle}
            options={BUTTON_STYLES}
            onChange={buttonStyle => this.changeButtonStyles(buttonStyle)}
          />
        </PanelBody>

        <PanelBody title={__("Margin & Padding")} initialOpen={false}>
          <UnitControl
            selectedUnit={marginUnit}
            unitTypes={[
              { label: "px", value: "px" },
              { label: "em", value: "em" },
              { label: "%", value: "%" }
            ]}
            onClick={marginUnit => setAttributes({ marginUnit })}
          />

          <DimentionsControl
            label="Margin"
            top={marginTop}
            right={marginRight}
            bottom={marginBottom}
            left={marginLeft}
            onChange={({ top, right, bottom, left }) => {
              setAttributes({
                marginTop: top,
                marginRight: right,
                marginBottom: bottom,
                marginLeft: left
              });
            }}
          />

          <UnitControl
            selectedUnit={paddingUnit}
            unitTypes={[
              { label: "px", value: "px" },
              { label: "em", value: "em" },
              { label: "%", value: "%" }
            ]}
            onClick={paddingUnit => setAttributes({ paddingUnit })}
          />

          <DimentionsControl
            label="Padding"
            top={paddingTop}
            right={paddingRight}
            bottom={paddingBottom}
            left={paddingLeft}
            onChange={({ top, right, bottom, left }) => {
              setAttributes({
                paddingTop: top,
                paddingRight: right,
                paddingBottom: bottom,
                paddingLeft: left
              });
            }}
          />
        </PanelBody>

        <PanelBody title={__("Font Size")} initialOpen={false}>
          <UnitControl
            selectedUnit={buttonSizeUnit}
            unitTypes={[
              { label: "px", value: "px" },
              { label: "em", value: "em" },
              { label: "%", value: "%" }
            ]}
            onClick={buttonSizeUnit => setAttributes({ buttonSizeUnit })}
          />

          <RangeControl
            label={__("Text Size")}
            value={textSize}
            allowReset
            onChange={textSize => setAttributes({ textSize })}
            min={0}
            max={100}
          />
        </PanelBody>

        <PanelColorSettings
          title={__("Colors")}
          initialOpen={false}
          colorSettings={[
            {
              value: buttonColor,
              onChange: newColor => setAttributes({ buttonColor: newColor }),
              label: __("Button Color")
            },

            {
              value: textColor,
              onChange: newColor => setAttributes({ textColor: newColor }),
              label: __("Text Color")
            },
            {
              value: hoverButtonColor,
              onChange: newColor =>
                setAttributes({ hoverButtonColor: newColor }),
              label: __("Hover Button Color")
            },

            {
              value: hoverTextColor,
              onChange: newColor => setAttributes({ hoverTextColor: newColor }),
              label: __("Hover Text Color")
            }
          ]}
        />

        <PanelBody title={__("Border Radius")} initialOpen={false}>
          <UnitControl
            selectedUnit={borderRadiusUnit}
            unitTypes={[
              { label: "px", value: "px" },
              { label: "em", value: "em" },
              { label: "%", value: "%" }
            ]}
            onClick={borderRadiusUnit => setAttributes({ borderRadiusUnit })}
          />

          <DimentionsControl
            label={__("Border Radius")}
            top={borderRadiusTopLeft}
            right={borderRadiusTopRight}
            bottom={borderRadiusBottomRight}
            left={borderRadiusBottomLeft}
            onChange={({ top, right, bottom, left }) =>
              setAttributes({
                borderRadiusTopLeft: top,
                borderRadiusTopRight: right,
                borderRadiusBottomRight: bottom,
                borderRadiusBottomLeft: left
              })
            }
          />
        </PanelBody>

        <PanelBody title={__("Border Settings")} initialOpen={false}>
          <PanelColorSettings
            title={__("Border Color")}
            colorSettings={[
              {
                value: borderColor,
                onChange: newColor => setAttributes({ borderColor: newColor }),
                label: __("Border Color")
              }
            ]}
          />

          <SelectControl
            label={__("Border Style")}
            value={borderStyle}
            options={BORDER_STYLES}
            onChange={newStyle => setAttributes({ borderStyle: newStyle })}
          />

          <RangeControl
            label={__("Border Width")}
            value={borderWidth || 0}
            allowReset
            onChange={newValue => setAttributes({ borderWidth: newValue })}
            min={0}
            max={20}
          />
        </PanelBody>

        <PanelBody title={__("Button Shadow")} initialOpen={false}>
          <PanelColorSettings
            title={__("Shadow Color")}
            colorSettings={[
              {
                value: buttonShadowColor,
                onChange: newColor =>
                  setAttributes({ buttonShadowColor: newColor }),
                label: __("Shadow Color")
              }
            ]}
          />

          <RangeControl
            label={__("Horizontal Offset")}
            allowReset
            value={buttonHOffset || 0}
            onChange={newValue => setAttributes({ buttonHOffset: newValue })}
            min={0}
            max={20}
          />

          <RangeControl
            label={__("Vertical Offset")}
            value={buttonVOffset || 0}
            allowReset
            onChange={newValue => setAttributes({ buttonVOffset: newValue })}
            min={0}
            max={20}
          />

          <RangeControl
            label={__("Shadow Blur")}
            value={buttonShadowBlur || 0}
            allowReset
            onChange={newValue => setAttributes({ buttonShadowBlur: newValue })}
            min={0}
            max={20}
          />

          <RangeControl
            label={__("Shadow Spread")}
            value={buttonShadowSpread || 0}
            allowReset
            onChange={newValue =>
              setAttributes({ buttonShadowSpread: newValue })
            }
            min={0}
            max={20}
          />
        </PanelBody>

        <PanelBody title={__("Text Shadow")} initialOpen={false}>
          <PanelColorSettings
            title={__("Shadow Color")}
            colorSettings={[
              {
                value: textShadowColor,
                onChange: newColor =>
                  setAttributes({ textShadowColor: newColor }),
                label: __("Shadow Color")
              }
            ]}
          />

          <RangeControl
            label={__("Horizontal Offset")}
            value={textHOffset}
            allowReset
            onChange={newValue => setAttributes({ textHOffset: newValue })}
            min={0}
            max={20}
          />

          <RangeControl
            label={__("Vertical Offset")}
            value={textVOffset}
            allowReset
            onChange={newValue => setAttributes({ textVOffset: newValue })}
            min={0}
            max={20}
          />

          <RangeControl
            label={__("Shadow Blur")}
            value={textShadowBlur}
            allowReset
            onChange={newValue => setAttributes({ textShadowBlur: newValue })}
            min={0}
            max={20}
          />
        </PanelBody>
      </InspectorControls>
    );
  }
}

export default Inspector;
