const { RichText } = wp.editor;

const save = ({ attributes }) => {
  const {
    marginTop,
    marginRight,
    marginBottom,
    marginLeft,
    paddingTop,
    paddingRight,
    paddingBottom,
    paddingLeft,
    buttonText,
    borderRadiusTopLeft,
    borderRadiusTopRight,
    borderRadiusBottomRight,
    borderRadiusBottomLeft,
    borderWidth,
    borderColor,
    borderStyle,
    buttonHOffset,
    buttonVOffset,
    buttonShadowBlur,
    buttonShadowSpread,
    buttonShadowColor,
    textSize,
    textColor,
    textHOffset,
    textVOffset,
    textShadowBlur,
    textShadowColor,
    buttonColor,
    buttonURL,
    buttonAlign,
    hoverButtonColor,
    hoverTextColor,
    marginUnit,
    paddingUnit,
    buttonSizeUnit,
    borderRadiusUnit
  } = attributes;

  // Style objects
  const wrapperStyles = {
    display: "flex",
    flexDirection: "column",
    alignItems: buttonAlign
  };

  const buttonStyles = {
    margin: `${marginTop || 0}${marginUnit} ${marginRight ||
      0}${marginUnit} ${marginBottom || 0}${marginUnit} ${marginLeft ||
      0}${marginUnit}`,
    padding: `${paddingTop || 0}${paddingUnit} ${paddingRight ||
      0}${paddingUnit} ${paddingBottom || 0}${paddingUnit} ${paddingLeft ||
      0}${paddingUnit}`,
    borderRadius: `${borderRadiusTopLeft ||
      0}${borderRadiusUnit}  ${borderRadiusTopRight ||
      0}${borderRadiusUnit} ${borderRadiusBottomRight ||
      0}${borderRadiusUnit} ${borderRadiusBottomLeft || 0}${borderRadiusUnit}`,
    background: buttonColor || "#0f94f6",
    display: "inline-block",
    borderWidth: `${borderWidth || 0}px`,
    borderStyle: borderStyle,
    borderColor: borderColor,
    boxShadow: `${buttonHOffset || 0}px ${buttonVOffset ||
      0}px ${buttonShadowBlur || 0}px ${buttonShadowSpread ||
      0}px ${buttonShadowColor || "#767676"}`,
    fontSize: `${textSize || 20}${buttonSizeUnit}`,
    color: textColor || "#ffffff",
    textShadow: `${textHOffset || 0}px ${textVOffset || 0}px ${textShadowBlur ||
      0}px ${textShadowColor || "#767676"}`,
    cursor: "pointer"
  };

  const linkStyles = {
    textDecoration: "none"
  };

  return (
    <div
      className="eb-button-wrapper"
      style={wrapperStyles}
      data-button-color={buttonColor || "#0f94f6"}
      data-text-color={textColor || "#ffffff"}
      data-hover-color={hoverButtonColor || buttonColor || "#0f94f6"}
      data-hover-text-color={hoverTextColor || buttonColor || "#ffffff"}
    >
      <a className="eb-button-link" href={buttonURL} style={linkStyles}>
        <div className="eb-button" style={buttonStyles}>
          <RichText.Content className="eb-button-text" value={buttonText} />
        </div>
      </a>
    </div>
  );
};

export default save;
