/**
 * WordPress dependencies
 */
const { __ } = wp.i18n;
const { BlockControls, AlignmentToolbar, RichText, URLInput } = wp.editor;

/**
 * Internal dependencies
 */
import Inspector from "./inspector";

const edit = props => {
	const { isSelected, attributes, setAttributes } = props;
	const {
		marginTop,
		marginRight,
		marginBottom,
		marginLeft,
		paddingTop,
		paddingRight,
		paddingBottom,
		paddingLeft,
		contentStyle,
		contentAlign,
		backgroundType,
		backgroundColor,
		backgroundGradient,
		backgroundImageURL,
		icon,
		iconSize,
		iconColor,
		title,
		titleTag,
		titleFontSize,
		titleColor,
		description,
		descriptionFontSize,
		descriptionColor,
		buttonText,
		buttonURL,
		buttonTextSize,
		buttonBackgroundColor,
		buttonTextColor,
		buttonPaddingTop,
		buttonPaddingRight,
		buttonPaddingBottom,
		buttonPaddingLeft,
		buttonBorderRadius,
		shadowColor,
		hOffset,
		vOffset,
		blur,
		spread,
		paddingUnit,
		marginUnit,
		titleSizeUnit,
		descriptionSizeUnit,
		buttonSizeUnit,
		buttonRadiusUnit,
		iconSizeUnit
	} = attributes;

	const wrapperStyles = {
		margin: `${marginTop || 0}${marginUnit} ${marginRight ||
			0}${marginUnit} ${marginBottom || 0}${marginUnit} ${marginLeft ||
			0}${marginUnit}`,
		padding: `${paddingTop || 10}${paddingUnit} ${paddingRight ||
			30}${paddingUnit} ${paddingBottom || 10}${paddingUnit} ${paddingLeft ||
			30}${paddingUnit}`,
		backgroundColor:
			backgroundType === "color" && backgroundColor
				? backgroundColor
				: "#1e203e",
		backgroundImage:
			backgroundType === "image"
				? `url(${backgroundImageURL})`
				: backgroundType === "gradient"
				? backgroundGradient
				: "none",
		display: "flex",
		flexDirection: contentStyle === "basic" ? "column" : "row",
		alignItems: "center",
		textAlign: "center",
		backgroundSize: "cover",
		backgroundRepeat: "no-repeat",
		boxShadow: `${hOffset || 0}px ${vOffset || 0}px ${blur || 0}px ${spread ||
			0}px ${shadowColor || "#abb8c3"}`
	};

	const iconStyles = {
		display: contentStyle === "inlineWithIcon" ? "block" : "none",
		flex: "1",
		fontSize: `${iconSize || 32}${iconSizeUnit}`,
		color: iconColor || "white"
	};

	const textWrapperStyles = {
		flex: "4",
		wordBreak: "break-all",
		padding: 5,
		textAlign: contentAlign
	};

	const titleStyles = {
		color: titleColor || "#ffffff",
		fontSize: `${titleFontSize}${titleSizeUnit}`
	};

	const descriptionStyles = {
		color: descriptionColor || "#ffffff",
		fontSize: `${descriptionFontSize || 20}${descriptionSizeUnit}`
	};

	const buttonWrapperStyles = {
		flex: "1"
	};

	const buttonStyles = {
		background: buttonBackgroundColor || "#ffffff",
		color: buttonTextColor || "#1ee203e",
		padding: `${buttonPaddingTop}px ${buttonPaddingRight}px ${buttonPaddingBottom}px ${buttonPaddingLeft}px`,
		marginBottom: "10px",
		borderRadius: `${buttonBorderRadius || 10}${buttonRadiusUnit}`,
		fontSize: `${buttonTextSize || 20}${buttonSizeUnit}`
	};

	const urlInputStyles = {
		textAlign: "center"
	};

	return [
		isSelected && <Inspector {...props} />,
		<BlockControls>
			<AlignmentToolbar
				value={contentAlign}
				onChange={contentAlign => setAttributes({ contentAlign })}
			/>
		</BlockControls>,

		// Edit view here
		<div className="eb-cia-wrapper" style={wrapperStyles}>
			<div className={icon} style={iconStyles} />
			<div className="eb-cia-text-wrapper" style={textWrapperStyles}>
				<RichText
					tagName={titleTag}
					className="eb-cia-title"
					style={titleStyles}
					placeholder={__("Add title...")}
					keepPlaceholderOnFocus
					value={title}
					onChange={newTitle => setAttributes({ title: newTitle })}
				/>
				<RichText
					tagName="p"
					className="eb-cia-description"
					style={descriptionStyles}
					placeholder={__("Add Description...")}
					keepPlaceholderOnFocus
					value={description}
					onChange={newText => setAttributes({ description: newText })}
				/>
			</div>

			<div className="eb-cia-button-wrapper" style={buttonWrapperStyles}>
				<RichText
					className="eb-cia-button"
					style={buttonStyles}
					placeholder={__("Add Text")}
					keepPlaceholderOnFocus
					value={buttonText}
					onChange={newText => setAttributes({ buttonText: newText })}
				/>
			</div>
		</div>,

		<div style={urlInputStyles}>
			{isSelected && (
				<URLInput
					value={buttonURL}
					onChange={newURL => setAttributes({ buttonURL: newURL })}
				/>
			)}
		</div>
	];
};

export default edit;
