const { RichText } = wp.editor;

const save = ({ attributes }) => {
	const {
		marginTop,
		marginRight,
		marginBottom,
		marginLeft,
		paddingTop,
		paddingRight,
		paddingBottom,
		paddingLeft,
		contentStyle,
		contentAlign,
		backgroundType,
		backgroundColor,
		backgroundGradient,
		backgroundImageURL,
		icon,
		iconSize,
		iconColor,
		title,
		titleTag,
		titleFontSize,
		titleColor,
		description,
		descriptionFontSize,
		descriptionColor,
		buttonText,
		buttonURL,
		buttonTextSize,
		buttonBackgroundColor,
		buttonTextColor,
		buttonPaddingTop,
		buttonPaddingRight,
		buttonPaddingBottom,
		buttonPaddingLeft,
		buttonBorderRadius,
		shadowColor,
		hOffset,
		vOffset,
		blur,
		spread,
		paddingUnit,
		marginUnit,
		titleSizeUnit,
		descriptionSizeUnit,
		buttonSizeUnit,
		buttonRadiusUnit,
		iconSizeUnit
	} = attributes;

	const wrapperStyles = {
		margin: `${marginTop || 0}${marginUnit} ${marginRight ||
			0}${marginUnit} ${marginBottom || 0}${marginUnit} ${marginLeft ||
			0}${marginUnit}`,
		padding: `${paddingTop || 10}${paddingUnit} ${paddingRight ||
			30}${paddingUnit} ${paddingBottom || 10}${paddingUnit} ${paddingLeft ||
			30}${paddingUnit}`,
		backgroundColor:
			backgroundType === "color" && backgroundColor
				? backgroundColor
				: "#1e203e",
		backgroundImage:
			backgroundType === "image"
				? `url(${backgroundImageURL})`
				: backgroundType === "gradient"
				? backgroundGradient
				: "none",
		display: "flex",
		flexDirection: contentStyle === "basic" ? "column" : "row",
		alignItems: "center",
		textAlign: "center",
		backgroundSize: "cover",
		backgroundRepeat: "no-repeat",
		boxShadow: `${hOffset || 0}px ${vOffset || 0}px ${blur || 0}px ${spread ||
			0}px ${shadowColor || "#abb8c3"}`
	};

	const titleStyles = {
		color: titleColor || "#ffffff",
		fontSize: `${titleFontSize}${titleSizeUnit}`
	};

	const descriptionStyles = {
		color: descriptionColor || "#ffffff",
		fontSize: `${descriptionFontSize || 20}${descriptionSizeUnit}`
	};

	const iconStyles = {
		display: contentStyle === "inlineWithIcon" ? "block" : "none",
		flex: "1",
		fontSize: `${iconSize || 32}${iconSizeUnit}`,
		color: iconColor || "white"
	};

	const textWrapperStyles = {
		flex: "4",
		wordBreak: "break-all",
		padding: 5,
		textAlign: contentAlign
	};

	const buttonStyles = {
		background: buttonBackgroundColor || "#ffffff",
		color: buttonTextColor || "#1e203e",
		padding: `${buttonPaddingTop}px ${buttonPaddingRight}px ${buttonPaddingBottom}px ${buttonPaddingLeft}px`,
		marginBottom: 10,
		marginRight: 10,
		borderRadius: `${buttonBorderRadius || 10}${buttonRadiusUnit}`,
		flex: "1"
	};

	const linkStyles = {
		color: buttonTextColor || "#1e203e",
		textDecoration: "none",
		fontSize: `${buttonTextSize || 20}${buttonSizeUnit}`
	};

	return (
		<div>
			<div
				className="eb-cia-wrapper"
				style={wrapperStyles}
				data-icon={icon ? icon : "glass"}
			>
				<div className={icon} style={iconStyles} />
				<div className="eb-text-wrapper" style={textWrapperStyles}>
					<RichText.Content
						tagName={titleTag}
						className="eb-cia-title"
						style={titleStyles}
						value={title}
					/>
					<RichText.Content
						tagName="p"
						className="eb-cia-description"
						style={descriptionStyles}
						value={description}
					/>
				</div>

				<div className="eb-cia-button-wrapper">
					<a href={buttonURL} style={linkStyles}>
						<div style={buttonStyles}>
							<RichText.Content className="eb-cia-button" value={buttonText} />
						</div>
					</a>
				</div>
			</div>
		</div>
	);
};

export default save;
