/**
 * WordPress dependencies
 */
const { __ } = wp.i18n;
const { InspectorControls, PanelColorSettings } = wp.editor;
const {
  PanelBody,
  ToggleControl,
  TextControl,
  RangeControl,
  SelectControl,
  Button,
  ButtonGroup,
  BaseControl
} = wp.components;
/**
 * Internal dependencies
 */
import DateTime from "react-datetime";
import {
  BORDER_STYLES,
  BOX_JUSTIFY_CONTENT,
  DIGIT_FONT_WEIGHT,
  FONT_DECORATION,
  FONT_STYLES,
  LABEL_TRANSFORM,
  TEXT_ALIGN
} from "./constants";
import DimentionsControl from "../../../util/dimentions-control";
import UnitControl from "../../../util/unit-control";

const Inspector = ({ attributes, setAttributes }) => {
  const {
    id,
    date,
    days,
    hours,
    minutes,
    seconds,
    showDays,
    showHours,
    showMinutes,
    showSeconds,
    daysLabel,
    hoursLabel,
    minutesLabel,
    secondsLabel,
    boxHeight,
    boxWidth,
    boxSpace,
    justifyItems,
    paddingTop,
    paddingRight,
    paddingBottom,
    paddingLeft,
    radiusTopLeft,
    radiusTopRight,
    radiusBottomRight,
    radiusBottomLeft,
    showBorder,
    borderSize,
    borderStyle,
    showBoxShadow,
    hOffset,
    vOffset,
    shadowBlur,
    shadowSpread,
    inlineItems,
    digitFontSize,
    digitFontWeight,
    labelTransform,
    labelFontStyle,
    labelFontDecoration,
    labelLineHeight,
    labelLeftPadding,
    boxBackground,
    digitColor,
    labelColor,
    marginTop,
    marginRight,
    marginBottom,
    marginLeft,
    boxTextAlign,
    borderColor,
    shadowColor,
    labelFontSize,
    wrapMarginTop,
    wrapMarginRight,
    wrapMarginBottom,
    wrapMarginLeft,
    wrapPaddingTop,
    wrapPaddingRight,
    wrapPaddingBottom,
    wrapPaddingLeft,
    wrapMarginUnit,
    wrapPaddingUnit,
    boxMarginUnit,
    boxPaddingUnit,
    radiusUnit,
    digitSizeUnit,
    labelSizeUnit,
    lineHeightUnit
  } = attributes;

  const onDateTimeChange = momentObj => {
    let date = momentObj._d;
    let time = date.getTime();

    const counter = () => {
      let now = new Date().getTime();
      let timer = new Date(time - now);

      // Calculate days, hours, minutes and seconds
      let oneDay = 24 * 60 * 60 * 1000; // hours * minutes * seconds * miliseconds
      let days = Math.round((time - now) / oneDay).toString();
      let hours = timer.getHours().toString();
      let minutes = timer.getMinutes().toString();
      let seconds = timer.getSeconds().toString();

      setAttributes({ date, days, hours, minutes, seconds });
    };

    // Clear interval if countdown already exists
    if (window[id]) {
      clearInterval(window[id]);
    }
    window[id] = setInterval(counter, 1000);
  };

  return (
    <InspectorControls key="controls">
      <PanelBody title={__("Timer Setting")}>
        <BaseControl
          id="eb-countdown-due-date"
          label={__("Countdown Due Date")}
        >
          <DateTime
            value={date}
            onChange={momentObj => onDateTimeChange(momentObj)}
          />
        </BaseControl>
      </PanelBody>

      <PanelBody title={__("Context Setting")}>
        <ToggleControl
          label={__("Display Days")}
          checked={showDays}
          onChange={() => setAttributes({ showDays: !showDays })}
        />

        <ToggleControl
          label={__("Display Hours")}
          checked={showHours}
          onChange={() => setAttributes({ showHours: !showHours })}
        />

        <ToggleControl
          label={__("Display Minutes")}
          checked={showMinutes}
          onChange={() => setAttributes({ showMinutes: !showMinutes })}
        />

        <ToggleControl
          label={__("Display Seconds")}
          checked={showSeconds}
          onChange={() => setAttributes({ showSeconds: !showSeconds })}
        />

        <TextControl
          label={__("Custom Label For Days")}
          value={daysLabel}
          onChange={newValue => setAttributes({ daysLabel: newValue })}
        />
        <TextControl
          label={__("Custom Label For Hours")}
          value={hoursLabel}
          onChange={newValue => setAttributes({ hoursLabel: newValue })}
        />
        <TextControl
          label={__("Custom Label For Minutes")}
          value={minutesLabel}
          onChange={newValue => setAttributes({ minutesLabel: newValue })}
        />
        <TextControl
          label={__("Custom Label For Seconds")}
          value={secondsLabel}
          onChange={newValue => setAttributes({ secondsLabel: newValue })}
        />
      </PanelBody>

      <PanelBody title={__("Container Margin & Padding")} initialOpen={false}>
        <UnitControl
          selectedUnit={wrapMarginUnit}
          unitTypes={[
            { label: "px", value: "px" },
            { label: "em", value: "em" },
            { label: "%", value: "%" }
          ]}
          onClick={wrapMarginUnit => setAttributes({ wrapMarginUnit })}
        />

        <DimentionsControl
          label={__("Margin")}
          top={wrapMarginTop}
          right={wrapMarginRight}
          bottom={wrapMarginBottom}
          left={wrapMarginLeft}
          onChange={({ top, right, bottom, left }) =>
            setAttributes({
              wrapMarginTop: top,
              wrapMarginRight: right,
              wrapMarginBottom: bottom,
              wrapMarginLeft: left
            })
          }
        />

        <UnitControl
          selectedUnit={wrapPaddingUnit}
          unitTypes={[
            { label: "px", value: "px" },
            { label: "em", value: "em" },
            { label: "%", value: "%" }
          ]}
          onClick={wrapPaddingUnit => setAttributes({ wrapPaddingUnit })}
        />

        <DimentionsControl
          label={__("Padding")}
          top={wrapPaddingTop}
          right={wrapPaddingRight}
          bottom={wrapPaddingBottom}
          left={wrapPaddingLeft}
          onChange={({ top, right, bottom, left }) =>
            setAttributes({
              wrapPaddingTop: top,
              wrapPaddingRight: right,
              wrapPaddingBottom: bottom,
              wrapPaddingLeft: left
            })
          }
        />
      </PanelBody>

      <PanelBody title={__("Box Style")} initialOpen={false}>
        <ToggleControl
          label={__("Display Inline")}
          checked={inlineItems}
          onChange={() => setAttributes({ inlineItems: !inlineItems })}
        />

        <ToggleControl
          label={__("Display Border")}
          checked={showBorder}
          onChange={() => setAttributes({ showBorder: !showBorder })}
        />

        <ToggleControl
          label={__("Display Shadow")}
          checked={showBoxShadow}
          onChange={() => setAttributes({ showBoxShadow: !showBoxShadow })}
        />
        <SelectControl
          label={__("Box Positions")}
          value={justifyItems}
          options={BOX_JUSTIFY_CONTENT}
          onChange={newValue => setAttributes({ justifyItems: newValue })}
        />

        <RangeControl
          label={__("Box Height")}
          allowReset
          value={boxHeight}
          onChange={newValue => setAttributes({ boxHeight: newValue })}
          min={10}
          max={200}
        />

        <RangeControl
          label={__("Box Width")}
          value={boxWidth}
          allowReset
          onChange={newValue => setAttributes({ boxWidth: newValue })}
          min={10}
          max={200}
        />

        <RangeControl
          label={__("Space Between Boxes")}
          value={boxSpace}
          allowReset
          onChange={newValue => setAttributes({ boxSpace: newValue })}
          min={0}
          max={100}
        />

        <PanelColorSettings
          title={__("Box Background Color")}
          initialOpen={false}
          colorSettings={[
            {
              value: boxBackground,
              onChange: newColor => setAttributes({ boxBackground: newColor }),
              label: __("Box Background Color")
            }
          ]}
        />

        {inlineItems && (
          <RangeControl
            label={__("Left Spacing For Labels")}
            value={labelLeftPadding}
            allowReset
            onChange={newValue => setAttributes({ labelLeftPadding: newValue })}
            min={0}
            max={100}
          />
        )}

        <PanelBody title={__("Margin & Padding")} initialOpen={false}>
          <UnitControl
            selectedUnit={boxMarginUnit}
            unitTypes={[
              { label: "px", value: "px" },
              { label: "em", value: "em" },
              { label: "%", value: "%" }
            ]}
            onClick={boxMarginUnit => setAttributes({ boxMarginUnit })}
          />

          <DimentionsControl
            label={__("Margin")}
            top={marginTop}
            right={marginRight}
            bottom={marginBottom}
            left={marginLeft}
            onChange={({ top, right, bottom, left }) =>
              setAttributes({
                marginTop: top,
                marginRight: right,
                marginBottom: bottom,
                marginLeft: left
              })
            }
          />

          <UnitControl
            selectedUnit={boxPaddingUnit}
            unitTypes={[
              { label: "px", value: "px" },
              { label: "em", value: "em" },
              { label: "%", value: "%" }
            ]}
            onClick={boxPaddingUnit => setAttributes({ boxPaddingUnit })}
          />

          <DimentionsControl
            label={__("Padding")}
            top={paddingTop}
            right={paddingRight}
            bottom={paddingBottom}
            left={paddingLeft}
            onChange={({ top, right, bottom, left }) =>
              setAttributes({
                paddingTop: top,
                paddingRight: right,
                paddingBottom: bottom,
                paddingLeft: left
              })
            }
          />
        </PanelBody>

        <PanelBody title={__("Border Radius")} initialOpen={false}>
          <UnitControl
            selectedUnit={radiusUnit}
            unitTypes={[
              { label: "px", value: "px" },
              { label: "em", value: "em" },
              { label: "%", value: "%" }
            ]}
            onClick={radiusUnit => setAttributes({ radiusUnit })}
          />

          <DimentionsControl
            label={__("Border Radius")}
            top={radiusTopLeft}
            right={radiusTopRight}
            bottom={radiusBottomRight}
            left={radiusBottomLeft}
            onChange={({ top, right, bottom, left }) =>
              setAttributes({
                radiusTopLeft: top,
                radiusTopRight: right,
                radiusBottomRight: bottom,
                radiusBottomLeft: left
              })
            }
          />
        </PanelBody>

        {showBorder && (
          <PanelBody title={__("Border Settings")} initialOpen={false}>
            <PanelColorSettings
              title={__("Border Color")}
              colorSettings={[
                {
                  value: borderColor,
                  onChange: newColor =>
                    setAttributes({ borderColor: newColor }),
                  label: __("Border Color")
                }
              ]}
            />

            <RangeControl
              label={__("Border Size")}
              value={borderSize}
              onChange={newValue => setAttributes({ borderSize: newValue })}
              min={0}
              max={100}
            />

            <SelectControl
              label={__("Border Style")}
              value={borderStyle}
              options={BORDER_STYLES}
              onChange={newValue => setAttributes({ borderStyle: newValue })}
            />
          </PanelBody>
        )}

        {showBoxShadow && (
          <PanelBody title={__("Shadow Settings")} initialOpen={false}>
            <PanelColorSettings
              title={__("Shadow Color")}
              colorSettings={[
                {
                  value: shadowColor,
                  onChange: newColor =>
                    setAttributes({ shadowColor: newColor }),
                  label: __("Shadow Color")
                }
              ]}
            />

            <RangeControl
              label={__("Horizontal Offset")}
              value={hOffset}
              allowReset
              onChange={newValue => setAttributes({ hOffset: newValue })}
              min={0}
              max={100}
            />

            <RangeControl
              label={__("Vertical Offset")}
              value={vOffset}
              allowReset
              onChange={newValue => setAttributes({ vOffset: newValue })}
              min={0}
              max={100}
            />

            <RangeControl
              label={__("Blur")}
              value={shadowBlur}
              allowReset
              onChange={newValue => setAttributes({ shadowBlur: newValue })}
              min={0}
              max={100}
            />

            <RangeControl
              label={__("Spread")}
              value={shadowSpread}
              allowReset
              onChange={newValue => setAttributes({ shadowSpread: newValue })}
              min={0}
              max={100}
            />
          </PanelBody>
        )}
      </PanelBody>

      <PanelBody title={__("Text Settings")} initialOpen={false}>
        <BaseControl id="eb-countdown-box-text-align" label={__("Text Align")}>
          <ButtonGroup id="eb-countdown-box-text-align">
            {TEXT_ALIGN.map(item => (
              <Button
                isPrimary={boxTextAlign === item.value}
                isDefault={boxTextAlign !== item.value}
                onClick={() => setAttributes({ boxTextAlign: item.value })}
              >
                {item.label}
              </Button>
            ))}
          </ButtonGroup>
        </BaseControl>

        <PanelBody title={__("Digit Styles")} initialOpen={false}>
          <PanelColorSettings
            title={__("Digit Color")}
            colorSettings={[
              {
                value: digitColor,
                onChange: newColor => setAttributes({ digitColor: newColor }),
                label: __("Digit Color")
              }
            ]}
          />

          <UnitControl
            selectedUnit={digitSizeUnit}
            unitTypes={[
              { label: "px", value: "px" },
              { label: "em", value: "em" },
              { label: "%", value: "%" }
            ]}
            onClick={digitSizeUnit => setAttributes({ digitSizeUnit })}
          />

          <RangeControl
            label={__("Digit Font Size")}
            value={digitFontSize}
            allowReset
            onChange={newValue => setAttributes({ digitFontSize: newValue })}
            min={8}
            max={100}
          />

          <SelectControl
            label={__("Digit Font Weight")}
            value={digitFontWeight}
            allowReset
            options={DIGIT_FONT_WEIGHT}
            onChange={newValue => setAttributes({ digitFontWeight: newValue })}
          />
        </PanelBody>

        <PanelBody title={__("Label Styles")} initialOpen={false}>
          <PanelColorSettings
            title={__("Label Color")}
            colorSettings={[
              {
                value: labelColor,
                onChange: newColor => setAttributes({ labelColor: newColor }),
                label: __("Label Color")
              }
            ]}
          />

          <UnitControl
            selectedUnit={labelSizeUnit}
            unitTypes={[
              { label: "px", value: "px" },
              { label: "em", value: "em" },
              { label: "%", value: "%" }
            ]}
            onClick={labelSizeUnit => setAttributes({ labelSizeUnit })}
          />

          <RangeControl
            label={__("Label Font Size")}
            value={labelFontSize}
            allowReset
            onChange={newValue => setAttributes({ labelFontSize: newValue })}
            min={8}
            max={100}
          />

          <SelectControl
            label={__("Label Transform")}
            value={labelTransform}
            options={LABEL_TRANSFORM}
            onChange={newValue => setAttributes({ labelTransform: newValue })}
          />

          <BaseControl
            id="eb-countdown-box-font-style"
            label={__("Label Font Style")}
          >
            <ButtonGroup id="eb-countdown-box-font-style">
              {FONT_STYLES.map(item => (
                <Button
                  isPrimary={labelFontStyle === item.value}
                  isDefault={labelFontStyle !== item.value}
                  onClick={() => setAttributes({ labelFontStyle: item.value })}
                >
                  {item.label}
                </Button>
              ))}
            </ButtonGroup>
          </BaseControl>

          <SelectControl
            label={__("Label Font Decoration")}
            value={labelFontDecoration}
            options={FONT_DECORATION}
            onChange={newValue =>
              setAttributes({ labelFontDecoration: newValue })
            }
          />

          <UnitControl
            selectedUnit={lineHeightUnit}
            unitTypes={[
              { label: "px", value: "px" },
              { label: "em", value: "em" },
              { label: "%", value: "%" }
            ]}
            onClick={lineHeightUnit => setAttributes({ lineHeightUnit })}
          />

          <RangeControl
            label={__("Line Height")}
            value={labelLineHeight}
            allowReset
            onChange={newValue => setAttributes({ labelLineHeight: newValue })}
            min={0}
            max={100}
          />
        </PanelBody>
      </PanelBody>
    </InspectorControls>
  );
};

export default Inspector;
