/**
 * WordPress dependencies
 */
const { __ } = wp.i18n;
const { Fragment } = wp.element;
const {
	PanelBody,
	SelectControl,
	Button,
	TextControl,
	TextareaControl,
	RangeControl,
	ToggleControl,
	ButtonGroup,
	BaseControl,
	IconButton
} = wp.components;
const { InspectorControls, MediaUpload, PanelColorSettings } = wp.editor;

/*
 * Internal dependencies
 */
import faIcons from "../../../util/faIcons";
import GradientColorControl from "../../../util/gradient-color-controller";
import ImageAvater from "../../../util/image-avatar/ImageAvater";
import FontIconPicker from "@fonticonpicker/react-fonticonpicker";
import {
	BACKGROUND_SIZE,
	BACKGROUND_TYPE,
	BORDER_STYLES,
	BUTTON_STYLES,
	FLIPBOX_SIDES,
	FLIPBOX_TYPE,
	ICON_POSITIONS,
	ICON_TYPE,
	LINK_TYPE
} from "../constants";
import { getButtonClasses } from "../helper";
import DimentionsControl from "../../../util/dimentions-control";
import UnitControl from "../../../util/unit-control";

const Inspector = ({ attributes, setAttributes }) => {
	const {
		flipboxStyle,
		boxHeight,
		boxWidth,
		isHover,
		flipType,
		selectedSide,
		frontIconOrImage,
		frontIcon,
		frontImageUrl,
		frontImageId,
		backIconOrImage,
		backIcon,
		backImageUrl,
		backImageId,
		frontTitle,
		frontContent,
		backTitle,
		backContent,
		frontImageSize,
		backImageSize,
		frontBackground,
		backBackground,
		borderStyle,
		borderColor,
		borderWidth,
		borderRadius,
		addLink,
		linkType,
		buttonText,
		buttonIcon,
		buttonIconPos,
		link,
		frontTitleColor,
		backTitleColor,
		frontContentColor,
		backContentColor,
		frontImageRadius,
		backImageRadius,
		frontIconSize,
		backIconSize,
		frontIconColor,
		backIconColor,
		boxShadowColor,
		shadowVOffset,
		shadowHOffset,
		shadowSpread,
		shadowBlur,
		buttonStyle,
		buttonClasses,
		buttonBackground,
		buttonColor,
		buttonSize,
		buttonBorderSize,
		buttonBorderColor,
		buttonBorderType,
		buttonBorderRadius,
		buttonPaddingTop,
		buttonPaddingRight,
		buttonPaddingBottom,
		buttonPaddingLeft,
		btnShadowColor,
		btnShadowVOffset,
		btnShadowHOffset,
		btnShadowBlur,
		btnShadowSpread,
		frontIconBackground,
		frontIconPadding,
		frontIconBorderRadius,
		frontIconTopMargin,
		frontIconBorderSize,
		frontIconBorderType,
		frontIconBorderColor,
		displayFrontIconBorder,
		backIconBackground,
		backIconPadding,
		backIconBorderRadius,
		backIconTopMargin,
		backIconBorderSize,
		backIconBorderType,
		backIconBorderColor,
		displayBackIconBorder,
		frontBackgroundType,
		frontBackgroundGradient,
		backBackgroundType,
		backBackgroundGradient,
		transitionSpeed,
		frontBackgroundImageID,
		frontBackgroundImageURL,
		frontBackgroundSize,
		backBackgroundImageID,
		backBackgroundImageURL,
		backBackgroundSize,
		displayButtonIcon,
		linkedButtonPadding,
		titleFontSize,
		contentFontSize,
		linkedContainerMargin,
		containerMarginTop,
		containerMarginRight,
		containerMarginBottom,
		containerMarginLeft,
		linkedContainerPadding,
		containerPaddingTop,
		containerPaddingRight,
		containerPaddingBottom,
		containerPaddingLeft,
		marginUnit,
		paddingUnit,
		radiusUnit,
		buttonSizeUnit,
		buttonPaddingUnit,
		heightUnit,
		widthUnit
	} = attributes;

	// Genereate different button styles
	const handleButtonStyle = newStyle => {
		const buttonStyle = newStyle;
		const buttonClasses = getButtonClasses(newStyle);

		setAttributes({ buttonStyle, buttonClasses });
	};

	return (
		<InspectorControls keys="controls">
			<PanelBody title={__("Flipbox setting")}>
				<UnitControl
					selectedUnit={heightUnit}
					unitTypes={[
						{ label: "px", value: "px" },
						{ label: "em", value: "em" },
						{ label: "%", value: "%" }
					]}
					onClick={heightUnit => setAttributes({ heightUnit })}
				/>

				<RangeControl
					label={__("Box Height")}
					value={boxHeight}
					allowReset
					onChange={newSize => setAttributes({ boxHeight: newSize })}
					min={0}
					max={600}
				/>

				<UnitControl
					selectedUnit={widthUnit}
					unitTypes={[
						{ label: "px", value: "px" },
						{ label: "em", value: "em" },
						{ label: "%", value: "%" }
					]}
					onClick={widthUnit => setAttributes({ widthUnit })}
				/>

				<RangeControl
					label={__("Box Width")}
					value={boxWidth}
					allowReset
					onChange={newSize => setAttributes({ boxWidth: newSize })}
					min={0}
					max={600}
				/>

				<SelectControl
					label={__("Flipbox Type")}
					value={flipType}
					options={FLIPBOX_TYPE}
					onChange={newStyle => setAttributes({ flipType: newStyle })}
				/>

				<RangeControl
					label={__("Transition Speed")}
					value={transitionSpeed}
					onChange={newValue => {
						let transitionSpeed = newValue;
						setAttributes({ transitionSpeed });
					}}
					min={0}
					max={20}
				/>

				<BaseControl label={__("Selected Side")}>
					<ButtonGroup>
						{FLIPBOX_SIDES.map(option => (
							<Button
								isLarge
								isPrimary={selectedSide === option.value}
								isDefault={selectedSide !== option.value}
								onClick={() => setAttributes({ selectedSide: option.value })}
							>
								{option.label}
							</Button>
						))}
					</ButtonGroup>
				</BaseControl>

				{selectedSide === "front" && (
					<Fragment>
						<BaseControl label={__("Icon Type")} id="eb-flipbox-icon-type">
							<ButtonGroup id="eb-flipbox-icon-type">
								{ICON_TYPE.map(item => (
									<Button
										isLarge
										isPrimary={frontIconOrImage === item.value}
										isDefault={frontIconOrImage !== item.value}
										onClick={() =>
											setAttributes({ frontIconOrImage: item.value })
										}
									>
										{item.label}
									</Button>
								))}
							</ButtonGroup>
						</BaseControl>

						{frontIconOrImage === "icon" && (
							<PanelBody title={__("Icon Settings")}>
								<Fragment>
									<BaseControl label={__("Select Front Icon")}>
										<FontIconPicker
											icons={faIcons}
											value={frontIcon}
											onChange={frontIcon => setAttributes({ frontIcon })}
											appendTo="body"
											closeOnSelect
										/>
									</BaseControl>

									{frontIcon && (
										<Fragment>
											<PanelColorSettings
												title={__("Front Icon Color")}
												initialOpen={false}
												colorSettings={[
													{
														value: frontIconColor,
														onChange: newColor =>
															setAttributes({ frontIconColor: newColor }),
														label: __("Front Icon Color")
													},
													{
														value: frontIconBackground,
														onChange: newColor =>
															setAttributes({
																frontIconBackground: newColor
															}),
														label: __("Front Icon Background")
													}
												]}
											/>

											<RangeControl
												label={__("Icon Size")}
												value={frontIconSize}
												allowReset
												onChange={newSize =>
													setAttributes({ frontIconSize: newSize })
												}
												min={8}
												max={64}
											/>

											<RangeControl
												label={__("Front Icon Padding")}
												value={frontIconPadding}
												allowReset
												onChange={newValue =>
													setAttributes({ frontIconPadding: newValue })
												}
												min={0}
												max={100}
											/>

											<RangeControl
												label={__("Front Icon Top Margin")}
												value={frontIconTopMargin}
												allowReset
												onChange={newValue =>
													setAttributes({ frontIconTopMargin: newValue })
												}
												min={0}
												max={100}
											/>

											<PanelBody
												title={__("Front Icon Border Settings")}
												initialOpen={false}
											>
												<RangeControl
													label={__("Border Size")}
													value={frontIconBorderSize}
													allowReset
													onChange={newValue =>
														setAttributes({ frontIconBorderSize: newValue })
													}
													min={0}
													max={30}
												/>

												<RangeControl
													label={__("Border Radius")}
													value={frontIconBorderRadius}
													allowReset
													onChange={newValue =>
														setAttributes({
															frontIconBorderRadius: newValue
														})
													}
													min={0}
													max={50}
												/>

												<SelectControl
													label={__("Front Icon Border Type")}
													value={frontIconBorderType}
													options={BORDER_STYLES}
													onChange={newValue =>
														setAttributes({ frontIconBorderType: newValue })
													}
												/>

												<PanelColorSettings
													title={__("Front Icon Border Color")}
													initialOpen={false}
													colorSettings={[
														{
															value: frontIconBorderColor,
															onChange: newColor =>
																setAttributes({
																	frontIconBorderColor: newColor
																}),
															label: __("Front Icon Border Color")
														}
													]}
												/>
											</PanelBody>
										</Fragment>
									)}
								</Fragment>
							</PanelBody>
						)}

						{frontIconOrImage === "image" && (
							<PanelBody title={__("Front Image Settings")}>
								<BaseControl
									label={__("Flipbox Image")}
									id="eb-flipbox-front-image"
								>
									{frontImageUrl ? (
										<Fragment>
											<ImageAvater
												imageUrl={frontImageUrl}
												onDeleteImage={() =>
													setAttributes({ frontImageUrl: null })
												}
											/>

											<RangeControl
												label={__("Image Size")}
												value={frontImageSize}
												onChange={newSize =>
													setAttributes({ frontImageSize: newSize })
												}
												min={0}
												max={300}
											/>

											<RangeControl
												label={__("Border Radius")}
												value={frontImageRadius}
												onChange={newValue =>
													setAttributes({ frontImageRadius: newValue })
												}
												min={0}
												max={50}
											/>
										</Fragment>
									) : (
										<MediaUpload
											onSelect={media =>
												setAttributes({
													frontImageId: media.id,
													frontImageUrl: media.url
												})
											}
											type="image"
											value={frontImageId}
											render={({ open }) =>
												!frontImageUrl && (
													<IconButton
														className="eb-flipbox-upload-button"
														label={__("Upload Image")}
														icon="format-image"
														onClick={open}
													/>
												)
											}
										/>
									)}
								</BaseControl>
							</PanelBody>
						)}
					</Fragment>
				)}

				{selectedSide === "back" && (
					<Fragment>
						<BaseControl label={__("Icon Type")} id="eb-flipbox-icon-type">
							<ButtonGroup id="eb-flipbox-icon-type">
								{ICON_TYPE.map(item => (
									<Button
										isLarge
										isPrimary={backIconOrImage === item.value}
										isDefault={backIconOrImage !== item.value}
										onClick={() =>
											setAttributes({ backIconOrImage: item.value })
										}
									>
										{item.label}
									</Button>
								))}
							</ButtonGroup>
						</BaseControl>

						{backIconOrImage === "icon" && (
							<PanelBody title={__("Back Icon Settings")}>
								<Fragment>
									<BaseControl
										label={__("Select Back Icon")}
										id="eb-flipbox-back-icon"
									>
										<FontIconPicker
											icons={faIcons}
											value={backIcon}
											onChange={backIcon => setAttributes({ backIcon })}
											appendTo="body"
											closeOnSelect
										/>
									</BaseControl>

									{backIcon && (
										<Fragment>
											<RangeControl
												label={__("Icon Size")}
												value={backIconSize}
												allowReset
												onChange={newSize =>
													setAttributes({ backIconSize: newSize })
												}
												min={8}
												max={64}
											/>

											<PanelColorSettings
												title={__("Back Icon Color")}
												initialOpen={false}
												colorSettings={[
													{
														value: backIconColor,
														onChange: newColor =>
															setAttributes({
																backIconColor: newColor
															}),
														label: __("Back Icon Color")
													},
													{
														value: backIconBackground,
														onChange: newColor =>
															setAttributes({
																backIconBackground: newColor
															}),
														label: __("Back Icon Background")
													}
												]}
											/>

											<RangeControl
												label={__("Padding")}
												value={backIconPadding}
												allowReset
												onChange={newValue =>
													setAttributes({ backIconPadding: newValue })
												}
												min={0}
												max={100}
											/>

											<RangeControl
												label={__("Top Margin")}
												value={backIconTopMargin}
												allowReset
												onChange={newValue =>
													setAttributes({ backIconTopMargin: newValue })
												}
												min={0}
												max={100}
											/>

											<PanelBody
												title={__("Back Icon Border Settings")}
												initialOpen={false}
											>
												<RangeControl
													label={__("Border Size")}
													value={backIconBorderSize}
													allowReset
													onChange={newValue =>
														setAttributes({ backIconBorderSize: newValue })
													}
													min={0}
													max={30}
												/>

												<RangeControl
													label={__("Border Radius")}
													value={backIconBorderRadius}
													onChange={newValue =>
														setAttributes({
															backIconBorderRadius: newValue
														})
													}
													min={0}
													max={50}
												/>

												<SelectControl
													label={__("Back Icon Border Type")}
													value={backIconBorderType}
													options={BORDER_STYLES}
													onChange={newValue =>
														setAttributes({ backIconBorderType: newValue })
													}
												/>

												<PanelColorSettings
													title={__("Back Icon Border Color")}
													colorSettings={[
														{
															value: backIconBorderColor,
															onChange: newColor =>
																setAttributes({
																	backIconBorderColor: newColor
																}),
															label: __("Back Icon Border Color")
														}
													]}
												/>
											</PanelBody>
										</Fragment>
									)}
								</Fragment>
							</PanelBody>
						)}

						{backIconOrImage === "image" && (
							<PanelBody title={__("Back Image Settings")}>
								<BaseControl label={__("Flipbox Image")}>
									{backImageUrl ? (
										<Fragment>
											<ImageAvater
												imageUrl={backImageUrl}
												onDeleteImage={() =>
													setAttributes({ backImageUrl: null })
												}
											/>
											<RangeControl
												label={__("Image Size")}
												value={backImageSize}
												onChange={newSize =>
													setAttributes({ backImageSize: newSize })
												}
												min={0}
												max={300}
											/>

											<RangeControl
												label={__("Border Radius")}
												value={backImageRadius}
												onChange={newValue =>
													setAttributes({ backImageRadius: newValue })
												}
												min={0}
												max={50}
											/>
										</Fragment>
									) : (
										<MediaUpload
											onSelect={media =>
												setAttributes({
													backImageId: media.id,
													backImageUrl: media.url
												})
											}
											type="image"
											value={backImageId}
											render={({ open }) =>
												!backImageUrl && (
													<IconButton
														className="eb-flipbox-upload-button"
														label={__("Upload Image")}
														icon="format-image"
														onClick={open}
													/>
												)
											}
										/>
									)}
								</BaseControl>
							</PanelBody>
						)}
					</Fragment>
				)}
			</PanelBody>

			<PanelBody title={__(`Flipbox Content`)} initialOpen={false}>
				{selectedSide === "front" && (
					<Fragment>
						<TextControl
							label={__("Front Title")}
							value={frontTitle}
							onChange={newText => setAttributes({ frontTitle: newText })}
						/>

						<TextareaControl
							label={__("Front Content")}
							value={frontContent}
							onChange={newText => setAttributes({ frontContent: newText })}
						/>
					</Fragment>
				)}
				{selectedSide === "back" && (
					<Fragment>
						<TextControl
							label={__("Back Title")}
							value={backTitle}
							onChange={newText => setAttributes({ backTitle: newText })}
						/>

						<TextareaControl
							label={__("Back Content")}
							value={backContent}
							onChange={newText => setAttributes({ backContent: newText })}
						/>
					</Fragment>
				)}
			</PanelBody>

			<PanelBody title={__()} initialOpen={false} />
			<PanelBody title={__("Flipbox Style")} initialOpen={false}>
				{selectedSide === "front" && (
					<BaseControl
						label={__("Front Background Type")}
						id="eb-flipbox-front-background-type"
					>
						<ButtonGroup id="eb-flipbox-front-background-type">
							{BACKGROUND_TYPE.map(item => (
								<Button
									isLarge
									isPrimary={frontBackgroundType === item.value}
									isDefault={frontBackgroundType !== item.value}
									onClick={() =>
										setAttributes({ frontBackgroundType: item.value })
									}
								>
									{item.label}
								</Button>
							))}
						</ButtonGroup>
					</BaseControl>
				)}

				{selectedSide === "front" && frontBackgroundType === "fill" && (
					<PanelColorSettings
						title={__("Front Background")}
						initialOpen={false}
						colorSettings={[
							{
								value: frontBackground,
								onChange: newColor =>
									setAttributes({
										frontBackground: newColor
									}),
								label: __("Front Background")
							}
						]}
					/>
				)}

				{selectedSide === "front" && frontBackgroundType === "gradient" && (
					<PanelBody
						title={__("Background Gradient Colors")}
						initialOpen={false}
					>
						<GradientColorControl
							onChange={newValue =>
								setAttributes({ frontBackgroundGradient: newValue })
							}
						/>
					</PanelBody>
				)}

				{selectedSide === "front" && frontBackgroundType === "image" && (
					<MediaUpload
						onSelect={media => {
							setAttributes({
								frontBackgroundImageID: media.id,
								frontBackgroundImageURL: media.url
							});
						}}
						type="image"
						value={frontBackgroundImageID}
						render={({ open }) =>
							!frontBackgroundImageID && (
								<Button isDefault onClick={open}>
									Upload Image
								</Button>
							)
						}
					/>
				)}

				{frontBackgroundImageID && (
					<Fragment>
						<ImageAvater
							imageUrl={frontBackgroundImageURL}
							onDeleteImage={() =>
								setAttributes({
									frontBackgroundImageID: null,
									frontBackgroundImageURL: null
								})
							}
						/>

						<BaseControl
							label={__("Background Size")}
							id="eb-flipbox-front-background-size"
						>
							<ButtonGroup id="eb-flipbox-front-background-size">
								{BACKGROUND_SIZE.map(item => (
									<Button
										isLarge
										isPrimary={frontBackgroundSize === item.value}
										isDefault={frontBackgroundSize !== item.value}
										onClick={() =>
											setAttributes({ frontBackgroundSize: item.value })
										}
									>
										{item.label}
									</Button>
								))}
							</ButtonGroup>
						</BaseControl>
					</Fragment>
				)}

				{selectedSide === "front" && (
					<PanelColorSettings
						title={__("Front Color")}
						initialOpen={false}
						colorSettings={[
							{
								value: frontTitleColor,
								onChange: newColor =>
									setAttributes({
										frontTitleColor: newColor
									}),
								label: __("Front Title Color")
							},
							{
								value: frontContentColor,
								onChange: newColor =>
									setAttributes({
										frontContentColor: newColor
									}),
								label: __("Front Content Color")
							}
						]}
					/>
				)}

				{selectedSide === "back" && (
					<BaseControl
						label={__("Back Background Type")}
						id="eb-flipbox-back-background-type"
					>
						<ButtonGroup id="eb-flipbox-back-background-type">
							{BACKGROUND_TYPE.map(item => (
								<Button
									isLarge
									isPrimary={backBackgroundType === item.value}
									isDefault={backBackgroundType !== item.value}
									onClick={() =>
										setAttributes({ backBackgroundType: item.value })
									}
								>
									{item.label}
								</Button>
							))}
						</ButtonGroup>
					</BaseControl>
				)}

				{selectedSide === "back" && backBackgroundType === "fill" && (
					<PanelColorSettings
						title={__("Back Background")}
						initialOpen={false}
						colorSettings={[
							{
								value: backBackground,
								onChange: newColor =>
									setAttributes({
										backBackground: newColor
									}),
								label: __("Back Background")
							}
						]}
					/>
				)}

				{backBackgroundType === "gradient" && (
					<PanelBody
						title={__("Background Gradient Colors")}
						initialOpen={false}
					>
						<GradientColorControl
							onChange={newValue =>
								setAttributes({ backBackgroundGradient: newValue })
							}
						/>
					</PanelBody>
				)}

				{backBackgroundType === "image" && (
					<MediaUpload
						onSelect={media => {
							setAttributes({
								backBackgroundImageID: media.id,
								backBackgroundImageURL: media.url
							});
						}}
						type="image"
						value={backBackgroundImageID}
						render={({ open }) =>
							!backBackgroundImageID && (
								<Button isDefault onClick={open}>
									Upload Image
								</Button>
							)
						}
					/>
				)}

				{backBackgroundType === "image" && backBackgroundImageID && (
					<Fragment>
						<ImageAvater
							imageUrl={backBackgroundImageURL}
							onDeleteImage={() =>
								setAttributes({
									backBackgroundImageID: null,
									backBackgroundImageURL: null
								})
							}
						/>

						<BaseControl
							label={__("Background Size")}
							id="eb-flipbox-back-background-size"
						>
							<ButtonGroup id="eb-flipbox-back-background-size">
								{BACKGROUND_SIZE.map(item => (
									<Button
										isLarge
										isPrimary={backBackgroundSize === item.value}
										isDefault={backBackgroundSize !== item.value}
										onClick={() =>
											setAttributes({ backBackgroundSize: item.value })
										}
									>
										{item.label}
									</Button>
								))}
							</ButtonGroup>
						</BaseControl>
					</Fragment>
				)}

				{selectedSide === "back" && (
					<PanelColorSettings
						title={__("Back Title Color")}
						initialOpen={false}
						colorSettings={[
							{
								value: backTitleColor,
								onChange: newColor =>
									setAttributes({
										backTitleColor: newColor
									}),
								label: __("Back Title Color")
							},
							{
								value: backContentColor,
								onChange: newColor =>
									setAttributes({
										backContentColor: newColor
									}),
								label: __("Back Content Color")
							}
						]}
					/>
				)}

				<PanelBody title={__("Margin & Padding")} initialOpen={false}>
					<UnitControl
						selectedUnit={marginUnit}
						unitTypes={[
							{ label: "px", value: "px" },
							{ label: "em", value: "em" },
							{ label: "%", value: "%" }
						]}
						onClick={marginUnit => setAttributes({ marginUnit })}
					/>

					<DimentionsControl
						label={__("Margin")}
						top={containerMarginTop}
						right={containerMarginRight}
						bottom={containerMarginBottom}
						left={containerMarginLeft}
						onChange={({ top, right, bottom, left }) =>
							setAttributes({
								containerMarginTop: top,
								containerMarginRight: right,
								containerMarginBottom: bottom,
								containerMarginLeft: left
							})
						}
					/>

					<UnitControl
						selectedUnit={paddingUnit}
						unitTypes={[
							{ label: "px", value: "px" },
							{ label: "em", value: "em" },
							{ label: "%", value: "%" }
						]}
						onClick={paddingUnit => setAttributes({ paddingUnit })}
					/>

					<DimentionsControl
						label={__("Padding")}
						top={containerPaddingTop}
						right={containerPaddingRight}
						bottom={containerPaddingBottom}
						left={containerPaddingLeft}
						onChange={({ top, right, bottom, left }) =>
							setAttributes({
								containerPaddingTop: top,
								containerPaddingRight: right,
								containerPaddingBottom: bottom,
								containerPaddingLeft: left
							})
						}
					/>
				</PanelBody>

				<PanelBody title={__("Border Settings")} initialOpen={false}>
					<SelectControl
						label={__("Border Style")}
						value={borderStyle}
						options={BORDER_STYLES}
						onChange={newStyle => setAttributes({ borderStyle: newStyle })}
					/>

					<PanelColorSettings
						title={__("Border Color")}
						colorSettings={[
							{
								value: borderColor,
								onChange: newColor =>
									setAttributes({
										borderColor: newColor
									}),
								label: __("Border Color")
							}
						]}
					/>

					<RangeControl
						label={__("Border Width")}
						value={borderWidth}
						onChange={newSize => setAttributes({ borderWidth: newSize })}
						min={0}
						max={100}
					/>

					<UnitControl
						selectedUnit={radiusUnit}
						unitTypes={[
							{ label: "px", value: "px" },
							{ label: "em", value: "em" },
							{ label: "%", value: "%" }
						]}
						onClick={radiusUnit => setAttributes({ radiusUnit })}
					/>

					<RangeControl
						label={__("Border Radius")}
						value={borderRadius}
						onChange={newSize => setAttributes({ borderRadius: newSize })}
						min={0}
						max={100}
					/>
				</PanelBody>

				<PanelBody title={__("Shadow Settings")} initialOpen={false}>
					<PanelColorSettings
						title={__("Shadow Color")}
						colorSettings={[
							{
								value: boxShadowColor,
								onChange: newColor =>
									setAttributes({
										boxShadowColor: newColor
									}),
								label: __("Box Shadow Color")
							}
						]}
					/>

					<RangeControl
						label={__("Vertical Offset")}
						value={shadowVOffset}
						onChange={newValue => setAttributes({ shadowVOffset: newValue })}
						min={0}
						max={100}
					/>

					<RangeControl
						label={__("Horizontal Offset")}
						value={shadowHOffset}
						onChange={newValue => setAttributes({ shadowHOffset: newValue })}
						min={0}
						max={100}
					/>

					<RangeControl
						label={__("Blur")}
						value={shadowBlur}
						onChange={newValue => setAttributes({ shadowBlur: newValue })}
						min={0}
						max={100}
					/>

					<RangeControl
						label={__("Spread")}
						value={shadowSpread}
						onChange={newValue => setAttributes({ shadowSpread: newValue })}
						min={0}
						max={100}
					/>
				</PanelBody>
			</PanelBody>

			<PanelBody title={__("Font Sizes")} initialOpen={false}>
				<RangeControl
					label={__("Title Font Size")}
					value={titleFontSize}
					allowReset
					onChange={titleFontSize => setAttributes({ titleFontSize })}
					min={0}
					max={64}
				/>

				<RangeControl
					label={__("Content Font Size")}
					value={contentFontSize}
					allowReset
					onChange={contentFontSize => setAttributes({ contentFontSize })}
					min={0}
					max={64}
				/>
			</PanelBody>

			<PanelBody title={__("Link Settings")} initialOpen={false}>
				<BaseControl label={__("Link Type")} id="eb-flipbox-link-type">
					<ButtonGroup id="eb-flipbox-link-type">
						{LINK_TYPE.map(item => (
							<Button
								isLarge
								isPrimary={linkType === item.value}
								isDefault={linkType !== item.value}
								onClick={() => setAttributes({ linkType: item.value })}
							>
								{item.label}
							</Button>
						))}
					</ButtonGroup>
				</BaseControl>

				<TextControl
					label={__("Link")}
					value={link}
					placeholder="https://your-link.com"
					onChange={newLink => setAttributes({ link: newLink })}
				/>

				<TextControl
					label={__("Button Text")}
					value={buttonText}
					onChange={newText => setAttributes({ buttonText: newText })}
				/>

				{linkType === "button" && (
					<PanelBody title={__("Button Settings")}>
						<SelectControl
							label={__("Button Style")}
							value={buttonStyle}
							options={BUTTON_STYLES}
							onChange={newStyle => handleButtonStyle(newStyle)}
						/>

						{buttonStyle === "custom" && (
							<Fragment>
								<PanelColorSettings
									title={__("Button Colors")}
									initialOpen={false}
									colorSettings={[
										{
											value: buttonBackground,
											onChange: newColor =>
												setAttributes({
													buttonBackground: newColor
												}),
											label: __("Button Background")
										},
										{
											value: buttonColor,
											onChange: newColor =>
												setAttributes({
													buttonColor: newColor
												}),
											label: __("Button Color")
										}
									]}
								/>

								<PanelBody title={__("Button Size")} initialOpen={false}>
									<UnitControl
										selectedUnit={buttonSizeUnit}
										unitTypes={[
											{ label: "px", value: "px" },
											{ label: "em", value: "em" },
											{ label: "%", value: "%" }
										]}
										onClick={buttonSizeUnit =>
											setAttributes({ buttonSizeUnit })
										}
									/>

									<RangeControl
										label={__("Button Size")}
										value={buttonSize}
										allowReset
										onChange={newSize => setAttributes({ buttonSize: newSize })}
										min={20}
										max={600}
									/>
								</PanelBody>

								<PanelBody title={__("Button Padding")} initialOpen={false}>
									<UnitControl
										selectedUnit={buttonPaddingUnit}
										unitTypes={[
											{ label: "px", value: "px" },
											{ label: "em", value: "em" },
											{ label: "%", value: "%" }
										]}
										onClick={buttonPaddingUnit =>
											setAttributes({ buttonPaddingUnit })
										}
									/>

									<DimentionsControl
										label={__("Padding")}
										top={buttonPaddingTop}
										right={buttonPaddingRight}
										bottom={buttonPaddingBottom}
										left={buttonPaddingLeft}
										onChange={({ top, right, bottom, left }) =>
											setAttributes({
												buttonPaddingTop: top,
												buttonPaddingRight: right,
												buttonPaddingBottom: bottom,
												buttonPaddingLeft: left
											})
										}
									/>
								</PanelBody>

								<PanelBody title={__("Button Border")} initialOpen={false}>
									<PanelColorSettings
										title={__("Border Color")}
										colorSettings={[
											{
												value: buttonBorderColor,
												onChange: newColor =>
													setAttributes({
														buttonBorderColor: newColor
													}),
												label: __("Button Border Color")
											}
										]}
									/>

									<RangeControl
										label={__("Border Size")}
										value={buttonBorderSize}
										onChange={newSize =>
											setAttributes({ buttonBorderSize: newSize })
										}
										min={0}
										max={10}
									/>

									<RangeControl
										label={__("Border Radius")}
										value={buttonBorderRadius}
										onChange={newSize =>
											setAttributes({ buttonBorderRadius: newSize })
										}
										min={0}
										max={50}
									/>

									<SelectControl
										label={__("Border Type")}
										value={buttonBorderType}
										options={BORDER_STYLES}
										onChange={newType =>
											setAttributes({ buttonBorderType: newType })
										}
									/>
								</PanelBody>

								<PanelBody title={__("Button Shadow")} initialOpen={false}>
									<PanelColorSettings
										title={__("Shadow Color")}
										initialOpen={false}
										colorSettings={[
											{
												value: btnShadowColor,
												onChange: newColor =>
													setAttributes({
														btnShadowColor: newColor
													}),
												label: __("Button Shadow Color")
											}
										]}
									/>

									<RangeControl
										label={__("Vertical Offset")}
										value={btnShadowVOffset}
										allowReset
										onChange={newValue =>
											setAttributes({ btnShadowVOffset: newValue })
										}
										min={0}
										max={30}
									/>

									<RangeControl
										label={__("Horizontal Offset")}
										value={btnShadowHOffset}
										allowReset
										onChange={newValue =>
											setAttributes({ btnShadowHOffset: newValue })
										}
										min={0}
										max={30}
									/>

									<RangeControl
										label={__("Blur")}
										value={btnShadowBlur}
										allowReset
										onChange={newValue =>
											setAttributes({ btnShadowBlur: newValue })
										}
										min={0}
										max={30}
									/>

									<RangeControl
										label={__("Spread")}
										value={btnShadowSpread}
										allowReset
										onChange={newValue =>
											setAttributes({ btnShadowSpread: newValue })
										}
										min={0}
										max={30}
									/>
								</PanelBody>

								<PanelBody title={__("Button Icon")} initialOpen={false}>
									<ToggleControl
										label={__("Display Button Icon")}
										checked={displayButtonIcon}
										onChange={() =>
											setAttributes({ displayButtonIcon: !displayButtonIcon })
										}
									/>

									{displayButtonIcon && (
										<BaseControl
											label={__("Select Icon")}
											id="eb-flipbox-link-icon"
											help="Add icon with button (optional)"
										>
											<FontIconPicker
												icons={faIcons}
												value={buttonIcon}
												onChange={buttonIcon => setAttributes({ buttonIcon })}
												appendTo="body"
												closeOnSelect
											/>
										</BaseControl>
									)}

									{displayButtonIcon && buttonIcon && (
										<Fragment>
											<BaseControl
												label={__("Icon Position")}
												id="eb-flipbox-icon-pos"
											>
												<ButtonGroup id="eb-flipbox-icon-pos">
													{ICON_POSITIONS.map(item => (
														<Button
															style={{ zIndex: 0 }} // ? Add this style to fix icon list and primary button issue
															isLarge
															isDefault={buttonIconPos !== item.value}
															isPrimary={buttonIconPos === item.value}
															onClick={() =>
																setAttributes({ buttonIconPos: item.value })
															}
														>
															{item.label}
														</Button>
													))}
												</ButtonGroup>
											</BaseControl>
										</Fragment>
									)}
								</PanelBody>
							</Fragment>
						)}
					</PanelBody>
				)}
			</PanelBody>
		</InspectorControls>
	);
};

export default Inspector;
