/**
 * WordPress dependencies
 */
const { RichText } = wp.editor;
const { Component } = wp.element;

/**
 * Internal depenencies
 */
import Inspector from "./inspector";
import uuid from "../../../util/uuid";

class Edit extends Component {
  componentDidMount() {
    let noticeId = uuid().substr(0, 5);
    this.props.setAttributes({ noticeId });
  }

  render() {
    const { attributes, setAttributes, isSelected } = this.props;
    const {
      dismissible,
      titleFontSize,
      textFontSize,
      title,
      text,
      backgroundColor,
      titleColor,
      textColor,
      noticeId,
      shadowColor,
      shadowHOffset,
      shadowVOffset,
      shadowBlur,
      shadowSpread,
      titleSizeUnit,
      textSizeUnit
    } = attributes;

    const wrapperStyles = {
      background: backgroundColor ? backgroundColor : "#e2e3e5",
      padding: 15,
      boxShadow: `${shadowHOffset || 0}px ${shadowVOffset ||
        0}px ${shadowBlur || 0}px ${shadowSpread || 0}px ${shadowColor ||
        "#000000"}`
    };

    const titleWrapperStyles = {
      display: "flex",
      justifyContent: "space-between"
    };

    const titleStyles = {
      fontSize: `${titleFontSize || 24}${titleSizeUnit}`,
      color: titleColor || "#383d41"
    };

    const textStyles = {
      fontSize: `${textFontSize || 18}${textSizeUnit}`,
      color: textColor || "#383d41"
    };

    const dismissStyles = {
      color: textColor,
      display: dismissible ? "flex" : "none",
      justifyContent: "flex-end"
    };

    return [
      isSelected && <Inspector {...this.props} />,

      //Edit view here
      <div
        className="eb-notice-wrapper"
        style={wrapperStyles}
        data-id={noticeId}
      >
        <div className="eb-notice-title-wrapper" style={titleWrapperStyles}>
          <RichText
            className="eb-notice-title"
            style={titleStyles}
            value={title}
            onChange={newTitle => setAttributes({ title: newTitle })}
            placeholder="Add Title..."
            keepPlaceholderOnFocus
          />
          <span className="eb-notice-dismiss" style={dismissStyles} />
        </div>

        <div>
          <RichText
            className="eb-notice-text"
            style={textStyles}
            value={text}
            onChange={newText => setAttributes({ text: newText })}
            placeholder="Add Text..."
            keepPlaceholderOnFocus
          />
        </div>
      </div>
    ];
  }
}

export default Edit;
