/**
 * WordPress dependencies
 */
const { __ } = wp.i18n;
const { Component } = wp.element;
const { InspectorControls, PanelColorSettings } = wp.editor;
const { PanelBody, ToggleControl, SelectControl, RangeControl } = wp.components;

/**
 * Internal dependencies
 */
import { NOTICE_TYPES } from "./constants";
import UnitControl from "../../../util/unit-control";

class Inspector extends Component {
  onTypeChange = type => {
    switch (type) {
      case "success":
        this.props.setAttributes({
          noticeType: type,
          backgroundColor: "#4caf50",
          titleColor: "#ffffff",
          textColor: "#ffffff"
        });
        break;

      case "info":
        this.props.setAttributes({
          noticeType: type,
          backgroundColor: "#2196f3",
          titleColor: "#ffffff",
          textColor: "#ffffff"
        });
        break;

      case "danger":
        this.props.setAttributes({
          noticeType: type,
          backgroundColor: "#f44336",
          titleColor: "#ffffff",
          textColor: "#ffffff"
        });
        break;

      case "warning":
        this.props.setAttributes({
          noticeType: type,
          backgroundColor: "#ffeb3b",
          titleColor: "#000000",
          textColor: "#000000"
        });
        break;

      case "default":
        this.props.setAttributes({
          noticeType: type,
          backgroundColor: "#d3d3d3",
          titleColor: "#000000",
          textColor: "#000000"
        });
        break;
    }
  };
  render = () => {
    const { attributes, setAttributes } = this.props;
    const {
      dismissible,
      noticeType,
      titleFontSize,
      textFontSize,
      backgroundColor,
      titleColor,
      textColor,
      showAfterDismiss,
      shadowColor,
      shadowHOffset,
      shadowVOffset,
      shadowBlur,
      shadowSpread,
      titleSizeUnit,
      textSizeUnit
    } = attributes;

    return (
      <InspectorControls key="controls">
        <PanelBody title={__("Notice Settings")}>
          <ToggleControl
            label={__("Dismissible")}
            checked={dismissible}
            onChange={() => setAttributes({ dismissible: !dismissible })}
          />

          <ToggleControl
            label={__("Show After Dismiss")}
            checked={showAfterDismiss}
            onChange={() =>
              setAttributes({ showAfterDismiss: !showAfterDismiss })
            }
          />

          <SelectControl
            label={__("Type")}
            value={noticeType}
            options={NOTICE_TYPES}
            onChange={type => this.onTypeChange(type)}
          />
        </PanelBody>

        <PanelBody title={__("Font Sizes")} initialOpen={false}>
          <UnitControl
            selectedUnit={titleSizeUnit}
            unitTypes={[
              { label: "px", value: "px" },
              { label: "em", value: "em" },
              { label: "%", value: "%" }
            ]}
            onClick={titleSizeUnit => setAttributes({ titleSizeUnit })}
          />

          <RangeControl
            label={__("Title Font Size")}
            value={titleFontSize}
            allowReset
            onChange={newSize => setAttributes({ titleFontSize: newSize })}
            min={8}
            max={100}
          />

          <UnitControl
            selectedUnit={textSizeUnit}
            unitTypes={[
              { label: "px", value: "px" },
              { label: "em", value: "em" },
              { label: "%", value: "%" }
            ]}
            onClick={textSizeUnit => setAttributes({ textSizeUnit })}
          />

          <RangeControl
            label={__("Text Font Size")}
            value={textFontSize}
            allowReset
            onChange={newSize => setAttributes({ textFontSize: newSize })}
            min={8}
            max={100}
          />
        </PanelBody>

        <PanelColorSettings
          title={__("Color Settings")}
          initialOpen={false}
          colorSettings={[
            {
              value: backgroundColor,
              onChange: newColor =>
                setAttributes({ backgroundColor: newColor }),
              label: __("Background Color")
            },
            {
              value: titleColor,
              onChange: newColor => setAttributes({ titleColor: newColor }),
              label: __("Title Color")
            },
            {
              value: textColor,
              onChange: newColor => setAttributes({ textColor: newColor }),
              label: __("Text Color")
            }
          ]}
        />

        <PanelBody title={__("Shadow")} initialOpen={false}>
          <PanelColorSettings
            title={__("Shadow Color")}
            colorSettings={[
              {
                value: shadowColor,
                onChange: shadowColor => setAttributes({ shadowColor }),
                label: __("Shadow Color")
              }
            ]}
          />

          <RangeControl
            label={__("Horizontal Offset")}
            value={shadowHOffset}
            allowReset
            onChange={shadowHOffset => setAttributes({ shadowHOffset })}
            min={0}
            max={100}
          />

          <RangeControl
            label={__("Vertical Offset")}
            value={shadowVOffset}
            allowReset
            onChange={shadowVOffset => setAttributes({ shadowVOffset })}
            min={0}
            max={100}
          />

          <RangeControl
            label={__("Blur")}
            value={shadowBlur}
            allowReset
            onChange={shadowBlur => setAttributes({ shadowBlur })}
            min={0}
            max={20}
          />

          <RangeControl
            label={__("Spread")}
            value={shadowSpread}
            allowReset
            onChange={shadowSpread => setAttributes({ shadowSpread })}
            min={0}
            max={20}
          />
        </PanelBody>
      </InspectorControls>
    );
  };
}

export default Inspector;
