const { RichText } = wp.editor;

const save = ({ attributes }) => {
  const {
    dismissible,
    titleFontSize,
    textFontSize,
    title,
    text,
    backgroundColor,
    titleColor,
    textColor,
    noticeId,
    showAfterDismiss,
    shadowColor,
    shadowHOffset,
    shadowVOffset,
    shadowBlur,
    shadowSpread,
    titleSizeUnit,
    textSizeUnit
  } = attributes;

  const wrapperStyles = {
    background: backgroundColor || "#e2e3e5",
    padding: 15,
    boxShadow: `${shadowHOffset || 0}px ${shadowVOffset || 0}px ${shadowBlur ||
      0}px ${shadowSpread || 0}px ${shadowColor || "#000000"}`
  };

  const titleWrapperStyles = {
    display: "flex",
    justifyContent: "space-between"
  };

  const titleStyles = {
    fontSize: `${titleFontSize || 24}${titleSizeUnit}`,
    color: titleColor
  };

  const textStyles = {
    fontSize: `${textFontSize || 18}${textSizeUnit}`,
    color: textColor
  };

  const dismissStyles = {
    color: textColor,
    display: dismissible ? "flex" : "none",
    justifyContent: "center",
    width: 24,
    height: 24,
    cursor: "pointer",
    alignItems: "center"
  };

  return (
    <div
      className="eb-notice-wrapper"
      style={wrapperStyles}
      data-id={noticeId}
      data-show-again={showAfterDismiss}
    >
      <div className="eb-notice-title-wrapper" style={titleWrapperStyles}>
        <RichText.Content
          tagName="div"
          className="eb-notice-title"
          value={title}
          style={titleStyles}
        />
        <span className="eb-notice-dismiss" style={dismissStyles} />
      </div>
      <div>
        <RichText.Content
          tagName="div"
          className="eb-notice-text"
          value={text}
          style={textStyles}
        />
      </div>
    </div>
  );
};

export default save;
