/**
 * WordPress dependencies
 */
const { __ } = wp.i18n;
const { RichText, URLInput } = wp.editor;
const { Dashicon } = wp.components;
/**
 * Internal dependencies
 */
import Inspector from "./inspector";

const edit = props => {
	const { attributes, isSelected, setAttributes } = props;
	const {
		title,
		displaySubtitle,
		subtitle,
		titleBackgroundColor,
		titleTextColor,
		dollarIcon,
		dollarIconSize,
		dollarColor,
		price,
		priceValueSize,
		displayPriceDetails,
		priceDetails,
		priceBackgroundColor,
		priceTextColor,
		features,
		featuresBackgroundColor,
		featuresTextColor,
		buttonBackground,
		buttonTextColor,
		buttonText,
		buttonFontSize,
		isHover,
		hoverBackgroundColor,
		hoverTextColor,
		buttonURL,
		priceboxBackground,
		featureFontSize,
		shadowColor,
		shadowHOffset,
		shadowVOffset,
		shadowBlur,
		shadowSpread,
		borderWidth,
		borderStyle,
		borderColor,
		marginTop,
		marginRight,
		marginBottom,
		marginLeft,
		paddingTop,
		paddingRight,
		paddingBottom,
		paddingLeft,
		marginUnit,
		paddingUnit,
		iconSizeUnit,
		priceSizeUnit,
		featureSizeUnit,
		buttonSizeUnit,
		buttonHeight,
		buttonHeightUnit,
		buttonWidth,
		buttonWidthUnit,
		buttonBorderStyle,
		buttonBorderWidth,
		buttonBorderColor,
		hoverBorderColor,
		buttonBorderRadius,
		buttonBorderRadiusUnit
	} = attributes;

	const wrapperStyles = {
		margin: `${marginTop || 0}${marginUnit} ${marginRight ||
			0}${marginUnit} ${marginBottom || 0}${marginUnit} ${marginLeft ||
			0}${marginUnit}`,
		padding: `${paddingTop || 0}${paddingUnit} ${paddingRight ||
			0}${paddingUnit} ${paddingBottom || 0}${paddingUnit} ${paddingLeft ||
			0}${paddingUnit}`,
		display: "flex",
		flexDirection: "column",
		alignItems: "center",
		background: priceboxBackground || "#ffffff",
		boxShadow: `${shadowHOffset || 0}px ${shadowVOffset || 0}px ${shadowBlur ||
			0}px ${shadowSpread || 0}px ${shadowColor || "#000000"}`,
		border: `${borderWidth || 0}px ${borderStyle} ${borderColor || "#000000"}`
	};

	const titleWrapperStyles = {
		width: "100%",
		background: titleBackgroundColor || "#00bcd6",
		textAlign: "center"
	};

	const titleStyles = {
		color: titleTextColor || "#ffffff"
	};

	const dollarIconStyles = {
		display: "flex",
		flexDirection: "column",
		justifyContent: "center",
		fontSize: `${dollarIconSize || 32}${iconSizeUnit}`,
		color: dollarColor || "#767676"
	};

	const priceWrapperStyles = {
		display: "flex",
		justifyContent: "center",
		width: "100%",
		background: priceBackgroundColor || "#e4e4e4",
		color: priceTextColor || "#767676"
	};

	const priceStyles = {
		fontSize: `${priceValueSize || 48}${priceSizeUnit}`
	};

	const featuresWrapperStyles = {
		background: featuresBackgroundColor,
		width: "100%",
		textAlign: "center"
	};

	const featureStyles = {
		color: featuresTextColor || "#767676",
		listStyle: "none",
		fontSize: `${featureFontSize || 18}${featureSizeUnit}`
	};

	const buttonStyles = {
		height: buttonHeight ? `${buttonHeight}${buttonHeightUnit}` : undefined,
		width: buttonWidth ? `${buttonWidth}${buttonWidthUnit}` : undefined,
		borderWidth: `${buttonBorderWidth || 0}px`,
		borderStyle: buttonBorderStyle,
		borderColor: isHover
			? hoverBorderColor || "#000000"
			: buttonBorderColor || "#000000",
		textAlign: "center",
		background: isHover
			? hoverBackgroundColor || "#00bcd6"
			: buttonBackground || "#00bcd6",
		color: isHover ? hoverTextColor || "#ffffff" : buttonTextColor || "#ffffff",
		margin: 10,
		textAlign: "center",
		padding: "5px 10px",
		display: "inline-block",
		borderRadius: `${buttonBorderRadius || 0}${buttonBorderRadiusUnit}`,
		fontSize: `${buttonFontSize || 24}${buttonSizeUnit}`,
		cursor: isHover ? "pointer" : "default"
	};

	const buttonLinkStyles = {
		display: "flex",
		alignItems: "center"
	};

	return [
		isSelected && <Inspector {...props} />,

		// Edit view here
		<div className="eb-pricebox-wrapper" style={wrapperStyles}>
			<div style={titleWrapperStyles}>
				<RichText
					tagName="h3"
					className="eb-pricebox-title"
					value={title}
					style={titleStyles}
					placeholder="Add Title"
					onChange={newTitle => setAttributes({ title: newTitle })}
					keepPlaceholderOnFocus
				/>

				<RichText
					tagName="p"
					className="eb-pricebox-subtitle"
					value={subtitle}
					style={{
						...titleStyles,
						display: displaySubtitle ? "block" : "none"
					}}
					placeholder="Add Subtitle"
					onChange={newSubtitle => setAttributes({ subtitle: newSubtitle })}
					keepPlaceholderOnFocus
				/>
			</div>

			<div className="eb-pricebox-price" style={priceWrapperStyles}>
				<i className={dollarIcon} style={dollarIconStyles} />
				<RichText
					tagName="p"
					value={price}
					style={priceStyles}
					placeholder={__("99")}
					onChange={newPrice => setAttributes({ price: newPrice })}
					keepPlaceholderOnFocus
				/>
			</div>

			<div style={featuresWrapperStyles}>
				<RichText
					tagName="ul"
					className="eb-pricebox-features"
					value={features}
					style={featureStyles}
					placeholder={__("Add feature text. Press Enter to add another")}
					multiline="li"
					onChange={newFeature => setAttributes({ features: newFeature })}
					keepPlaceholderOnFocus
				/>
			</div>

			<div
				className="eb-pricebox-button"
				style={buttonStyles}
				onMouseEnter={() => setAttributes({ isHover: true })}
				onMouseLeave={() => setAttributes({ isHover: false })}
			>
				<RichText
					value={buttonText}
					placeholder={__("Add Text")}
					onChange={newText => setAttributes({ buttonText: newText })}
					keepPlaceholderOnFocus
				/>
			</div>

			{isSelected && (
				<div style={buttonLinkStyles}>
					<Dashicon icon="admin-links" />
					<URLInput
						value={buttonURL}
						onChange={newURL => setAttributes({ buttonURL: newURL })}
					/>
				</div>
			)}
			<div />
		</div>
	];
};

export default edit;
