/**
 * WordPress dependencies
 */
const { __ } = wp.i18n;
const { Component } = wp.element;
const { InspectorControls, PanelColorSettings } = wp.editor;
const { PanelBody, ToggleControl, RangeControl, SelectControl } = wp.components;

/**
 * Internal dependencies
 */
import { BORDER_STYLES } from "../constants";
import currencyIcons from "../../../assets/js/fa-currency";
import DimentionsControl from "../../../util/dimentions-control";
import UnitControl from "../../../util/unit-control";
import FontIconPicker from "@fonticonpicker/react-fonticonpicker";

class Inspector extends Component {
	render = () => {
		const { attributes, setAttributes } = this.props;
		const {
			displaySubtitle,
			titleBackgroundColor,
			titleTextColor,
			dollarIcon,
			dollarIconSize,
			dollarColor,
			price,
			priceValueSize,
			displayPriceDetails,
			priceDetails,
			priceBackgroundColor,
			priceTextColor,
			features,
			featuresBackgroundColor,
			featuresTextColor,
			buttonBackground,
			buttonTextColor,
			buttonText,
			buttonFontSize,
			hoverBackgroundColor,
			hoverTextColor,
			priceboxBackground,
			featureFontSize,
			shadowColor,
			shadowHOffset,
			shadowVOffset,
			shadowBlur,
			shadowSpread,
			borderWidth,
			borderStyle,
			borderColor,
			linkedMargin,
			marginTop,
			marginRight,
			marginBottom,
			marginLeft,
			linkedPadding,
			paddingTop,
			paddingRight,
			paddingBottom,
			paddingLeft,
			priceIcon,
			marginUnit,
			paddingUnit,
			iconSizeUnit,
			priceSizeUnit,
			featureSizeUnit,
			buttonSizeUnit,
			buttonHeight,
			buttonHeightUnit,
			buttonWidth,
			buttonWidthUnit,
			buttonBorderStyle,
			buttonBorderWidth,
			buttonBorderColor,
			hoverBorderColor,
			buttonBorderRadius,
			buttonBorderRadiusUnit
		} = attributes;

		return (
			<InspectorControls key="controls">
				<PanelBody>
					<ToggleControl
						label="Display Subtitle"
						checked={displaySubtitle}
						onChange={() =>
							setAttributes({ displaySubtitle: !displaySubtitle })
						}
					/>

					<PanelBody title={__("Price Icon")} initialOpen={false}>
						<FontIconPicker
							icons={currencyIcons}
							value={dollarIcon}
							onChange={dollarIcon => setAttributes({ dollarIcon })}
							isMulti={false}
							appendTo="body"
							iconsPerPage={25}
						/>
					</PanelBody>

					<PanelBody title={__("Font Sizes")} initialOpen={false}>
						<UnitControl
							selectedUnit={iconSizeUnit}
							unitTypes={[
								{ label: "px", value: "px" },
								{ label: "em", value: "em" },
								{ label: "%", value: "%" }
							]}
							onClick={iconSizeUnit => setAttributes({ iconSizeUnit })}
						/>

						<RangeControl
							label={__("Icon Size")}
							value={dollarIconSize}
							allowReset
							onChange={newSize => setAttributes({ dollarIconSize: newSize })}
							min={8}
							max={100}
						/>

						<UnitControl
							selectedUnit={priceSizeUnit}
							unitTypes={[
								{ label: "px", value: "px" },
								{ label: "em", value: "em" },
								{ label: "%", value: "%" }
							]}
							onClick={priceSizeUnit => setAttributes({ priceSizeUnit })}
						/>

						<RangeControl
							label={__("Price Size")}
							value={priceValueSize}
							allowReset
							onChange={newSize => setAttributes({ priceValueSize: newSize })}
							min={8}
							max={100}
						/>

						<UnitControl
							selectedUnit={featureSizeUnit}
							unitTypes={[
								{ label: "px", value: "px" },
								{ label: "em", value: "em" },
								{ label: "%", value: "%" }
							]}
							onClick={featureSizeUnit => setAttributes({ featureSizeUnit })}
						/>

						<RangeControl
							label={__("Feature Font Size")}
							value={featureFontSize}
							allowReset
							onChange={newSize => setAttributes({ featureFontSize: newSize })}
							min={8}
							max={100}
						/>
					</PanelBody>
					<PanelBody title={__("Colors")} initialOpen={false}>
						<PanelColorSettings
							title={__("Background Color")}
							initialOpen={false}
							colorSettings={[
								{
									value: priceboxBackground,
									onChange: newColor =>
										setAttributes({ priceboxBackground: newColor }),
									label: __("Background Color")
								}
							]}
						/>

						<PanelColorSettings
							title={__("Title Colors")}
							initialOpen={false}
							colorSettings={[
								{
									value: titleBackgroundColor,
									onChange: newColor =>
										setAttributes({ titleBackgroundColor: newColor }),
									label: __("Title Background Color")
								},
								{
									value: titleTextColor,
									onChange: newColor =>
										setAttributes({ titleTextColor: newColor }),
									label: __("Title Text Color")
								}
							]}
						/>

						<PanelColorSettings
							title={__("Price Colors")}
							initialOpen={false}
							colorSettings={[
								{
									value: dollarColor,
									onChange: newColor =>
										setAttributes({ dollarColor: newColor }),
									label: __("Icon Color")
								},
								{
									value: priceBackgroundColor,
									onChange: newColor =>
										setAttributes({ priceBackgroundColor: newColor }),
									label: __("Price Background Color")
								},
								{
									value: priceTextColor,
									onChange: newColor =>
										setAttributes({ priceTextColor: newColor }),
									label: __("Price Text Color")
								}
							]}
						/>

						<PanelColorSettings
							title={__("Features Colors")}
							initialOpen={false}
							colorSettings={[
								{
									value: featuresBackgroundColor,
									onChange: newColor =>
										setAttributes({ featuresBackgroundColor: newColor }),
									label: __("Features Background Color")
								},
								{
									value: featuresTextColor,
									onChange: newColor =>
										setAttributes({ featuresTextColor: newColor }),
									label: __("Features Text Color")
								}
							]}
						/>
					</PanelBody>
					<PanelBody title={__("Border")} initialOpen={false}>
						<PanelColorSettings
							title={__("Border Color")}
							colorSettings={[
								{
									value: borderColor,
									onChange: borderColor => setAttributes({ borderColor }),
									label: __("Border Color")
								}
							]}
						/>

						<RangeControl
							label={__("Border Width")}
							initialOpen={false}
							value={borderWidth}
							allowReset
							onChange={borderWidth => setAttributes({ borderWidth })}
						/>

						<SelectControl
							label={__("Border Style")}
							value={borderStyle}
							options={BORDER_STYLES}
							onChange={newStyle => setAttributes({ borderStyle: newStyle })}
						/>
					</PanelBody>
					<PanelBody title={__("Shadow")} initialOpen={false}>
						<PanelColorSettings
							title={__("Shadow Color")}
							colorSettings={[
								{
									value: shadowColor,
									onChange: shadowColor => setAttributes({ shadowColor }),
									label: __("Shadow Color")
								}
							]}
						/>

						<RangeControl
							label={__("Horizontal Offset")}
							value={shadowHOffset}
							allowReset
							onChange={shadowHOffset => setAttributes({ shadowHOffset })}
							min={0}
							max={100}
						/>

						<RangeControl
							label={__("Vertical Offset")}
							value={shadowVOffset}
							allowReset
							onChange={shadowVOffset => setAttributes({ shadowVOffset })}
							min={0}
							max={100}
						/>

						<RangeControl
							label={__("Blur")}
							value={shadowBlur}
							allowReset
							onChange={shadowBlur => setAttributes({ shadowBlur })}
							min={0}
							max={20}
						/>

						<RangeControl
							label={__("Spread")}
							value={shadowSpread}
							allowReset
							onChange={shadowSpread => setAttributes({ shadowSpread })}
							min={0}
							max={20}
						/>
					</PanelBody>

					<PanelBody title={__("Button Settings")} initialOpen={false}>
						<UnitControl
							selectedUnit={buttonHeightUnit}
							unitTypes={[
								{ label: "px", value: "px" },
								{ label: "em", value: "em" },
								{ label: "%", value: "%" }
							]}
							onClick={buttonHeightUnit => setAttributes({ buttonHeightUnit })}
						/>

						<RangeControl
							label={__("Height")}
							value={buttonHeight}
							allowReset
							onChange={buttonHeight => setAttributes({ buttonHeight })}
							min={0}
							max={600}
						/>

						<UnitControl
							selectedUnit={buttonWidthUnit}
							unitTypes={[
								{ label: "px", value: "px" },
								{ label: "em", value: "em" },
								{ label: "%", value: "%" }
							]}
							onClick={buttonWidthUnit => setAttributes({ buttonWidthUnit })}
						/>

						<RangeControl
							label={__("Width")}
							value={buttonWidth}
							allowReset
							onChange={buttonWidth => setAttributes({ buttonWidth })}
							min={0}
							max={600}
						/>

						<UnitControl
							selectedUnit={buttonSizeUnit}
							unitTypes={[
								{ label: "px", value: "px" },
								{ label: "em", value: "em" },
								{ label: "%", value: "%" }
							]}
							onClick={buttonSizeUnit => setAttributes({ buttonSizeUnit })}
						/>

						<RangeControl
							label={__("Font Size")}
							value={buttonFontSize}
							allowReset
							onChange={buttonFontSize => setAttributes({ buttonFontSize })}
							min={8}
							max={100}
						/>

						<PanelColorSettings
							title={__("Button Colors")}
							initialOpen={false}
							colorSettings={[
								{
									value: buttonBackground,
									onChange: buttonBackground =>
										setAttributes({ buttonBackground }),
									label: __("Button Background Color")
								},
								{
									value: buttonTextColor,
									onChange: buttonTextColor =>
										setAttributes({ buttonTextColor }),
									label: __("Button Text Color")
								},
								{
									value: buttonBorderColor,
									onChange: buttonBorderColor =>
										setAttributes({ buttonBorderColor }),
									label: __("Border Color")
								},
								{
									value: hoverBackgroundColor,
									onChange: hoverBackgroundColor =>
										setAttributes({ hoverBackgroundColor }),
									label: __("Hover Background Color")
								},
								{
									value: hoverTextColor,
									onChange: hoverTextColor => setAttributes({ hoverTextColor }),
									label: __("Hover Text Color")
								},
								{
									value: hoverBorderColor,
									onChange: hoverBorderColor =>
										setAttributes({ hoverBorderColor }),
									label: __("Hover Border Color")
								}
							]}
						/>

						<PanelBody title={__("Border")} initialOpen={false}>
							<RangeControl
								label={__("Border Width (px)")}
								value={buttonBorderWidth}
								allowReset
								onChange={buttonBorderWidth =>
									setAttributes({ buttonBorderWidth })
								}
								min={0}
								max={20}
							/>

							<UnitControl
								selectedUnit={buttonBorderRadiusUnit}
								unitTypes={[
									{ label: "px", value: "px" },
									{ label: "%", value: "%" }
								]}
								onClick={buttonBorderRadiusUnit =>
									setAttributes({ buttonBorderRadiusUnit })
								}
							/>

							<RangeControl
								label={__("Border Radius")}
								value={buttonBorderRadius}
								allowReset
								onChange={buttonBorderRadius =>
									setAttributes({ buttonBorderRadius })
								}
								min={0}
								max={100}
							/>

							<SelectControl
								label={__("Border Style")}
								value={buttonBorderStyle}
								options={BORDER_STYLES}
								onChange={buttonBorderStyle =>
									setAttributes({ buttonBorderStyle })
								}
							/>
						</PanelBody>
					</PanelBody>

					<PanelBody title={__("Margin & Padding")} initialOpen={false}>
						<UnitControl
							selectedUnit={marginUnit}
							unitTypes={[
								{ label: "px", value: "px" },
								{ label: "em", value: "em" },
								{ label: "%", value: "%" }
							]}
							onClick={marginUnit => setAttributes({ marginUnit })}
						/>

						<DimentionsControl
							label={__("Margin")}
							top={marginTop}
							right={marginRight}
							bottom={marginBottom}
							left={marginLeft}
							onChange={({ top, right, bottom, left }) =>
								setAttributes({
									marginTop: top,
									marginRight: right,
									marginBottom: bottom,
									marginLeft: left
								})
							}
						/>

						<UnitControl
							selectedUnit={paddingUnit}
							unitTypes={[
								{ label: "px", value: "px" },
								{ label: "em", value: "em" },
								{ label: "%", value: "%" }
							]}
							onClick={paddingUnit => setAttributes({ paddingUnit })}
						/>

						<DimentionsControl
							label={__("Padding")}
							top={paddingTop}
							right={paddingRight}
							bottom={paddingBottom}
							left={paddingLeft}
							onChange={({ top, right, bottom, left }) =>
								setAttributes({
									paddingTop: top,
									paddingRight: right,
									paddingBottom: bottom,
									paddingLeft: left
								})
							}
						/>
					</PanelBody>
				</PanelBody>
			</InspectorControls>
		);
	};
}

export default Inspector;
