/**
 * WordPress dependencies
 */
const { RichText } = wp.editor;

const save = ({ attributes }) => {
	const {
		title,
		titleTag,
		displaySubtitle,
		subtitle,
		titleBackgroundColor,
		titleTextColor,
		dollarIcon,
		dollarIconSize,
		dollarColor,
		price,
		priceValueSize,
		displayPriceDetails,
		priceDetails,
		priceBackgroundColor,
		priceTextColor,
		features,
		featuresBackgroundColor,
		featuresTextColor,
		buttonBackground,
		buttonTextColor,
		buttonText,
		buttonFontSize,
		hoverBackgroundColor,
		hoverTextColor,
		buttonURL,
		priceboxBackground,
		featureFontSize,
		shadowColor,
		shadowHOffset,
		shadowVOffset,
		shadowBlur,
		shadowSpread,
		borderWidth,
		borderStyle,
		borderColor,
		marginTop,
		marginRight,
		marginBottom,
		marginLeft,
		paddingTop,
		paddingRight,
		paddingBottom,
		paddingLeft,
		marginUnit,
		paddingUnit,
		iconSizeUnit,
		priceSizeUnit,
		featureSizeUnit,
		buttonSizeUnit,
		buttonHeight,
		buttonHeightUnit,
		buttonWidth,
		buttonWidthUnit,
		buttonBorderStyle,
		buttonBorderWidth,
		buttonBorderColor,
		hoverBorderColor,
		buttonBorderRadius,
		buttonBorderRadiusUnit
	} = attributes;

	const wrapperStyles = {
		margin: `${marginTop || 0}${marginUnit} ${marginRight ||
			0}${marginUnit} ${marginBottom || 0}${marginUnit} ${marginLeft ||
			0}${marginUnit}`,
		padding: `${paddingTop || 0}${paddingUnit} ${paddingRight ||
			0}${paddingUnit} ${paddingBottom || 0}${paddingUnit} ${paddingLeft ||
			0}${paddingUnit}`,
		display: "flex",
		flexDirection: "column",
		alignItems: "center",
		background: priceboxBackground ? priceboxBackground : "#ffffff",
		boxShadow: `${shadowHOffset || 0}px ${shadowVOffset || 0}px ${shadowBlur ||
			0}px ${shadowSpread || 0}px ${shadowColor || "#000000"}`,
		border: `${borderWidth || 0}px ${borderStyle} ${borderColor || "#000000"}`
	};

	const titleWrapperStyles = {
		width: "100%",
		background: titleBackgroundColor || "#00bcd6",
		textAlign: "center"
	};

	const titleStyles = {
		color: titleTextColor || "#ffffff"
	};

	const dollarIconStyles = {
		display: "flex",
		flexDirection: "column",
		justifyContent: "center",
		fontSize: `${dollarIconSize || 32}${iconSizeUnit}`,
		color: dollarColor || "#767676"
	};

	const priceWrapperStyles = {
		display: "flex",
		justifyContent: "center",
		width: "100%",
		background: priceBackgroundColor || "#e4e4e4",
		color: priceTextColor || "#767676"
	};

	const priceStyles = {
		fontSize: `${priceValueSize || 48}${priceSizeUnit}`
	};

	const featuresWrapperStyles = {
		background: featuresBackgroundColor,
		width: "100%",
		textAlign: "center"
	};

	const featureStyles = {
		color: featuresTextColor || "#767676",
		listStyle: "none",
		fontSize: `${featureFontSize || 18}${featureSizeUnit}`
	};

	const buttonStyles = {
		height: buttonHeight ? `${buttonHeight}${buttonHeightUnit}` : undefined,
		width: buttonWidth ? `${buttonWidth}${buttonWidthUnit}` : undefined,
		background: buttonBackground || "#00bcd6",
		borderWidth: `${buttonBorderWidth || 0}px`,
		borderStyle: buttonBorderStyle,
		borderColor: buttonBorderColor || "#000000",
		color: buttonTextColor || "#ffffff",
		margin: 10,
		padding: "5px 10px",
		textAlign: "center",
		display: "inline-block",
		borderRadius: `${buttonBorderRadius || 0}${buttonBorderRadiusUnit}`,
		textDecoration: "none",
		fontSize: `${buttonFontSize || 24}${buttonSizeUnit}`
	};

	return (
		<div
			className="eb-pricebox-wrapper"
			style={wrapperStyles}
			data-button-background={buttonBackground || "#00bcd6"}
			data-button-text-color={buttonTextColor || "#ffffff"}
			data-button-border={`${buttonBorderWidth ||
				0}px ${buttonBorderStyle} ${buttonBorderColor || "#000000"}`}
			data-hover-background={hoverBackgroundColor || "#00bcd6"}
			data-hover-text-color={hoverTextColor || "#ffffff"}
			data-hover-border={`${buttonBorderWidth ||
				0}px ${buttonBorderStyle} ${hoverBorderColor || "#000000"}`}
		>
			<div style={titleWrapperStyles}>
				<RichText.Content
					tagName="h3"
					className="eb-pricebox-title"
					value={title}
					style={titleStyles}
				/>
				<RichText.Content
					tagName="p"
					className="eb-pricebox-subtitle"
					style={{
						...titleStyles,
						display: displaySubtitle ? "block" : "none"
					}}
					value={subtitle}
				/>
			</div>

			<div style={priceWrapperStyles}>
				<i
					className={dollarIcon}
					style={{ ...dollarIconStyles, display: price ? "flex" : "none" }}
				/>
				<RichText.Content
					tagName="p"
					className="eb-pricebox-price"
					value={price}
					style={priceStyles}
				/>
			</div>

			<div style={featuresWrapperStyles}>
				<RichText.Content
					tagName="ul"
					className="eb-pricebox-features"
					style={featureStyles}
					value={features}
				/>
			</div>

			<a className="eb-pricebox-button" href={buttonURL} style={buttonStyles}>
				{buttonText}
			</a>
		</div>
	);
};
export default save;
