/**
 * WordPress dependencies
 */
const { __ } = wp.i18n;
const { RichText } = wp.editor;
const { Component } = wp.element;

/**
 * Internal depenencies
 */
import Inspector from "./inspector";

export default class Edit extends Component {
  render() {
    const { attributes, setAttributes, isSelected } = this.props;
    const {
      progress,
      height,
      displayTitle,
      title,
      displayPercentage,
      colorType,
      progressBackground,
      progressColor,
      progressGradient,
      titleFontSize,
      titleColor,
      percentageType,
      percentageColor,
      tooltipBackground,
      heightUnit
    } = attributes;

    const wrapperStyles = {
      paddingTop: displayPercentage && percentageType === "tooltip" ? 30 : 0
    };

    const containerStyle = {
      backgroundColor: progressBackground || "#e3e3e3",
      height: `${height || 30}${heightUnit}`
    };

    const titleStyles = {
      visibility: displayTitle ? "visible" : "hidden",
      fontSize: `${titleFontSize}px`,
      color: titleColor
    };

    const progressStyle = {
      backgroundColor: colorType === "fill" ? progressColor : "#2962ff",
      width: `${progress || 50}%`,
      backgroundImage: colorType === "gradient" ? progressGradient : "none"
    };

    const tooltipStyles = {
      display:
        displayPercentage && percentageType == "tooltip" ? "block" : "none",
      backgroundColor: tooltipBackground || "#ff3838",
      color: percentageColor || "#ffffff"
    };

    const tooltipArrowStyles = {
      borderTop: `5px solid ${tooltipBackground || "#ff3838"}`
    };

    const innerProgressStyle = {
      display:
        displayPercentage && percentageType === "inline" ? "block" : "none",
      paddingRight: 8,
      fontSize: `${titleFontSize}px`,
      color: titleColor
    };

    return [
      isSelected && <Inspector {...this.props} />,
      <div className="eb-progressbar-wrapper" style={wrapperStyles}>
        <div className="eb-progressbar-container" style={containerStyle}>
          <div className="eb-progressbar-progress" style={progressStyle}>
            <div className="eb-progressbar-tooltip" style={tooltipStyles}>
              {`${progress || 50}%`}
              <span
                className="eb-progressbar-tooltip-arrow"
                style={tooltipArrowStyles}
              />
            </div>
            <RichText
              className="eb-progressbar-title"
              style={titleStyles}
              value={title}
              placeholder={__("Enter text")}
              keepPlaceholderOnFocus
              onChange={newTitle => setAttributes({ title: newTitle })}
            />
            <div style={innerProgressStyle}>{`${progress || 50}%`}</div>
          </div>
        </div>
      </div>
    ];
  }
}
