/**
 * WordPress dependencies
 */
const { __ } = wp.i18n;
const { InspectorControls, PanelColorSettings } = wp.editor;
const {
	PanelBody,
	ToggleControl,
	RangeControl,
	FontSizePicker
} = wp.components;

/**
 *
 * Internal dependencies
 */
import { FONT_SIZES } from "./constants";
import GradientColorController from "../../../util/gradient-color-controller";
import UnitControl from "../../../util/unit-control";

const Inspector = ({ attributes, setAttributes }) => {
	const {
		progress,
		height,
		displayTitle,
		displayPercentage,
		colorType,
		progressBackground,
		progressColor,
		progressGradient,
		titleFontSize,
		titleColor,
		percentageType,
		percentageColor,
		tooltipBackground,
		heightUnit
	} = attributes;
	return (
		<InspectorControls key="controls">
			<PanelBody>
				<RangeControl
					label={__("Progress")}
					value={progress}
					allowReset
					onChange={newValue => setAttributes({ progress: newValue })}
					min={0}
					max={100}
				/>

				<UnitControl
					selectedUnit={heightUnit}
					unitTypes={[
						{ label: "px", value: "px" },
						{ label: "em", value: "em" }
					]}
					onClick={heightUnit => setAttributes({ heightUnit })}
				/>

				<RangeControl
					label={__("Height")}
					value={height}
					allowReset
					onChange={newValue => setAttributes({ height: newValue })}
					min={0}
					max={100}
				/>

				<ToggleControl
					label={__("Display Title")}
					checked={displayTitle}
					onChange={() => setAttributes({ displayTitle: !displayTitle })}
				/>

				<ToggleControl
					label={__("Display Percentage")}
					checked={displayPercentage}
					onChange={() =>
						setAttributes({ displayPercentage: !displayPercentage })
					}
				/>

				{displayPercentage && (
					<ToggleControl
						label={__("Inline percentage")}
						checked={percentageType === "inline"}
						onChange={() =>
							percentageType === "inline"
								? setAttributes({ percentageType: "tooltip" })
								: setAttributes({ percentageType: "inline" })
						}
					/>
				)}

				<ToggleControl
					label={__("Gradient Color")}
					checked={colorType === "gradient"}
					onChange={() =>
						colorType === "fill"
							? setAttributes({ colorType: "gradient" })
							: setAttributes({ colorType: "fill" })
					}
				/>

				{displayTitle && (
					<PanelBody title={__("Title Font Size")} initialOpen={false}>
						<FontSizePicker
							value={titleFontSize}
							onChange={newSize => setAttributes({ titleFontSize: newSize })}
							withSlider={true}
							fontSizes={FONT_SIZES}
						/>
					</PanelBody>
				)}

				{displayTitle && (
					<PanelColorSettings
						title={__("Title Color")}
						initialOpen={false}
						colorSettings={[
							{
								value: titleColor,
								onChange: newColor => setAttributes({ titleColor: newColor }),
								label: __("Title Color")
							}
						]}
					/>
				)}

				{displayPercentage && percentageType === "tooltip" && (
					<PanelColorSettings
						title={__("Tooltip Background Color")}
						initialOpen={false}
						colorSettings={[
							{
								value: tooltipBackground,
								onChange: newColor =>
									setAttributes({ tooltipBackground: newColor }),
								label: __("Tooltip Background Color")
							}
						]}
					/>
				)}

				{displayPercentage && percentageType === "tooltip" && (
					<PanelColorSettings
						title={__("Percentage Color")}
						initialOpen={false}
						colorSettings={[
							{
								value: percentageColor,
								onChange: newColor =>
									setAttributes({ percentageColor: newColor }),
								label: __("Percentage Color")
							}
						]}
					/>
				)}

				<PanelColorSettings
					title={__("Background Color")}
					initialOpen={false}
					colorSettings={[
						{
							value: progressBackground,
							onChange: newColor =>
								setAttributes({ progressBackground: newColor }),
							label: __("Background Color")
						}
					]}
				/>

				{colorType == "fill" && (
					<PanelColorSettings
						title={__("Progressbar Color")}
						initialOpen={false}
						colorSettings={[
							{
								value: progressColor,
								onChange: newColor =>
									setAttributes({ progressColor: newColor }),
								label: __("Progressbar Color")
							}
						]}
					/>
				)}

				{colorType === "gradient" && (
					<PanelBody title={__("Gradient Color")} initialOpen={false}>
						<GradientColorController
							onChange={newValue =>
								setAttributes({ progressGradient: newValue })
							}
						/>
					</PanelBody>
				)}
			</PanelBody>
		</InspectorControls>
	);
};

export default Inspector;
