/**
 * Internal dependencies
 */
import SocialLinks from "./social-links";
import Inspector from "./inspector";

/**
 * WordPress dependencies
 */
const { __ } = wp.i18n;
const { IconButton } = wp.components;

const {
	MediaUpload,
	RichText,
	BlockControls,
	BlockAlignmentToolbar
} = wp.editor;

const Edit = props => {
	const { isSelected, attributes, setAttributes } = props;
	const {
		imageUrl,
		imageId,
		imageHeight,
		imageWidth,
		memberName,
		jobTitle,
		jobDetails,
		contactAlign,
		borderRadius,
		nameColor,
		jobTitleColor,
		jobDetailsColor,
		nameFontSize,
		jobTitleFontSize,
		jobDetailsFontSize,
		socialIconSize,
		socialProfiles,
		socialIconSpacing,
		socialIconColor,
		socialIconAlign,
		marginTop,
		marginRight,
		marginBottom,
		marginLeft,
		paddingTop,
		paddingRight,
		paddingBottom,
		paddingLeft,
		shadowColor,
		shadowHOffset,
		shadowVOffset,
		shadowBlur,
		shadowSpread,
		borderColor,
		borderWidth,
		borderStyle,
		nameUnit,
		jobTitleUnit,
		jobDetailsUnit,
		marginUnit,
		paddingUnit,
		iconSizeUnit,
		iconSpaceUnit
	} = attributes;

	const wrapperStyle = {
		margin: `${marginTop || 0}${marginUnit} ${marginRight ||
			0}${marginUnit} ${marginBottom || 0}${marginUnit} ${marginLeft ||
			0}${marginUnit}`,
		padding: `${paddingTop || 0}${paddingUnit} ${paddingRight ||
			0}${paddingUnit} ${paddingBottom || 0}${paddingUnit} ${paddingLeft ||
			0}${paddingUnit}`,
		boxShadow: `${shadowHOffset || 0}px ${shadowVOffset}px ${shadowBlur ||
			0}px ${shadowSpread || 0}px ${shadowColor || "#000000"}`,
		border: `${borderWidth || 0}px ${borderStyle} ${borderColor || "#000000"}`
	};

	const uploadButtonStyle = {
		margin:
			contactAlign === "left"
				? "0px 0px 0px 0px"
				: contactAlign === "center"
				? "0 auto"
				: "0px 0px 0px auto",
		height: 150,
		width: 150
	};

	const imageStyle = {
		margin:
			contactAlign === "left"
				? "0px 0px 0px 0px"
				: contactAlign === "center"
				? "0 auto"
				: "0px 0px 0px auto",
		height: `${imageHeight}px`,
		width: `${imageWidth}px`,
		borderRadius: `${borderRadius}%`,
		backgroundSize: "cover",
		backgroundPosition: "center"
	};

	const contactStyle = {
		textAlign: contactAlign
	};

	const memberNameStyle = {
		color: nameColor || "#000000",
		fontSize: `${nameFontSize || 24}${nameUnit}`
	};

	const jobTitleStyle = {
		color: jobTitleColor || "#000000",
		fontSize: `${jobTitleFontSize || 18}${jobTitleUnit}`
	};

	const jobDetailsStyle = {
		color: jobDetailsColor || "#000000",
		fontSize: `${jobDetailsFontSize || 18}${jobDetailsUnit}`
	};

	const profileStyles = {
		container: {
			fontSize: `${socialIconSize || 32}${iconSizeUnit}`,
			display: "flex",
			justifyContent: socialIconAlign
		},
		iconWrapper: {
			textDecoration: "none",
			color: socialIconColor || "#000000",
			paddingRight: `${socialIconSpacing || 10}${iconSpaceUnit}`
		}
	};

	return [
		isSelected && <Inspector {...props} />,
		<BlockControls>
			<BlockAlignmentToolbar
				value={contactAlign}
				onChange={newAlign => setAttributes({ contactAlign: newAlign })}
				controls={["left", "center", "right"]}
			/>
		</BlockControls>,

		<div className="eb-team-member-container">
			<div className="eb-team-member-column" style={wrapperStyle}>
				<MediaUpload
					onSelect={media =>
						setAttributes({ imageUrl: media.url, imageId: media.id })
					}
					type="image"
					value={imageId}
					render={({ open }) =>
						!imageUrl && (
							<div style={uploadButtonStyle}>
								<IconButton
									className="eb-team-member-image components-button"
									label={__("Upload Image")}
									icon="format-image"
									onClick={open}
								/>
							</div>
						)
					}
				/>

				<div
					style={{
						...imageStyle,
						backgroundImage: imageUrl ? `url(${imageUrl})` : "none",
						display: imageUrl ? "block" : "none"
					}}
				/>

				<div style={contactStyle}>
					<RichText
						tagName="h3"
						className="eb-member-name"
						placeholder={__("Name")}
						value={memberName}
						onChange={newName => setAttributes({ memberName: newName })}
						style={memberNameStyle}
					/>
					<RichText
						tagName="h4"
						className="eb-member-job-title"
						placeholder={__("Job Title")}
						value={jobTitle}
						onChange={newTitle => setAttributes({ jobTitle: newTitle })}
						style={jobTitleStyle}
					/>
					<RichText
						tagName="p"
						className="eb-member-job-details"
						placeholder={__("Job Details")}
						value={jobDetails}
						onChange={newDetails => setAttributes({ jobDetails: newDetails })}
						style={jobDetailsStyle}
					/>

					<SocialLinks
						profiles={socialProfiles}
						profileStyles={profileStyles}
					/>
				</div>
			</div>
		</div>
	];
};

export default Edit;
