/**
 * WordPress dependencies
 */
const { __ } = wp.i18n;
const { Component, Fragment } = wp.element;
const {
	PanelBody,
	SelectControl,
	Button,
	RangeControl,
	BaseControl,
	ButtonGroup
} = wp.components;

const { InspectorControls, PanelColorSettings } = wp.editor;

/**
 * Internal dependencies
 */
import ImageAvatar from "../../../util/image-avatar/ImageAvater";
import DealSocialProfiles from "../../../util/social-profiles/DealSocialProfiles";
import {
	IMAGE_SHAPES,
	IMAGE_SIZES,
	ICON_ALIGN,
	BORDER_STYLES
} from "../constants";
import DimentionsControl from "../../../util/dimentions-control";
import UnitControl from "../../../util/unit-control";
import IconList from "../../../util/social-profiles/IconList";

class Inspector extends Component {
	onSizeSelect = newSize => {
		switch (newSize) {
			case "thumbnail":
				this.props.setAttributes({
					imageWidth: "150",
					imageHeight: "150",
					customSize: false,
					imageSize: newSize
				});
				break;

			case "small":
				this.props.setAttributes({
					imageWidth: "200",
					imageHeight: "200",
					customSize: false,
					imageSize: newSize
				});
				break;

			case "medium":
				this.props.setAttributes({
					imageWidth: "400",
					imageHeight: "200",
					customSize: false,
					imageSize: newSize
				});
				break;

			case "large":
				this.props.setAttributes({
					imageWidth: "600",
					imageHeight: "230",
					customSize: false,
					imageSize: newSize
				});
				break;

			case "full":
				this.props.setAttributes({
					imageWidth: "610",
					imageHeight: "231",
					customSize: false,
					imageSize: newSize
				});
				break;

			case "custom":
				this.props.setAttributes({
					customSize: true,
					imageSize: newSize
				});
				break;
		}
	};

	render() {
		const { attributes, setAttributes } = this.props;
		const {
			imageSize,
			imageUrl,
			imageHeight,
			imageWidth,
			customSize,
			showIcons,
			borderRadius,
			nameColor,
			jobTitleColor,
			jobDetailsColor,
			nameFontSize,
			jobTitleFontSize,
			jobDetailsFontSize,
			socialIconSize,
			socialProfiles,
			socialIconSpacing,
			socialIconColor,
			socialIconAlign,
			marginTop,
			marginRight,
			marginBottom,
			marginLeft,
			paddingTop,
			paddingRight,
			paddingBottom,
			paddingLeft,
			shadowColor,
			shadowHOffset,
			shadowVOffset,
			shadowBlur,
			shadowSpread,
			borderColor,
			borderWidth,
			borderStyle,
			nameUnit,
			jobTitleUnit,
			jobDetailsUnit,
			marginUnit,
			paddingUnit,
			iconSizeUnit,
			iconSpaceUnit
		} = attributes;

		const hasProfile = socialProfiles.length > 0 ? true : false;

		return (
			<InspectorControls key="controls">
				{imageUrl && (
					<PanelBody title={__("Avatar")}>
						<ImageAvatar
							imageUrl={imageUrl}
							onDeleteImage={() => setAttributes({ imageUrl: null })}
						/>

						<SelectControl
							label={__("Image Size")}
							value={imageSize}
							options={IMAGE_SIZES}
							onChange={newSize => this.onSizeSelect(newSize)}
						/>

						{customSize && (
							<RangeControl
								label={__("Image Height")}
								value={imageHeight}
								onChange={newSize => setAttributes({ imageHeight: newSize })}
								min={0}
								max={610}
							/>
						)}

						{customSize && (
							<RangeControl
								label={__("Image Width")}
								value={imageWidth}
								onChange={newSize => setAttributes({ imageWidth: newSize })}
								min={0}
								max={610}
							/>
						)}

						<BaseControl
							id="eb-team-member-image-shape"
							label={__("Image Shape")}
						>
							<ButtonGroup id="eb-team-member-image-shape">
								{IMAGE_SHAPES.map(item => (
									<Button
										isLarge
										isDefault={borderRadius !== item.value}
										isPrimary={borderRadius === item.value}
										onClick={() => setAttributes({ borderRadius: item.value })}
									>
										{item.label}
									</Button>
								))}
							</ButtonGroup>
						</BaseControl>

						<RangeControl
							label={__("Border Radius")}
							value={borderRadius}
							onChange={newValue => setAttributes({ borderRadius: newValue })}
							min={0}
							max={50}
						/>
					</PanelBody>
				)}

				<PanelColorSettings
					title={__("Colors")}
					initialOpen={false}
					colorSettings={[
						{
							value: nameColor,
							onChange: newColor => setAttributes({ nameColor: newColor }),
							label: __("Name Color")
						},
						{
							value: jobTitleColor,
							onChange: newColor => setAttributes({ jobTitleColor: newColor }),
							label: __("Job Title Color")
						},
						{
							value: jobDetailsColor,
							onChange: newColor =>
								setAttributes({ jobDetailsColor: newColor }),
							label: __("Job Details Color")
						}
					]}
				/>

				{showIcons && (
					<PanelColorSettings
						title={__("Social Icon Color")}
						initialOpen={false}
						colorSettings={[
							{
								value: socialIconColor,
								onChange: newColor =>
									setAttributes({ socialIconColor: newColor }),
								label: __("Social Icon Color")
							}
						]}
					/>
				)}

				<PanelBody title={__("Font Sizes")} initialOpen={false}>
					<UnitControl
						selectedUnit={nameUnit}
						unitTypes={[
							{ label: "px", value: "px" },
							{ label: "em", value: "em" },
							{ label: "%", value: "%" }
						]}
						onClick={nameUnit => setAttributes({ nameUnit })}
					/>

					<RangeControl
						label={__("Name")}
						value={nameFontSize}
						allowReset
						onChange={newSize => setAttributes({ nameFontSize: newSize })}
						min={0}
						max={100}
					/>

					<UnitControl
						selectedUnit={jobTitleUnit}
						unitTypes={[
							{ label: "px", value: "px" },
							{ label: "em", value: "em" },
							{ label: "%", value: "%" }
						]}
						onClick={jobTitleUnit => setAttributes({ jobTitleUnit })}
					/>

					<RangeControl
						label={__("Job Title")}
						value={jobTitleFontSize}
						allowReset
						onChange={newSize => setAttributes({ jobTitleFontSize: newSize })}
						min={0}
						max={100}
					/>

					<UnitControl
						selectedUnit={jobDetailsUnit}
						unitTypes={[
							{ label: "px", value: "px" },
							{ label: "em", value: "em" },
							{ label: "%", value: "%" }
						]}
						onClick={jobDetailsUnit => setAttributes({ jobDetailsUnit })}
					/>

					<RangeControl
						label={__("Job Details")}
						value={jobDetailsFontSize}
						allowReset
						onChange={newSize => setAttributes({ jobDetailsFontSize: newSize })}
						min={0}
						max={100}
					/>
				</PanelBody>

				<PanelBody title={__("Social Profiles")} initialOpen={false}>
					<DealSocialProfiles
						profiles={socialProfiles}
						onProfileAdd={socialProfiles => setAttributes({ socialProfiles })}
						iconList={IconList}
					/>

					{hasProfile && (
						<SelectControl
							label={__("Align")}
							value={socialIconAlign}
							options={ICON_ALIGN}
							onChange={newAlign =>
								setAttributes({ socialIconAlign: newAlign })
							}
						/>
					)}

					{hasProfile && (
						<Fragment>
							<UnitControl
								selectedUnit={iconSizeUnit}
								unitTypes={[
									{ label: "px", value: "px" },
									{ label: "em", value: "em" },
									{ label: "%", value: "%" }
								]}
								onClick={iconSizeUnit => setAttributes({ iconSizeUnit })}
							/>

							<RangeControl
								label={__("Size")}
								value={socialIconSize}
								allowReset
								onChange={newSize => setAttributes({ socialIconSize: newSize })}
								min={8}
								max={100}
							/>
						</Fragment>
					)}

					{hasProfile && (
						<Fragment>
							<UnitControl
								selectedUnit={iconSpaceUnit}
								unitTypes={[
									{ label: "px", value: "px" },
									{ label: "em", value: "em" },
									{ label: "%", value: "%" }
								]}
								onClick={iconSpaceUnit => setAttributes({ iconSpaceUnit })}
							/>

							<RangeControl
								label={__("Spacing")}
								value={socialIconSpacing}
								allowReset
								onChange={newSize =>
									setAttributes({ socialIconSpacing: newSize })
								}
								min={8}
								max={100}
							/>
						</Fragment>
					)}
				</PanelBody>

				<PanelBody title={__("Border")} initialOpen={false}>
					<PanelColorSettings
						title={__("Border Color")}
						colorSettings={[
							{
								value: borderColor,
								onChange: borderColor => setAttributes({ borderColor }),
								label: __("Border Color")
							}
						]}
					/>

					<SelectControl
						label={__("Border Style")}
						value={borderStyle}
						onChange={borderStyle => setAttributes({ borderStyle })}
						options={BORDER_STYLES}
					/>

					<RangeControl
						label={__("Border Width")}
						value={borderWidth}
						allowReset
						onChange={borderWidth => setAttributes({ borderWidth })}
						min={0}
						max={100}
					/>
				</PanelBody>

				<PanelBody title={__("Shadow")} initialOpen={false}>
					<PanelColorSettings
						title={__("Shadow Color")}
						colorSettings={[
							{
								value: shadowColor,
								onChange: shadowColor => setAttributes({ shadowColor }),
								label: __("Shadow Color")
							}
						]}
					/>

					<RangeControl
						label={__("Horizontal Offset")}
						value={shadowHOffset}
						allowReset
						onChange={shadowHOffset => setAttributes({ shadowHOffset })}
						min={0}
						max={100}
					/>

					<RangeControl
						label={__("Vertical Offset")}
						value={shadowVOffset}
						allowReset
						onChange={shadowVOffset => setAttributes({ shadowVOffset })}
						min={0}
						max={100}
					/>

					<RangeControl
						label={__("Blur")}
						value={shadowBlur}
						allowReset
						onChange={shadowBlur => setAttributes({ shadowBlur })}
						min={0}
						max={20}
					/>

					<RangeControl
						label={__("Spread")}
						value={shadowSpread}
						allowReset
						onChange={shadowSpread => setAttributes({ shadowSpread })}
						min={0}
						max={20}
					/>
				</PanelBody>

				<PanelBody title={__("Margin & Padding")} initialOpen={false}>
					<UnitControl
						selectedUnit={marginUnit}
						unitTypes={[
							{ label: "px", value: "px" },
							{ label: "em", value: "em" },
							{ label: "%", value: "%" }
						]}
						onClick={marginUnit => setAttributes({ marginUnit })}
					/>

					<DimentionsControl
						label={__("Margin")}
						top={marginTop}
						right={marginRight}
						bottom={marginBottom}
						left={marginLeft}
						onChange={({ top, right, bottom, left }) =>
							setAttributes({
								marginTop: top,
								marginRight: right,
								marginBottom: bottom,
								marginLeft: left
							})
						}
					/>

					<UnitControl
						selectedUnit={paddingUnit}
						unitTypes={[
							{ label: "px", value: "px" },
							{ label: "em", value: "em" },
							{ label: "%", value: "%" }
						]}
						onClick={paddingUnit => setAttributes({ paddingUnit })}
					/>

					<DimentionsControl
						label={__("Padding")}
						top={paddingTop}
						right={paddingRight}
						bottom={paddingBottom}
						left={paddingLeft}
						onChange={({ top, right, bottom, left }) =>
							setAttributes({
								paddingTop: top,
								paddingRight: right,
								paddingBottom: bottom,
								paddingLeft: left
							})
						}
					/>
				</PanelBody>
			</InspectorControls>
		);
	}
}

export default Inspector;
