/**
 * Internal dependencies
 */
import SocialLinks from "./social-links";

/**
 * WordPress dependencies
 */
const { RichText } = wp.editor;

const Save = ({ attributes }) => {
	const {
		imageUrl,
		imageHeight,
		imageWidth,
		memberName,
		jobTitle,
		jobDetails,
		contactAlign,
		nameColor,
		nameFontSize,
		jobTitleColor,
		jobTitleFontSize,
		jobDetailsColor,
		jobDetailsFontSize,
		borderRadius,
		socialIconSize,
		socialProfiles,
		socialIconSpacing,
		socialIconColor,
		socialIconAlign,
		marginTop,
		marginRight,
		marginBottom,
		marginLeft,
		paddingTop,
		paddingRight,
		paddingBottom,
		paddingLeft,
		shadowColor,
		shadowHOffset,
		shadowVOffset,
		shadowBlur,
		shadowSpread,
		borderColor,
		borderWidth,
		borderStyle,
		nameUnit,
		jobTitleUnit,
		jobDetailsUnit,
		marginUnit,
		paddingUnit,
		iconSizeUnit,
		iconSpaceUnit
	} = attributes;

	const wrapperStyle = {
		margin: `${marginTop || 0}${marginUnit} ${marginRight ||
			0}${marginUnit} ${marginBottom || 0}${marginUnit} ${marginLeft ||
			0}${marginUnit}`,
		padding: `${paddingTop || 0}${paddingUnit} ${paddingRight ||
			0}${paddingUnit} ${paddingBottom || 0}${paddingUnit} ${paddingLeft ||
			0}${paddingUnit}`,
		boxShadow: `${shadowHOffset || 0}px ${shadowVOffset || 0}px ${shadowBlur ||
			0}px ${shadowSpread || 0}px ${shadowColor || "#000000"}`,
		border: `${borderWidth || 0}px ${borderStyle} ${borderColor || "#000000"}`
	};

	const imageStyle = {
		margin:
			contactAlign === "left"
				? "0px 0px 0px 0px"
				: contactAlign === "center"
				? "0 auto"
				: "0px 0px 0px auto",
		height: `${imageHeight}px`,
		width: `${imageWidth}px`,
		borderRadius: `${borderRadius}%`,
		backgroundSize: "cover",
		backgroundPosition: "center"
	};

	const contactStyle = {
		textAlign: contactAlign
	};

	const memberNameStyle = {
		color: nameColor,
		fontSize: `${nameFontSize || 24}${nameUnit}`
	};

	const jobTitleStyle = {
		color: jobTitleColor,
		fontSize: `${jobTitleFontSize || 18}${jobTitleUnit}`
	};

	const jobDetailsStyle = {
		color: jobDetailsColor,
		fontSize: `${jobDetailsFontSize || 18}${jobDetailsUnit}`
	};

	const profileStyles = {
		container: {
			fontSize: `${socialIconSize || 32}${iconSizeUnit}`,
			display: "flex",
			justifyContent: socialIconAlign
		},
		iconWrapper: {
			textDecoration: "none",
			color: socialIconColor || "#000000",
			paddingRight: `${socialIconSpacing || 10}${iconSpaceUnit}`
		}
	};

	return (
		<div className="eb-team-member-container">
			<div className="eb-team-member-column" style={wrapperStyle}>
				<div
					style={{
						...imageStyle,
						backgroundImage: `url(${imageUrl})`,
						display: imageUrl ? "block" : "none"
					}}
				/>

				<div style={contactStyle}>
					<RichText.Content
						tagName="h3"
						className="eb-member-name"
						value={memberName}
						style={memberNameStyle}
					/>

					<RichText.Content
						tagName="h4"
						className="eb-member-job-title"
						value={jobTitle}
						style={jobTitleStyle}
					/>

					<RichText.Content
						tagName="p"
						className="eb-member-job-details"
						value={jobDetails}
						style={jobDetailsStyle}
					/>

					<SocialLinks
						profileStyles={profileStyles}
						profiles={socialProfiles}
					/>
				</div>
			</div>
		</div>
	);
};

export default Save;
