/**
 * Internal dependencies
 */
import Inspector from "./inspector";

/**
 * WordPress dependencies
 */
const { __ } = wp.i18n;
const { MediaUpload, RichText } = wp.editor;
const { IconButton } = wp.components;

const Edit = props => {
	const { isSelected, attributes, setAttributes } = props;
	const {
		fontSize,
		displayAvatar,
		avatarInline,
		avatarPosition,
		avatarAlign,
		borderRadius,
		avatarOrder,
		imageId,
		imageUrl,
		userName,
		companyName,
		description,
		userInfoAlign,
		textAlign,
		userInfoPos,
		imagePosition,
		userNameColor,
		descriptionColor,
		quoteColor,
		userNameFontSize,
		companyFontSize,
		descriptionFontSize,
		quoteSize,
		backgroundColor,
		backgroundImageURL,
		marginTop,
		marginRight,
		marginBottom,
		marginLeft,
		paddingTop,
		paddingRight,
		paddingBottom,
		paddingLeft,
		shadowColor,
		shadowHOffset,
		shadowVOffset,
		shadowSpread,
		shadowBlur,
		marginUnit,
		paddingUnit,
		nameSizeUnit,
		companySizeUnit,
		descriptionSizeUnit,
		quoteSizeUnit,
		companyColor
	} = attributes;

	const containerStyle = {
		backgroundImage: backgroundImageURL
			? `url('${backgroundImageURL}')`
			: "none",
		backgroundColor: backgroundColor || "#ededed",
		margin: `${marginTop || 0}${marginUnit} ${marginRight ||
			0}${marginUnit} ${marginBottom || 0}${marginUnit} ${marginLeft ||
			0}${marginUnit}`,
		padding: `${paddingTop || 10}${paddingUnit} ${paddingRight ||
			10}${paddingUnit} ${paddingBottom || 10}${paddingUnit} ${paddingLeft ||
			10}${paddingUnit}`,
		boxShadow: `${shadowHOffset || 0}px ${shadowVOffset || 0}px ${shadowBlur ||
			0}px ${shadowSpread || 0}px ${shadowColor || "#000000"}`
	};

	const avatarContainerStyle = {
		order: avatarOrder,
		justifyContent: avatarPosition,
		alignItems: avatarAlign,
		fontSize: `${fontSize}px`,
		flexDirection: avatarInline ? "row" : "column"
	};

	const imageContainerStyle = {
		order: imagePosition
	};

	const userInfoStyle = {
		textAlign: textAlign,
		justifyContent: userInfoPos,
		alignSelf: userInfoAlign
	};

	const userNameStyle = {
		fontSize: `${userNameFontSize || 20}${nameSizeUnit}`,
		color: userNameColor
	};

	const companyNameStyle = {
		fontSize: `${companyFontSize || 14}${companySizeUnit}`,
		color: companyColor
	};

	const descriptionStyle = {
		fontSize: `${descriptionFontSize || 18}${descriptionSizeUnit}`,
		color: descriptionColor,
		paddingRight: 20
	};

	const quoteStyle = {
		color: quoteColor,
		fontSize: `${quoteSize || 24}${quoteSizeUnit}`
	};

	return [
		isSelected && <Inspector {...props} />,
		// Edit view here
		<div className="eb-testimonial-wrapper">
			<div className="eb-testimonial-container" style={containerStyle}>
				<div className="eb-avatar-container" style={avatarContainerStyle}>
					<div
						className="image-container"
						style={{
							...imageContainerStyle,
							display: displayAvatar ? "block" : "none"
						}}
					>
						<div
							className="eb-avatar-style"
							style={{
								backgroundImage: `url(${imageUrl})`,
								borderRadius: `${borderRadius}%`,
								display: imageUrl ? "block" : "none"
							}}
						/>
						<MediaUpload
							onSelect={media =>
								setAttributes({ imageUrl: media.url, imageId: media.id })
							}
							type="image"
							value={imageId}
							render={({ open }) =>
								!imageUrl && (
									<IconButton
										className="eb-testimonial-image components-button"
										label={__("Upload Image")}
										icon="format-image"
										onClick={open}
									/>
								)
							}
						/>
					</div>

					<div className="eb-userinfo-container" style={userInfoStyle}>
						<RichText
							tagName="p"
							className="eb-testimonial-username"
							value={userName}
							onChange={newName => setAttributes({ userName: newName })}
							style={userNameStyle}
						/>

						<RichText
							tagName="p"
							className="eb-testimonial-company"
							value={companyName}
							onChange={newName => setAttributes({ companyName: newName })}
							style={companyNameStyle}
						/>
					</div>
				</div>

				<div className="eb-description-container">
					<div
						className="fas fa-quote-left eb-testimonial-quote-style"
						style={quoteStyle}
					/>
					<RichText
						tagName="p"
						value={description}
						onChange={newText => setAttributes({ description: newText })}
						style={descriptionStyle}
					/>
				</div>
			</div>
		</div>
	];
};

export default Edit;
