/**
 * WordPress dependencies
 */
const { __ } = wp.i18n;
const { Component } = wp.element;
const { InspectorControls, PanelColorSettings, MediaUpload } = wp.editor;
const {
	PanelBody,
	ToggleControl,
	RangeControl,
	Button,
	BaseControl,
	ButtonGroup,
	IconButton
} = wp.components;

/**
 * Internal dependencies
 */
import ImageAvater from "../../../util/image-avatar/ImageAvater";
import {
	DESC_POSITIONS,
	TEXT_ALIGN,
	ALIGN_ITEMS,
	IMG_POSITIONS,
	BG_TYPES
} from "../constants";
import DimentionsControl from "../../../util/dimentions-control";
import UnitControl from "../../../util/unit-control";

class Inspector extends Component {
	render() {
		const { attributes, setAttributes } = this.props;
		const {
			displayAvatar,
			avatarInline,
			avatarPosition,
			avatarAlign,
			borderRadius,
			avatarOrder,
			imageUrl,
			userInfoAlign,
			textAlign,
			imagePosition,
			userNameColor,
			descriptionColor,
			quoteColor,
			userNameFontSize,
			companyFontSize,
			descriptionFontSize,
			quoteSize,
			backgroundColor,
			backgroundImageURL,
			marginTop,
			marginRight,
			marginBottom,
			marginLeft,
			paddingTop,
			paddingRight,
			paddingBottom,
			paddingLeft,
			shadowColor,
			shadowHOffset,
			shadowVOffset,
			shadowSpread,
			shadowBlur,
			marginUnit,
			paddingUnit,
			nameSizeUnit,
			companySizeUnit,
			descriptionSizeUnit,
			quoteSizeUnit,
			companyColor,
			backgroundType
		} = attributes;

		return (
			<InspectorControls key="controls">
				<PanelBody title={__("Avatar")} initialOpen={false}>
					<ToggleControl
						label="Display  Avatar"
						checked={displayAvatar}
						onChange={() => setAttributes({ displayAvatar: !displayAvatar })}
					/>

					{displayAvatar && (
						<ToggleControl
							label={__("Avatar Inline")}
							checked={avatarInline}
							onChange={() => setAttributes({ avatarInline: !avatarInline })}
						/>
					)}

					{displayAvatar && (
						<BaseControl
							id="eb-testimonial-image-pos"
							label={__("Image Position")}
						>
							<ButtonGroup id="eb-testimonial-image-pos">
								{IMG_POSITIONS.map(item => (
									<Button
										isLarge
										isDefault={imagePosition !== item.value}
										isPrimary={imagePosition === item.value}
										onClick={() => setAttributes({ imagePosition: item.value })}
									>
										{item.label}
									</Button>
								))}
							</ButtonGroup>
						</BaseControl>
					)}

					{displayAvatar && imageUrl && (
						<PanelBody title={__("Image Setting")}>
							{imageUrl && (
								<ImageAvater
									imageUrl={imageUrl}
									onDeleteImage={() => setAttributes({ imageUrl: null })}
								/>
							)}

							<ToggleControl
								label={__("Round Avatar")}
								checked={borderRadius === 50}
								onChange={() =>
									setAttributes({
										borderRadius: borderRadius === 50 ? 0 : 50
									})
								}
							/>

							<RangeControl
								label={__("Border Radius")}
								value={borderRadius}
								onChange={newValue => setAttributes({ borderRadius: newValue })}
								min={0}
								max={50}
							/>
						</PanelBody>
					)}
				</PanelBody>

				<PanelBody title={__("Layout Settings")} initialOpen={false}>
					{avatarInline && (
						<BaseControl label={__("User Info Position")}>
							<ButtonGroup>
								{ALIGN_ITEMS.map(item => (
									<Button
										isLarge
										isDefault={avatarPosition !== item.value}
										isPrimary={avatarPosition === item.value}
										onClick={() =>
											setAttributes({ avatarPosition: item.value })
										}
									>
										{item.label}
									</Button>
								))}
							</ButtonGroup>
						</BaseControl>
					)}

					{!avatarInline && displayAvatar && (
						<BaseControl
							label={avatarInline ? __("User Info Align") : __("Image Align")}
						>
							<ButtonGroup>
								{ALIGN_ITEMS.map(item => (
									<Button
										isLarge
										isDefault={avatarAlign !== item.value}
										isPrimary={avatarAlign === item.value}
										onClick={() => setAttributes({ avatarAlign: item.value })}
									>
										{item.label}
									</Button>
								))}
							</ButtonGroup>
						</BaseControl>
					)}

					<BaseControl label={__("Description Position")}>
						<ButtonGroup>
							{DESC_POSITIONS.map(item => (
								<Button
									isLarge
									isDefault={avatarOrder !== item.value}
									isPrimary={avatarOrder === item.value}
									onClick={() => setAttributes({ avatarOrder: item.value })}
								>
									{item.label}
								</Button>
							))}
						</ButtonGroup>
					</BaseControl>
					<BaseControl label={__("User Name Align")}>
						<ButtonGroup>
							{TEXT_ALIGN.map(option => (
								<Button
									isLarge
									isDefault={textAlign !== option.value}
									isPrimary={textAlign === option.value}
									onClick={() => setAttributes({ textAlign: option.value })}
								>
									{option.label}
								</Button>
							))}
						</ButtonGroup>
					</BaseControl>

					<BaseControl label={__("User Info Align")}>
						<ButtonGroup>
							{ALIGN_ITEMS.map(item => (
								<Button
									isLarge
									isDefault={userInfoAlign !== item.value}
									isPrimary={userInfoAlign === item.value}
									onClick={() => setAttributes({ userInfoAlign: item.value })}
								>
									{item.label}
								</Button>
							))}
						</ButtonGroup>
					</BaseControl>
				</PanelBody>

				<PanelBody title={__("Background Settings")} initialOpen={false}>
					<BaseControl label={__("Background Types")}>
						<ButtonGroup>
							{BG_TYPES.map(type => (
								<Button
									isPrimary={backgroundType === type.value}
									isDefault={backgroundType !== type.value}
									onClick={() => setAttributes({ backgroundType: type.value })}
								>
									{type.label}
								</Button>
							))}
						</ButtonGroup>
					</BaseControl>

					{backgroundType === "image" && (
						<MediaUpload
							onSelect={media =>
								setAttributes({ backgroundImageURL: media.url })
							}
							type="image"
							value={backgroundImageURL}
							render={({ open }) =>
								!backgroundImageURL ? (
									<IconButton
										className="eb-testimonial-background-upload components-button"
										label={__("Upload Background Image")}
										icon="format-image"
										onClick={open}
									/>
								) : (
									<ImageAvater
										imageUrl={backgroundImageURL}
										onDeleteImage={() =>
											setAttributes({ backgroundImageURL: null })
										}
									/>
								)
							}
						/>
					)}
					{backgroundType === "color" && (
						<PanelColorSettings
							title={__("Background Color")}
							colorSettings={[
								{
									value: backgroundColor,
									onChange: newColor =>
										setAttributes({ backgroundColor: newColor }),
									label: __("Background Color")
								}
							]}
						/>
					)}
				</PanelBody>

				<PanelBody title={__("Typography & Colors")} initialOpen={false}>
					<PanelBody title={__("User Name")} initialOpen={false}>
						<PanelColorSettings
							title={__("Color")}
							colorSettings={[
								{
									value: userNameColor,
									onChange: userNameColor => setAttributes({ userNameColor }),
									label: __("")
								}
							]}
						/>

						<UnitControl
							selectedUnit={nameSizeUnit}
							unitTypes={[
								{ label: "px", value: "px" },
								{ label: "em", value: "em" },
								{ label: "%", value: "%" }
							]}
							onClick={nameSizeUnit => setAttributes({ nameSizeUnit })}
						/>

						<RangeControl
							label={__("Font Size")}
							value={userNameFontSize}
							allowReset
							onChange={userNameFontSize => setAttributes({ userNameFontSize })}
							min={8}
							max={100}
						/>
					</PanelBody>

					<PanelBody title={__("Company Name")} initialOpen={false}>
						<PanelColorSettings
							title={__("Color")}
							colorSettings={[
								{
									value: companyColor,
									onChange: companyColor => setAttributes({ companyColor }),
									label: __("")
								}
							]}
						/>

						<UnitControl
							selectedUnit={companySizeUnit}
							unitTypes={[
								{ label: "px", value: "px" },
								{ label: "em", value: "em" },
								{ label: "%", value: "%" }
							]}
							onClick={companySizeUnit => setAttributes({ companySizeUnit })}
						/>

						<RangeControl
							label={__("Font Size")}
							value={companyFontSize}
							allowReset
							onChange={companyFontSize => setAttributes({ companyFontSize })}
							min={8}
							max={100}
						/>
					</PanelBody>

					<PanelBody title={__("Description")} initialOpen={false}>
						<PanelColorSettings
							title={__("Color")}
							colorSettings={[
								{
									value: descriptionColor,
									onChange: descriptionColor =>
										setAttributes({ descriptionColor }),
									label: __("")
								}
							]}
						/>

						<UnitControl
							selectedUnit={descriptionSizeUnit}
							unitTypes={[
								{ label: "px", value: "px" },
								{ label: "em", value: "em" },
								{ label: "%", value: "%" }
							]}
							onClick={descriptionSizeUnit =>
								setAttributes({ descriptionSizeUnit })
							}
						/>

						<RangeControl
							label={__("Font Size")}
							value={descriptionFontSize}
							allowReset
							onChange={descriptionFontSize =>
								setAttributes({ descriptionFontSize })
							}
							min={8}
							max={100}
						/>
					</PanelBody>

					<PanelBody title={__("Quote")} initialOpen={false}>
						<PanelColorSettings
							title={__("Color")}
							colorSettings={[
								{
									value: quoteColor,
									onChange: quoteColor => setAttributes({ quoteColor }),
									label: __("")
								}
							]}
						/>

						<UnitControl
							selectedUnit={quoteSizeUnit}
							unitTypes={[
								{ label: "px", value: "px" },
								{ label: "em", value: "em" },
								{ label: "%", value: "%" }
							]}
							onClick={quoteSizeUnit => setAttributes({ quoteSizeUnit })}
						/>

						<RangeControl
							label={__("Font Size")}
							value={quoteSize}
							allowReset
							onChange={quoteSize => setAttributes({ quoteSize })}
							min={8}
							max={100}
						/>
					</PanelBody>
				</PanelBody>

				<PanelBody title={__("Box Shadow")} initialOpen={false}>
					<PanelColorSettings
						title={__("Shadow Color")}
						colorSettings={[
							{
								value: shadowColor,
								onChange: shadowColor => setAttributes({ shadowColor }),
								label: __("Shadow Color")
							}
						]}
					/>

					<RangeControl
						label={__("Horizontal Offset")}
						value={shadowHOffset}
						allowReset
						onChange={shadowHOffset => setAttributes({ shadowHOffset })}
						min={0}
						max={100}
					/>

					<RangeControl
						label={__("Vertical Offset")}
						value={shadowVOffset}
						allowReset
						onChange={shadowVOffset => setAttributes({ shadowVOffset })}
						min={0}
						max={100}
					/>

					<RangeControl
						label={__("Blur")}
						value={shadowBlur}
						allowReset
						onChange={shadowBlur => setAttributes({ shadowBlur })}
						min={0}
						max={20}
					/>

					<RangeControl
						label={__("Spread")}
						value={shadowSpread}
						allowReset
						onChange={shadowSpread => setAttributes({ shadowSpread })}
						min={0}
						max={20}
					/>
				</PanelBody>

				<PanelBody title={__("Margin & Padding")} initialOpen={false}>
					<UnitControl
						selectedUnit={marginUnit}
						unitTypes={[
							{ label: "px", value: "px" },
							{ label: "em", value: "em" },
							{ label: "%", value: "%" }
						]}
						onClick={marginUnit => setAttributes({ marginUnit })}
					/>

					<DimentionsControl
						label={__("Margin")}
						top={marginTop}
						right={marginRight}
						bottom={marginBottom}
						left={marginLeft}
						onChange={({ top, right, bottom, left }) =>
							setAttributes({
								marginTop: top,
								marginRight: right,
								marginBottom: bottom,
								marginLeft: left
							})
						}
					/>

					<UnitControl
						selectedUnit={paddingUnit}
						unitTypes={[
							{ label: "px", value: "px" },
							{ label: "em", value: "em" },
							{ label: "%", value: "%" }
						]}
						onClick={paddingUnit => setAttributes({ paddingUnit })}
					/>

					<DimentionsControl
						label={__("Padding")}
						top={paddingTop}
						right={paddingRight}
						bottom={paddingBottom}
						left={paddingLeft}
						onChange={({ top, right, bottom, left }) =>
							setAttributes({
								paddingTop: top,
								paddingRight: right,
								paddingBottom: bottom,
								paddingLeft: left
							})
						}
					/>
				</PanelBody>
			</InspectorControls>
		);
	}
}

export default Inspector;
