/**
 * WordPress dependencies
 */
const { RichText } = wp.editor;

const Save = ({ attributes }) => {
	const {
		fontSize,
		displayAvatar,
		avatarInline,
		avatarPosition,
		avatarAlign,
		borderRadius,
		avatarOrder,
		imageUrl,
		userName,
		companyName,
		description,
		userInfoAlign,
		textAlign,
		userInfoPos,
		imagePosition,
		userNameColor,
		descriptionColor,
		quoteColor,
		userNameFontSize,
		companyFontSize,
		descriptionFontSize,
		quoteSize,
		backgroundColor,
		backgroundImageURL,
		marginTop,
		marginRight,
		marginBottom,
		marginLeft,
		paddingTop,
		paddingRight,
		paddingBottom,
		paddingLeft,
		shadowColor,
		shadowHOffset,
		shadowVOffset,
		shadowSpread,
		shadowBlur,
		marginUnit,
		paddingUnit,
		nameSizeUnit,
		companySizeUnit,
		descriptionSizeUnit,
		quoteSizeUnit,
		companyColor
	} = attributes;

	const containerStyle = {
		backgroundImage: backgroundImageURL
			? `url('${backgroundImageURL}')`
			: "none",
		backgroundColor: backgroundColor || "#ededed",
		margin: `${marginTop || 0}${marginUnit} ${marginRight ||
			0}${marginUnit} ${marginBottom || 0}${marginUnit} ${marginLeft ||
			0}${marginUnit}`,
		padding: `${paddingTop || 10}${paddingUnit} ${paddingRight ||
			10}${paddingUnit} ${paddingBottom || 10}${paddingUnit} ${paddingLeft ||
			10}${paddingUnit}`,
		boxShadow: `${shadowHOffset || 0}px ${shadowVOffset || 0}px ${shadowBlur ||
			0}px ${shadowSpread || 0}px ${shadowColor || "#000000"}`
	};

	const avatarContainerStyle = {
		order: avatarOrder,
		justifyContent: avatarPosition,
		alignItems: avatarAlign,
		fontSize: `${fontSize}px`,
		flexDirection: avatarInline ? "row" : "column"
	};

	const imageContainerStyle = {
		order: imagePosition,
		display: displayAvatar && imageUrl ? "block" : "none"
	};

	const userInfoStyle = {
		textAlign: textAlign,
		justifyContent: userInfoPos,
		alignSelf: userInfoAlign
	};

	const userNameStyle = {
		fontSize: `${userNameFontSize || 20}${nameSizeUnit}`,
		color: userNameColor,
		margin: 0
	};

	const companyNameStyle = {
		fontSize: `${companyFontSize || 14}${companyFontSize}`,
		color: companyColor,
		margin: 0
	};

	const descriptionStyle = {
		fontSize: `${descriptionFontSize || 18}${descriptionSizeUnit}`,
		color: descriptionColor,
		margin: 0,
		paddingRight: 20
	};

	const quoteStyle = {
		color: quoteColor,
		fontSize: `${quoteSize || 24}${quoteSizeUnit}`
	};

	return (
		<div className="eb-testimonial-wrapper">
			<div className="eb-testimonial-container" style={containerStyle}>
				<div
					className={`eb-avatar-container ${
						avatarInline ? "avatar-inline" : "avatar-basic"
					} `}
					style={avatarContainerStyle}
				>
					<div className="image-container" style={imageContainerStyle}>
						<div
							style={{
								backgroundImage: `url(${imageUrl})`,
								borderRadius: `${borderRadius}%`
							}}
							className="eb-avatar-style"
						/>
					</div>
					<div className="eb-userinfo-container" style={userInfoStyle}>
						<RichText.Content
							tagName="p"
							className="username-one"
							value={userName}
							style={userNameStyle}
						/>

						<RichText.Content
							tagName="p"
							className="company-one"
							value={companyName}
							style={companyNameStyle}
						/>
					</div>
				</div>

				<div className="eb-description-container">
					<div
						className="fas fa-quote-left eb-testimonial-quote-style"
						style={quoteStyle}
					/>
					<RichText.Content
						tagName="p"
						className="description-one"
						value={description}
						style={descriptionStyle}
					/>
				</div>
			</div>
		</div>
	);
};

export default Save;
