<?php
/**
 * Blocks Initializer
 *
 * Enqueue CSS/JS of all the blocks.
 *
 * @since   1.0.0
 * @package Essential_Blocks
 */

// Exit if accessed directly.
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Enqueue Gutenberg block assets for both frontend + backend.
 *
 * `wp-blocks`: includes block type registration and related functions.
 *
 * @since 1.0.0
 */
function essential_blocks_cgb_block_assets()
{
    // Styles.
    wp_enqueue_style(
        'essential-blocks-style-css', // Handle.
        plugins_url('dist/blocks.style.build.css', dirname(__FILE__)), // Block style CSS.
        array('wp-editor') // Dependency to include the CSS after it.
        // filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.style.build.css' ) // Version: filemtime — Gets file modification time.
    );

    wp_enqueue_style(
        'essential-blocks-cgb-hover-css',
        plugins_url('src/assets/css/hover-min.css', dirname(__FILE__)),
        array('wp-editor')
    );

    wp_enqueue_style(
       'fontpicker-default-theme',
        plugins_url('/src/assets/css/fonticonpicker.base-theme.react.css', dirname(__FILE__)),
        array()
    );

    wp_enqueue_style(
        'fontawesome-frontend-css',
        plugins_url('/src/assets/css/font-awesome5.css', dirname(__FILE__)),
        array()
    );

    wp_enqueue_style(
        'hover-effects-style',
        plugins_url('/src/assets/css/hover-effects.css', dirname(__FILE__)),
        array()
    );

    wp_enqueue_style(
        'twenty-twenty-style',
        plugins_url('/src/assets/css/twentytwenty.css', dirname(__FILE__)),
        array()
    );

    wp_enqueue_script(
        'essential-blocks-countdown-frontend',
        plugins_url("/src/frontend/countdown-frontend.js", dirname(__FILE__)),
        array(),
        true
    );

    wp_enqueue_script(
        'essential-blocks-accordion-frontend',
        plugins_url("/src/frontend/accordion-frontend.js", dirname(__FILE__)),
        array(),
        true
    );

    wp_enqueue_script(
        'essential-blocks-notice-frontend',
        plugins_url("/src/frontend/notice-frontend.js", dirname(__FILE__)),
        array(),
        true
    );

    wp_enqueue_script(
        'essential-blocks-wrapper-frontend',
        plugins_url("/src/frontend/wrapper-frontend.js", dirname(__FILE__)),
        array(),
        '',
        true
    );

    wp_enqueue_script(
        'essential-blocks-twenty-move',
        plugins_url("/src/assets/js/jquery.event.move.js", dirname(__FILE__)),
        array("wp-editor"),
        true
    );

    wp_enqueue_script(
        'essential-blocks-twenty-twenty',
        plugins_url("/src/assets/js/jquery.twentytwenty.js", dirname(__FILE__)),
        array("wp-editor"),
        true
    );

    wp_enqueue_script(
        'essential-blocks-image-comparison-frontend',
        plugins_url("src/frontend/image-comparison-frontend.js", dirname(__FILE__)),
        array("wp-editor"),
        true
    );

    wp_enqueue_script(
        'essential-blocks-button-frontend',
        plugins_url("src/frontend/button-frontend.js", dirname(__FILE__)),
        array("wp-editor"),
        true
    );

    wp_enqueue_script(
        'essential-blocks-pricing-table-frontend',
        plugins_url("src/frontend/pricing-table-frontend.js", dirname(__FILE__)),
        array("wp-editor"),
        true
    );

} // End function essential-blocks_cgb_block_assets().

// Hook: Frontend assets.
add_action('enqueue_block_assets', 'essential_blocks_cgb_block_assets');

/**
 * Enqueue Gutenberg block assets for backend editor.
 *
 * `wp-blocks`: includes block type registration and related functions.
 * `wp-element`: includes the WordPress Element abstraction for describing the structure of your blocks.
 * `wp-i18n`: To internationalize the block's text.
 *
 * @since 1.0.0
 */
function essential_blocks_cgb_editor_assets()
{
    // Scripts.
    wp_enqueue_script(
        'essential-blocks-js', // Handle.
        plugins_url('/dist/blocks.build.js', dirname(__FILE__)), // Block.build.js: We register the block here. Built with Webpack.
        array('wp-editor', 'wp-blocks', 'wp-i18n', 'wp-element'), // Dependencies, defined above.
        // filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.build.js' ), // Version: filemtime — Gets file modification time.
        true// Enqueue the script in the footer.
    );

    // Styles.
    wp_enqueue_style(
        'essential-blocks-editor-css', // Handle.
        plugins_url('dist/blocks.editor.build.css', dirname(__FILE__)), // Block editor CSS.
        array('wp-edit-blocks') // Dependency to include the CSS after it.
        // filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.editor.build.css' ) // Version: filemtime — Gets file modification time.
    );

    wp_enqueue_style(
        'react-select-style',
        plugins_url('/src/assets/css/react-select.min.css', dirname(__FILE__)),
        array()
    );

    wp_enqueue_style(
        'react-datetime-style',
        plugins_url('/src/assets/css/react-datetime.css', dirname(__FILE__)),
        array()
    );
} // End function essential-blocks_cgb_editor_assets().

// Hook: Editor assets.
add_action('enqueue_block_editor_assets', 'essential_blocks_cgb_editor_assets');

function block_categories($categories, $post)
{
    if ($post->post_type === 'post' || $post->post_type === 'page') {
        $categories = array_merge($categories, [
            [
                'slug' => 'essential-blocks',
                'title' => __('Essential Blocks', 'essential-blocks'),
            ],
        ]);
    }
    return $categories;

}
add_filter('block_categories', 'block_categories', 10, 2);
